
/*******************************************************************************
*	DISCLAIMER
*
*	THIS SOFTWARE IS PROVIDED "AS IS" AND BFG ENGINEERING MAKES NO WARRANTIES
*	REGARDING THIS SOFTWARE, WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING
*	BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR 
*	PURPOSE AND NON-INFRINGEMENT. ALL SUCH WARRANTIES ARE EXPRESSLY DISCLAIMED.
*
*	WE (BFG ENGINEERING) DO NOT WARRANT THAT THIS SOFTWARE IS FREE FROM CLAIMS
*	BY A THIRD PARTY OF COPYRIGHT, PATENT, TRADEMARK, TRADE SECRET OR ANY OTHER
*	INTELLECTUAL PROPERTY INFRINGIMENT.
*
*	TO THE MAXIMUM EXTENT PERMITTED NOT PROHIBITED BY LAW, BFG ENGINEERING
*	SHALL NOT BE LIABLE FOR ANY DIRECT, INDIRECT, SPECIAL, INCIDENTAL OR
*	CONSEQUENTIAL DAMAGES FOR ANY REASON RELATED TO THIS SOFTWARE, EVEN IF BFG
*	ENGINEERING HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
*	PARTICULARLY, UNDER NO CIRCUMSTANCES ARE WE LIABLE FOR ANY OF THE FOLLOWING:
*	- THIRD PARTY CLAIMS AGAINST YOU FOR LOSSES OR DAMAGES;
*	- LOSS OF, OR DAMAGE TO YOUR RECORDS OR DATA; OR
*	- ECONOMIC CONSEQUENTIAL DAMAGES (INCLUDING LOST PROFITS OR SAVINGS) OR
*	  INCIDENTAL DAMAGES, EVEN IF WE ARE INFORMED OF THEIR POSSIBILITY.
*
*	BFG ENGINEERING DOES NOT WARRANT UNINTERRUPTED OR ERROR_FREE OPERATION OF
*	THIS SOFTWARE.
*	BFG ENGINEERING HAS NO OBLIGATION TO PROVIDE SERVICE, DEFECT CORRECTION OR
*	ANY MANTEINANCE OF THIS SOFTWARE; OR TO SUPPLY ANY UPDATES OR ENHANCEMENTS
*	EVEN IF SUCH ARE, OR LATER BECOME, AVAILABLE.
*
*	IF YOU DOWNLOAD OR USE THIS SOFTWARE YOU AGREE TO THESE TERMS, AND DO IT AT
*	YOUR OWN RISK.
*******************************************************************************/

/*******************************************************************************
*	File:		inv_nl.h
*	Project:	MCRP07 RX62T
*	Revision:	7
*	Date:		25-10-2013 (DD-MM-YYYY)
*	Author:		Andrea Ghirardello
*	Contents:	Header for inv_nl.c
*******************************************************************************/

#ifndef _INV_NL_H
#define _INV_NL_H

/******************************************************************************
Function:		INL_IniVar
Description:	variables init
Input:			i maximum index in table
Output:			nothing
Revision:		1.0
******************************************************************************/
void INL_IniVar(unsigned short i);

/******************************************************************************
Function:		INL_SetMea
Description:	measurement routine, used to pass to the algorithm the
				measurement samples
Input:			v voltage amplitude sample [V]
				i current amplitude sample [A]
				b bus voltage sample [V]
Output:			nothing
Revision:		1.0
******************************************************************************/
void INL_SetMea(float v, float i, float b);

/******************************************************************************
Function:		INL_UpdAcc
Description:	trigger routine, used to update the measurement accumulators
Input:			nothing
Output:			nothing
Revision:		1.0
******************************************************************************/
void INL_UpdAcc(void);

/******************************************************************************
Function:		INL_SetRes1
Description:	trigger routine, used to take the first intermediate results
				and to reset the accumulators
Input:			nothing
Output:			nothing
Revision:		1.0
******************************************************************************/
void INL_SetRes1(void);

/******************************************************************************
Function:		INL_SetRes2
Description:	trigger routine, used to take the second intermediate
				results and to reset the accumulators
Input:			nothing
Output:			nothing
Revision:		1.0
******************************************************************************/
void INL_SetRes2(void);

/******************************************************************************
Function:		INL_SetResi
Description:	trigger routine, used to take the i-th intermediate
				results and to reset the accumulators
Input:			v[] voltage measurements vector [V]
				i[] current measurements vector [A]
				b[] bus voltage measurements vector [V]
				k index in the vectors
Output:			nothing
Revision:		1.0
******************************************************************************/
void INL_SetResi(float v[], float i[], float b[], unsigned short k);

/******************************************************************************
Function:		INL_SetTab
Description:	table calculation routine; given the measurements vectors,
				it produces the non-linearity compensation table
Input:			v[] voltage measurements vector [V]
				i[] current measurements vector [A]
				b[] bus voltage measurements vector [V]
				t[] non-linearity table
Output:			nothing
Modifies:		t[0], .., t[ind_max] non-linearity table values
Revision:		1.0
******************************************************************************/
void INL_SetTab(float v[], float i[], float b[], float t[]);

/******************************************************************************
Function:		INL_SetRef
Description:	reference setting routine; given the requested current
				amplitude, it calculates the d and q references
Input:			r requested current amplitude [A]
				*d d reference current address
				*q q reference current address
Output:			nothing
Modifies:		d d reference current address [A]
				q q reference current address [A]
Revision:		1.0
******************************************************************************/
void INL_SetRef(float r, float *d, float *q);

#endif	// _INV_NL_H

