
/*******************************************************************************
*	DISCLAIMER
*
*	THIS SOFTWARE IS PROVIDED "AS IS" AND BFG ENGINEERING MAKES NO WARRANTIES
*	REGARDING THIS SOFTWARE, WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING
*	BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
*	PURPOSE AND NON-INFRINGEMENT. ALL SUCH WARRANTIES ARE EXPRESSLY DISCLAIMED.
*
*	WE (BFG ENGINEERING) DO NOT WARRANT THAT THIS SOFTWARE IS FREE FROM CLAIMS
*	BY A THIRD PARTY OF COPYRIGHT, PATENT, TRADEMARK, TRADE SECRET OR ANY OTHER
*	INTELLECTUAL PROPERTY INFRINGIMENT.
*
*	TO THE MAXIMUM EXTENT PERMITTED NOT PROHIBITED BY LAW, BFG ENGINEERING
*	SHALL NOT BE LIABLE FOR ANY DIRECT, INDIRECT, SPECIAL, INCIDENTAL OR
*	CONSEQUENTIAL DAMAGES FOR ANY REASON RELATED TO THIS SOFTWARE, EVEN IF BFG
*	ENGINEERING HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
*	PARTICULARLY, UNDER NO CIRCUMSTANCES ARE WE LIABLE FOR ANY OF THE FOLLOWING:
*	- THIRD PARTY CLAIMS AGAINST YOU FOR LOSSES OR DAMAGES;
*	- LOSS OF, OR DAMAGE TO YOUR RECORDS OR DATA; OR
*	- ECONOMIC CONSEQUENTIAL DAMAGES (INCLUDING LOST PROFITS OR SAVINGS) OR
*	  INCIDENTAL DAMAGES, EVEN IF WE ARE INFORMED OF THEIR POSSIBILITY.
*
*	BFG ENGINEERING DOES NOT WARRANT UNINTERRUPTED OR ERROR_FREE OPERATION OF
*	THIS SOFTWARE.
*	BFG ENGINEERING HAS NO OBLIGATION TO PROVIDE SERVICE, DEFECT CORRECTION OR
*	ANY MANTEINANCE OF THIS SOFTWARE; OR TO SUPPLY ANY UPDATES OR ENHANCEMENTS
*	EVEN IF SUCH ARE, OR LATER BECOME, AVAILABLE.
*
*	IF YOU DOWNLOAD OR USE THIS SOFTWARE YOU AGREE TO THESE TERMS, AND DO IT AT
*	YOUR OWN RISK.
*******************************************************************************/

/*******************************************************************************
*	File:		const_def.h
*	Project:	MCRP07 RX62T
*	Revision:	7.0
*	Date:		25-10-2013 (DD-MM-YYYY)
*	Author:		Andrea Ghirardello
*	Contents:	Internal constants definition
*******************************************************************************/

#ifndef	_CONST_DEF_H
#define	_CONST_DEF_H
#include "typedefine.h"
#include "customize.h"
#include "pws_E6108A.h"

// floating point numerical constants
#ifndef F_CONST
#define F_CONST
#define PI				3.141592654		// 180
#define PISIXTH			(PI/6.0)		// 030
#define PIFOURTHS		(PI/4.0)		// 045
#define PITHIRDS		(PI/3.0)		// 060
#define PIHALVES		(PI/2.0)		// 090
#define TWOPITHIRDS		(PI*2.0/3.0)	// 120
#define THREEPIFOURTHS	(PI*3.0/4.0)	// 135
#define FIVEPISIXTH		(PI*5.0/6.0)	// 150
#define SEVENPISIXTH	(PI*7.0/6.0)	// 210
#define FIVEPIFOURTHS	(PI*5.0/4.0)	// 225
#define FOURPITHIRDS	(PI*4.0/3.0)	// 240
#define THREEPIHALVES	(PI*3.0/2.0)	// 270
#define FIVEPITHIRDS	(PI*5.0/3.0)	// 300
#define SEVENPIFOURTHS	(PI*7.0/4.0)	// 315
#define ELEVENPISIXTH	(PI*11.0/6.0)	// 330
#define TWOPI			(PI*2.0)		// 360
#define	ONETHIRD		(1.0/3.0)
#define	TWOTHIRDS		(2.0/3.0)
#define	FOURTHIRDS		(4.0/3.0)
#define	SQRT2			1.414213562
#define	SQRT3			1.732050808
#define SQRT2D2			(SQRT2/2.0)
#define SQRT3D2			(SQRT3/2.0)
#define SQRT3D3			(SQRT3/3.0)
#define FPI				((float) PI)
#define FPISIXTH		((float) PISIXTH)
#define FPIFOURTHS		((float) PIFOURTHS)
#define FPITHIRDS		((float) PITHIRDS)
#define FPIHALVES		((float) PIHALVES)
#define FTWOPITHIRDS	((float) TWOPITHIRDS)
#define FTHREEPIFOURTHS	((float) THREEPIFOURTHS)
#define FFIVEPISIXTH	((float) FIVEPISIXTH)
#define FSEVENPISIXTH	((float) SEVENPISIXTH)
#define FFIVEPIFOURTHS	((float) FIVEPIFOURTHS)
#define FFOURPITHIRDS	((float) FOURPITHIRDS)
#define FTHREEPIHALVES	((float) THREEPIHALVES)
#define FFIVEPITHIRDS	((float) FIVEPITHIRDS)
#define FSEVENPIFOURTHS	((float) SEVENPIFOURTHS)
#define FELEVENPISIXTH	((float) ELEVENPISIXTH)
#define FTWOPI			((float) TWOPI)
#define	FONETHIRD		((float) ONETHIRD)
#define	FTWOTHIRDS		((float) TWOTHIRDS)
#define	FFOURTHIRDS		((float) FOURTHIRDS)
#define	FSQRT2			((float) SQRT2)
#define	FSQRT3			((float) SQRT3)
#define FSQRT2D2		((float) SQRT2D2)
#define FSQRT3D2		((float) SQRT3D2)
#define FSQRT3D3		((float) SQRT3D3)
#endif	// F_CONST

// MTU frequency
#define MTU_FRE_HZ		100000000.0				// MTU frequency in Hz

// timings
#if (	((PWM_FREQ_CUSTOM<2500) || (PWM_FREQ_CUSTOM>20000)) ||	\
		((SAM_FREQ_CUSTOM<2500) || (SAM_FREQ_CUSTOM>20000)) ||	\
		(SAM_FREQ_CUSTOM>PWM_FREQ_CUSTOM) )
	#if ((1/0)==0)	// used only to generate a zero divide error @ compile-time
	#endif
#endif
#define TC_RATIO		(PWM_FREQ_CUSTOM/SAM_FREQ_CUSTOM)	// 1<=TC_RATIO<=8 due to previous controls
#if (TC_RATIO==1)
#define	INT_SKIP		0
#else	// if (TC_RATIO==1)
#define	INT_SKIP		(7+TC_RATIO)						// (0x10=8) + (TC_RATIO-1)
#endif	// if (TC_RATIO==1)

#define	PWM_PERIOD_S	(1.0/PWM_FREQ_CUSTOM)				// desired pwm period in sec
#define	SAM_PERIOD_S	(PWM_PERIOD_S*TC_RATIO)				// expected sampling period in sec
#define	SEMIPER			((u16)(PWM_PERIOD_S*MTU_FRE_HZ*0.5))// MTU pulses in 1/2 pwm period
#define PWM_PER			((u16)(SEMIPER*2))					// MTU pulses in 1 pwm period
#define SAM_PER			((u16)(PWM_PER*TC_RATIO))			// MTU pulses in 1 sampling period
#define	PWM_FRE_HZ		((float)(MTU_FRE_HZ/PWM_PER))		// actual pwm frequency in Hz
#define	SAM_FRE_HZ		((float)(MTU_FRE_HZ/SAM_PER))		// actual sampling frequency in Hz
#define	PWM_PER_S		((float)(PWM_PER/MTU_FRE_HZ))		// actual pwm period in sec
#define	SAM_PER_S		((float)(SAM_PER/MTU_FRE_HZ))		// actual sampling period in sec
#define	XMLOOP_PER_S	0.01								// desired main loop time in sec
#define NUM_INT			((u16)(XMLOOP_PER_S*SAM_FRE_HZ))	// main loop timing
#define MLOOP_PER_S		((float)(NUM_INT*SAM_PER_S))		// actual main loop time in sec
#define	MLOOP_FRE_HZ	((float)(SAM_FRE_HZ/NUM_INT))		// actual main loop frequency in Hz
#define CNT_MS( X )		((u32)(( X )*SAM_FRE_HZ/1000.0))	// n. of sam. periods corr. to X[ms]

// other pwm parameters
#if (DEADTIM_NS<=10)	// 10=(1000000000/MTU_FRE_HZ)
#define DEADTIM			1
#else	// if (DEADTIM_NS<=10)
#define DEADTIM			((u16)(MTU_FRE_HZ*(DEADTIM_NS/1000000000.0)))
#endif	// if (DEADTIM_NS<=10)
#define	SEMIPERDEAD		((u16)(SEMIPER+DEADTIM))
#define PWM_CENTER		((u16)(SEMIPERDEAD>>1))

// minimum on time of low arms, to guarantee bootstrap operations (LARGER than DEADTIM!)
#define MIN_TON_LOW		((u16)(MTU_FRE_HZ*(MIN_TON_LOW_NS/1000000000.0)))

// maximum delta duty and default effective output voltage ratio
#define DELMAX			((u16)(SEMIPER - MIN_TON_LOW))
#define KVOUT			((float)(DELMAX/((float)SEMIPER)))

// 12 bit A/D converter voltage and range
#define A12VCC			5.0		// A/D Range V
#define AD12FS			4096.0	// A/D full scale (bit)

// 10 bit A/D converter voltage and range
#define A10VCC			5.0		// A/D Range V
#define AD10FS			1024.0	// A/D full scale (bit)

// reference voltage
#define VREF_VOL		4.25	// reference voltage value
#define VREF_AD			((float)(VREF_VOL*AD10FS/A10VCC))

// output currents A/D conversion (the reading is referred to AVCC/2, so half the range is used)
#define RAV_AD			(1.0/(RSHUNT_OHM*RSGAIN))	// peak real_ampere/pin_volt ratio at the input pin

// voltages (bus and output) A/D conversion (the reading is referred to 0, so all the range is used)
#define RVV_AD			((RVBUSH_OHM+RVBUSL_OHM)/RVBUSL_OHM)	// peak real_volt/pin_volt ratio at the input pin

// currents
#define KADI			((float)(RAV_AD*A12VCC/AD12FS))

// voltages
#define KADV			((float)(RVV_AD*A12VCC/AD12FS))

// time, speed etc. conversion constants
#define KFO				((float)(TWOPI))		// Omega[rad/sec]=KFO*Freq[Hertz]
#define KOF				((float)(1.0/TWOPI))	// Freq[Hertz]=KOF*Omega[rad/sec]
#define KRPMO			((float)(TWOPI/60.0))	// Omega[rad/sec]=KRPMO*velocita[rpm]
#define KORPM			((float)(60.0/TWOPI))	// velocita[rpm]=KORPM*Omega[rad/sec]

// flux weakening
#define INTID_RAMP		((float)(DCUR_DT/SAM_FRE_HZ))

// phase compensation
#define K_COMPPH		1.5f
#define COMPTIME		((float) (SAM_PER_S*K_COMPPH))

// alarms
#define	EQP_ALL			1	// eeprom alarm code
#define	FAULT_ALL		2	// overcurrent hardware alarm code (POE)
#define	TRIP_ALL		3	// loss of phase alarm code

// trip control
#define TRIP_CONTROL
#define MAX_TRIP		150

#endif	// _CONST_DEF_H


