
/*******************************************************************************
*	DISCLAIMER
*
*	THIS SOFTWARE IS PROVIDED "AS IS" AND BFG ENGINEERING MAKES NO WARRANTIES
*	REGARDING THIS SOFTWARE, WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING
*	BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
*	PURPOSE AND NON-INFRINGEMENT. ALL SUCH WARRANTIES ARE EXPRESSLY DISCLAIMED.
*
*	WE (BFG ENGINEERING) DO NOT WARRANT THAT THIS SOFTWARE IS FREE FROM CLAIMS
*	BY A THIRD PARTY OF COPYRIGHT, PATENT, TRADEMARK, TRADE SECRET OR ANY OTHER
*	INTELLECTUAL PROPERTY INFRINGIMENT.
*
*	TO THE MAXIMUM EXTENT PERMITTED NOT PROHIBITED BY LAW, BFG ENGINEERING
*	SHALL NOT BE LIABLE FOR ANY DIRECT, INDIRECT, SPECIAL, INCIDENTAL OR
*	CONSEQUENTIAL DAMAGES FOR ANY REASON RELATED TO THIS SOFTWARE, EVEN IF BFG
*	ENGINEERING HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
*	PARTICULARLY, UNDER NO CIRCUMSTANCES ARE WE LIABLE FOR ANY OF THE FOLLOWING:
*	- THIRD PARTY CLAIMS AGAINST YOU FOR LOSSES OR DAMAGES;
*	- LOSS OF, OR DAMAGE TO YOUR RECORDS OR DATA; OR
*	- ECONOMIC CONSEQUENTIAL DAMAGES (INCLUDING LOST PROFITS OR SAVINGS) OR
*	  INCIDENTAL DAMAGES, EVEN IF WE ARE INFORMED OF THEIR POSSIBILITY.
*
*	BFG ENGINEERING DOES NOT WARRANT UNINTERRUPTED OR ERROR_FREE OPERATION OF
*	THIS SOFTWARE.
*	BFG ENGINEERING HAS NO OBLIGATION TO PROVIDE SERVICE, DEFECT CORRECTION OR
*	ANY MANTEINANCE OF THIS SOFTWARE; OR TO SUPPLY ANY UPDATES OR ENHANCEMENTS
*	EVEN IF SUCH ARE, OR LATER BECOME, AVAILABLE.
*
*	IF YOU DOWNLOAD OR USE THIS SOFTWARE YOU AGREE TO THESE TERMS, AND DO IT AT
*	YOUR OWN RISK.
*******************************************************************************/

/*******************************************************************************
*	File:		hwsetup.c
*	Project:	MCRP07 RX62T
*	Revision:	7.0
*	Date:		25-10-2013 (DD-MM-YYYY)
*	Author:		Andrea Ghirardello
*	Contents:	Hardware setup file
*******************************************************************************/

#include "globdef.h"

/* PIN DESCRIPTION MCRP07 RX62T ************************************************

   1 PE5 IRQ0-B							DIG IN	PE5_UP1			EXT_SUP_ON
   2 EMLE								E1 IN	EMLE_UP2
   3 VSS
   4 MDE								E1 IN	MDE_UP4
   5 VCL
   6 MD1								E1 IN	MD1_UP6
   7 MD0								E1 IN	MD0_UP7
   8 PE4 TCLKC-C IRQ1-B POE10#-B		DIG IN	X
   9 PE3 TCLKD-C IRQ2-A POE11#			DIG IN	X
  10 RES#								E1 IN	RES_UP10
  11 XTAL
  12 VSS
  13 EXTAL
  14 VCC
  15 PE2 NMI POE10#-A					DIG IN	NMI_UP15
  16 PE1 SSL3-C							DIG OUT	EEPSCL_UP16		EEP_SCL
  17 PE0 CRX-C SSL2-C					DIG I/O EEPSDA_UP17		EEP_SDA
  18 PD7 GTIOC0A-B CTX-C SSL1-C TRST#	E1 IN	TRST_UP18
  19 PD6 GTIOC0B-B SSL0-C TMS			E1 IN	TMS_UP19
  20 PD5 GTIOC1A-B RxD1 TDI				E1 IN	TDI_UP20
  21 PD4 GTIOC1B-B SCK1 TCK				E1 IN	TCK_UP21
  22 PD3 GTIOC2A-B TxD1 TDO				E1 IN	TDO_UP22
  23 PD2 GTIOC2B-B MOSI-C TRCLK			DIG IN	X
  24 PD1 GTIOC3A MISO-C TRDATA3			DIG IN	X
  25 PD0 GTIOC3B RSPCK-C TRDATA2		DIG IN	X
>>
  26 PB7 SCK2-A TRDATA1					DIG IN	X
  27 PB6 CRX-A RxD2-A TRDATA0			DIG IN	RXD2_UP27		RX
  28 PB5 CTX-A TxD2-A TRSYNC#			DIG OUT	TXD2_UP28		TX
  29 PLLVCC
  30 PB4 GTETRG IRQ3 POE8#				DIG IN	X
  31 PLLVSS
  32 PB3 MTIOC0A-A SCK0					DIG IN	MTIOC0A_UP32	HALL_A
  33 PB2 MTIOC0B-A TxD0 SDA				DIG IN	MTIOC0B_UP33	HALL_B
  34 PB1 MTIOC0C RxD0 SCL				DIG IN	MTIOC0C_UP34	HALL_C
  35 PB0 MTIOC0D MOSI-B					DIG OUT MTIOC0D_UP35	DEB_PWM1
  36 PA5 ADTRG1#-A MTIOC1A MISO-B		DIG OUT MTIOC1A_UP36	DEB_PWM2
  37 PA4 ADTRG0#-A MTIOC1B RSPCK-B		DIG OUT MTIOC1B_UP37	DEB_PWM3
  38 PA3 MTIOC2A SSL0-B					DIG IN	X
  39 PA2 MTIOC2B SSL1-B					DIG IN	X
  40 PA1 MTIOC6A SSL2-B					DIG IN	X
  41 PA0 MTIOC6C SSL3-B					DIG IN	X
  42 VCC
  43 P96 IRQ4 POE4#						DIG IN	POE4_UP43		OVCURR
  44 VSS
  45 P95 MTIOC6B						DIG OUT	MTIOC6B_UP45	PWM_UH
  46 P94 MTIOC7A						DIG OUT	MTIOC7A_UP46	PWM_VH
  47 P93 MTIOC7B						DIG OUT	MTIOC7B_UP47	PWM_WH
  48 P92 MTIOC6D						DIG OUT	MTIOC6D_UP48	PWM_UL
  49 P91 MTIOC7C						DIG OUT	MTIOC7C_UP49	PWM_VL
  50 P90 MTIOC7D						DIG OUT	MTIOC7D_UP50	PWM_WL
>>
  51 P76 MTIOC4D GTIOC2B-A				DIG OUT	MTIOC4D_UP51	PWM1_WL
  52 P75 MTIOC4C GTIOC1B-A				DIG OUT	MTIOC4C_UP52	PWM1_VL
  53 P74 MTIOC3D GTIOC0B-A				DIG OUT	MTIOC3D_UP53	PWM1_UL
  54 P73 MTIOC4B GTIOC2A-A				DIG OUT	MTIOC4B_UP54	PWM1_WH
  55 P72 MTIOC4A GTIOC1A-A				DIG OUT	MTIOC4A_UP55	PWM1_VH
  56 P71 MTIOC3B GTIOC0A-A				DIG OUT	MTIOC3B_UP56	PWM1_UH
  57 P70 IRQ5 POE0#						DIG IN	POE0_UP57		OVCURR1
  58 P33 MTIOC3A MTCLKA-A SSL3-A		DIG OUT	P33_UP58		DL4
  59 P32 MTIOC3C MTCLKB-A SSL2-A		DIG OUT	P32_UP59		DL3
  60 VCC
  61 P31 MTIOC0A-B MTCLKC-A SSL1-A		DIG OUT	P31_UP61		DL2
  62 VSS
  63 P30 MTIOC0B-B MTCLKD-A SSL0-A		DIG OUT	P30_UP63		DL1
  64 P24 RSPCK-A						DIG IN	X
  65 P23 CTX-B LTX MOSI-A				DIG IN	X
  66 P22 ADTRG2# CRX-B LRX MISO-A		DIG IN	X
  67 P21 ADTRG1#-B MTCLKA-B IRQ6		DIG IN	MTCLKA_UP67		ENC_A1
  68 P20 ADTRG0#-B MTCLKB-B IRQ7		DIG IN	MTCLKB_UP68		ENC_A1
  69 P65 AN5							ANA IN	AN5_UP69		AN5_EXT
  70 P64 AN4							ANA IN	AN4_UP70		AN4_EXT
  71 AVCC2
  72 VREF
  73 AVSS2
  74 P63 AN3							ANA IN	AN3_UP74		AN3_TP
  75 P62 AN2							ANA IN	AN2_UP75		AN2_TEMP
>>
  76 P61 AN1							ANA IN	AN1_UP76		AN1_POT
  77 P60 AN0							ANA IN	AN0_UP77		AN0_REF
  78 P55 AN11							DIG IN	P55_UP78		GND
  79 P54 AN10							DIG IN	P54_UP79		GND
  80 P53 AN9							DIG IN	P53_UP80		SW3
  81 P52 AN8							DIG IN	P52_UP81		SW2
  82 P51 AN7							DIG IN	P51_UP82		SW1
  83 P50 AN6							DIG IN	P50_UP83		SW0
  84 P47 AN103 CVREFH					ANA IN	AN103_UP84		VB1
  85 P46 AN102							ANA IN	AN102_UP85		IU1
  86 P45 AN101							ANA IN	AN101_UP86		IV1
  87 P44 AN100							ANA IN	AN100_UP87		IW1
  88 P43 AN003 CVREFL					ANA IN	AN003_UP88		VB
  89 P42 AN002							ANA IN	AN002_UP89		IU
  90 P41 AN001							ANA IN	AN001_UP90		IV
  91 P40 AN000							ANA IN	AN000_UP91		IW
  92 AVCC1
  93 VREFH
  94 VREFL
  95 AVSS1
  96 P82 MTIC5U SCK2-B					DIG IN	MTIC5U_UP96		DEAD_U1
  97 P81 MTIC5V TxD2-B					DIG IN	MTIC5V_UP97		DEAD_V1
  98 P80 MTIC5W RxD2-B					DIG IN	MTIC5W_UP98		DEAD_W1
  99 P11 MTCLKC-B IRQ1-A				DIG IN 	MTCLKC_UP99		ENC_A
 100 P10 MTCLKD-B IRQ0-A				DIG IN 	MTCLKD_UP100	ENC_B

*******************************************************************************/

void HardwareSetup(void)
{

	/*** System configuration (clock, ram, rom etc.) ***/

	//SYSTEM.MDMONR.WORD			// at reset reflects the pin status
									// B15, .., B8
	//SYSTEM.MDMONR.BIT.MDE			// B7
									// B6, .., B2
	//SYSTEM.MDMONR.BIT.MD1			// B1
	//SYSTEM.MDMONR.BIT.MD0			// B0

	//SYSTEM.MDSR.WORD				// reset 0x0009 (on chip rom enabled)
									// B15, .., B5
	//SYSTEM.MDSR.BIT.BOTS			// B4
									// B3, .., B1
	//SYSTEM.MDSR.BIT.IROM			// B0

	//SYSTEM.SYSCR0.WORD			// reset 0x0001	(internal rom enabled)
	//SYSTEM.SYSCR0.BIT.KEY			// B15, .., B8
									// B7, .., B1
	//SYSTEM.SYSCR0.BIT.ROME		// B0

	//SYSTEM.SYSCR1.WORD			// reset 0x0001 (internal ram enabled)
									// B15, .., B1
	//SYSTEM.SYSCR1.BIT.RAME		// B0

	//SYSTEM.SBYCR.WORD				// reset 0x4F00
	//SYSTEM.SBYCR.BIT.SSBY			// B15
									// B14, B13
	//SYSTEM.SBYCR.BIT.STS			// B12, .., B8
									// B7, .., B0

	//SYSTEM.MSTPCRA.LONG			// reset 0x46FFFFFF
	//SYSTEM.MSTPCRA.BIT.ACSE		// B31				All modules
									// B30, B29
	//SYSTEM.MSTPCRA.BIT.MSTPA28	// B28				DTC
									// B27, .., B25
	//SYSTEM.MSTPCRA.BIT.MSTPA24	// B24				S12AD control section
	//SYSTEM.MSTPCRA.BIT.MSTPA23	// B28				AD 10bit
									// B22, .., B18
	//SYSTEM.MSTPCRA.BIT.MSTPA17	// B17				AD 12bit unit 0
	//SYSTEM.MSTPCRA.BIT.MSTPA16	// B16				AD 12bit unit 1
	//SYSTEM.MSTPCRA.BIT.MSTPA15	// B15				CMT0, CMT1
	//SYSTEM.MSTPCRA.BIT.MSTPA14	// B14				CMT2, CMT3
									// B13, .., B10
	//SYSTEM.MSTPCRA.BIT.MSTPA9		// B9				MTU3
									// B8
	//SYSTEM.MSTPCRA.BIT.MSTPA7		// B7				GPT
									// B6, .., B0

	//SYSTEM.MSTPCRB.LONG			// reset 0xFFFFFFFF
	//SYSTEM.MSTPCRB.BIT.MSTPB31	// B31				SCI0
	//SYSTEM.MSTPCRB.BIT.MSTPB30	// B30				SCI1
	//SYSTEM.MSTPCRB.BIT.MSTPB29	// B29				SCI2
									// B28, B24
	//SYSTEM.MSTPCRB.BIT.MSTPB23	// B23				CRC
									// B22
	//SYSTEM.MSTPCRB.BIT.MSTPB21	// B21				RIIC
									// B20, .., B18
	//SYSTEM.MSTPCRB.BIT.MSTPB17	// B17				RSPI
									// B16, .., B8
	//SYSTEM.MSTPCRB.BIT.MSTPB7		// B7				LIN
									// B6, .., B1
	//SYSTEM.MSTPCRB.BIT.MSTPB0		// B0				CAN

	//SYSTEM.MSTPCRC.LONG			// reset 0xFFFF0000
									// B31, .., B1
	//SYSTEM.MSTPCRC.BIT.MSTPC0		// B0				RAM

	SYSTEM.SCKCR.LONG=0x00020100;	// reset 0x02020200
									// B31, .., B28
	//SYSTEM.SCKCR.BIT.ICK=0;		// B27, .., B24		ICK=0 -> ICLK=EXTAL*8 (12.5M*8=100MHz)
									// B24, .., B12
	//SYSTEM.SCKCR.BIT.PCK=1;		// B11, .., B8		PCK=1 -> PCLK=EXTAL*4 (12.5M*4=50MHz)
									// B7, .., B0
	nop(); nop(); nop(); nop(); nop();	// wait some time after changing system clock frequency
	nop(); nop(); nop(); nop(); nop();	// wait some time after changing system clock frequency
	nop(); nop(); nop(); nop(); nop();	// wait some time after changing system clock frequency

	//SYSTEM.OSTDCR.WORD			// reset 0x0080
	//SYSTEM.OSTDCR.BIT.KEY			// B15, .., B8
	//SYSTEM.OSTDCR.BIT.OSTDE		// B7			Oscillation Stop Detect function is enabled
	//SYSTEM.OSTDCR.BIT.OSTDF		// B6
									// B5, .., B0

	//SYSTEM.DPSBYCR.BYTE			// reset 0x31
	//SYSTEM.DPSBYCR.BIT.DPSBY		// B7
	//SYSTEM.DPSBYCR.BIT.IOKEEP		// B6
									// B5, .., B0

	//SYSTEM.DPSWCR.BYTE			// reset 0x0F
									// B7, B6
	//SYSTEM.DPSWCR.BIT.WTSTS		// B5, .., B0

	//SYSTEM.DPSIER.BYTE			// reset 0x00
	//SYSTEM.DPSIER.BIT.DNMIE		// B7
									// B6, B5
	//SYSTEM.DPSIER.BIT.DLVDE		// B4
									// B3, B2
	//SYSTEM.DPSIER.BIT.DIRQ1E		// B1
	//SYSTEM.DPSIER.BIT.DIRQ0E		// B0

	//SYSTEM.DPSIFR.BYTE			// reset 0x00
	//SYSTEM.DPSIFR.BIT.DNMIF		// B7
									// B6, B5
	//SYSTEM.DPSIFR.BIT.DLVDF		// B4
									// B3, B2
	//SYSTEM.DPSIFR.BIT.DIRQ1F		// B1
	//SYSTEM.DPSIFR.BIT.DIRQ0F		// B0

	//SYSTEM.DPSIEGR.BYTE			// reset 0x00
	//SYSTEM.DPSIEGR.BIT.DNMIEG		// B7
									// B6, B2
	//SYSTEM.DPSIEGR.BIT.DIRQ1EG	// B1
	//SYSTEM.DPSIEGR.BIT.DIRQ0EG	// B0

	//SYSTEM.RSTSR.BYTE				// reset (value is determined by reset type)
	//SYSTEM.RSTSR.BIT.DPSRSTF		// B7
									// B6, B3
	//SYSTEM.RSTSR.BIT.LVD2F		// B2
	//SYSTEM.RSTSR.BIT.LVD1F		// B1
	//SYSTEM.RSTSR.BIT.PORF			// B0

	//SYSTEM.LVDKEYR				// reset 0x00

	//SYSTEM.LVDCR.BYTE				// reset 0x00
	//SYSTEM.LVDCR.BIT.LVD2E		// B7
	//SYSTEM.LVDCR.BIT.LVD2RI		// B6
									// B5, B4
	//SYSTEM.LVDCR.BIT.LVD1E		// B3
	//SYSTEM.LVDCR.BIT.LVD1RI		// B2
									// B1, B0
	//SYSTEM.DPSBKR[32]				// reset undefined


	/*** Watchdog timer ***/

	//WDT.READ.TCSR.BYTE		// reset 0xX8	(not enabled, interval timer)
								// B7
	//WDT.READ.TCSR.BIT.TMS		// B6
	//WDT.READ.TCSR.BIT.TME		// B5
								// B4, B3
	//WDT.READ.TCSR.BIT.CKS		// B2, B1, B0

	//WDT.READ.TCNT				// reset 0x00

	//WDT.READ.RSTCSR.BYTE		// reset 0x1F
	//WDT.READ.RSTCSR.BIT.WOVF	// B7
	//WDT.READ.RSTCSR.BIT.RSTE	// B6
								// B5, .., B0

	//WDT.WRITE.WINA=0x0000;
	//WDT.WRITE.WINB=0x0000;


	/*** Independent Watchdog Timer ***/

	//IWDT.IWDTCR.IWDTRR			// reset 0xFF

	//IWDT.IWDTCR.IWDTCR.WORD		// reset 0x3303
									// B15, .., B8
	//IWDT.IWDTCR.IWDTCR.BIT.CKS	// B7, .., B4
									// B3, B2
	//IWDT.IWDTCR.IWDTCR.BIT.TOPS	// B1, B0

	//IWDT.IWDTSR.WORD				// reset 0x0000
									// B15
	//IWDT.IWDTSR.BIT.UNDFF			// B14
	//IWDT.IWDTSR.BIT.CNTVAL		// B13, .., B0


	/*** Port function registers ***/

	//IOPORT.PF8IRQ.BYTE=0x00;		// reset 0x00
									// B7, .., B4
	//IOPORT.PF8IRQ.BIT.ITS1=0;		// B3, B2
	//IOPORT.PF8IRQ.BIT.ITS0=0;		// B1, B0

	//IOPORT.PF9IRQ.BYTE=0x00;		// reset 0x00
									// B7, .., B3
	//IOPORT.PF9IRQ.BIT.ITS2=0;		// B2
									// B1, B0

	//IOPORT.PFAADC.BYTE=0x00;		// reset 0x00
									// B7, .., B2
	//IOPORT.PFAADC.BIT.ADTRG1S=0;	// B1
	//IOPORT.PFAADC.BIT.ADTRG0S=0;	// B0

	IOPORT.PFCMTU.BYTE=0x40;		// reset 0x00
	//IOPORT.PFCMTU.BIT.TCLKS=1;	// B7, B6		MTCLKA, B, C, D -B selected
									// B5, .., B2
	//IOPORT.PFCMTU.BIT.MTUS1=0;	// B1			MTIOC0B -A selected
	//IOPORT.PFCMTU.BIT.MTUS0=0;	// B0			MTIOC0A -A selected

	//IOPORT.PFDGPT.BYTE=0x00;		// reset 0x00
									// B7, .., B1
	//IOPORT.PFDGPT.BIT.GPTS=0;		// B0

	//IOPORT.PFFSCI.BYTE=0x00;		// reset 0x00
									// B7, .., B3
	//IOPORT.PFFSCI.BIT.SCI2S=0;	// B2			TXD2-A, RXD2-A selected
									// B1, B0

	//IOPORT.PFGSPI.BYTE=0x00;		// reset 0x00
	//IOPORT.PFGSPI.BIT.SSL3E=0;	// B7
	//IOPORT.PFGSPI.BIT.SSL2E=0;	// B6
	//IOPORT.PFGSPI.BIT.SSL1E=0;	// B5
	//IOPORT.PFGSPI.BIT.SSL0E=0;	// B4
	//IOPORT.PFGSPI.BIT.MISOE=0;	// B3
	//IOPORT.PFGSPI.BIT.MOSIE=0;	// B2
	//IOPORT.PFGSPI.BIT.RSPCKE=0;	// B1
									// B0

	//IOPORT.PFHSPI.BYTE=0x00;		// reset 0x00
									// B7, .., B2
	//IOPORT.PFHSPI.BIT.RSPIS=0;	// B1, B0

	//IOPORT.PFJCAN.BYTE=0x00;		// reset 0x00
	//IOPORT.PFJCAN.BIT.CANS=0;		// B7, B6
									// B5, .., B2
	//IOPORT.PFJCAN.BIT.CANE=0;		// B1, B0

	//IOPORT.PFKLIN.BYTE=0x00;		// reset 0x00
									// B7, .., B1
	//IOPORT.PFKLIN.BIT.LINE=0;		// B0

	//IOPORT.PFMPOE.BYTE=0x00;		// reset 0x00
									// B7, .., B5
	//IOPORT.PFMPOE.BIT.POE11E=0;	// B4
	//IOPORT.PFMPOE.BIT.POE10E=0;	// B3
	//IOPORT.PFMPOE.BIT.POE8E=0;	// B2
	//IOPORT.PFMPOE.BIT.POE4E=0;	// B1			DISABLED for the moment
	//IOPORT.PFMPOE.BIT.POE0E=0;	// B0			DISABLED for the moment

	//IOPORT.PFNPOE.BYTE=0x00;		// reset 0x00
	//IOPORT.PFNPOE.BIT.POE10S=0;	// B7
									// B6, .., B0


	/*** Port 1 ***/

	//PORT1.DR.BYTE=0x00;			// reset 0x00
		// B7, .., B2
	//PORT1.DR.BIT.B1=0;			// PIN99	P11 DIG IN 	MTCLKC_UP99		ENC_A
	//PORT1.DR.BIT.B0=0;			// PIN100	P10 DIG IN 	MTCLKD_UP100	ENC_B

	//PORT1.DDR.BYTE=0x00;			// reset 0x00
		// B7, .., B2
	//PORT1.DDR.BIT.B1=0;			// PIN99	P11 DIG IN 	MTCLKC_UP99		ENC_A
	//PORT1.DDR.BIT.B0=0;			// PIN100	P10 DIG IN 	MTCLKD_UP100	ENC_B

	//PORT1.PORT.BYTE				// reset undefined
		// B7, .., B2
	//PORT1.PORT.BIT.B1				// PIN99	P11 DIG IN 	MTCLKC_UP99		ENC_A
	//PORT1.PORT.BIT.B0				// PIN100	P10 DIG IN 	MTCLKD_UP100	ENC_B

	PORT1.ICR.BYTE=0x03;			// reset 0x00
		// B7, .., B2
	//PORT1.ICR.BIT.B1=1;			// PIN99	P11 DIG IN 	MTCLKC_UP99		ENC_A
	//PORT1.ICR.BIT.B0=1;			// PIN100	P10 DIG IN 	MTCLKD_UP100	ENC_B


	/*** Port 2 ***/

	//PORT2.DR.BYTE=0x00;			// reset 0x00
		// B7, .., B5
	//PORT2.DR.BIT.B4=0;			// PIN64	P24 DIG IN	X
	//PORT2.DR.BIT.B3=0;			// PIN65	P23 DIG IN	X
	//PORT2.DR.BIT.B2=0;			// PIN66	P22 DIG IN	X
	//PORT2.DR.BIT.B1=0;			// PIN67	P21 DIG IN	MTCLKA_UP67		ENC_A1
	//PORT2.DR.BIT.B0=0;			// PIN68	P20 DIG IN	MTCLKB_UP68		ENC_A1

	//PORT2.DDR.BYTE=0x00;			// reset 0x00
		// B7, .., B5
	//PORT2.DDR.BIT.B4=0;			// PIN64	P24 DIG IN	X
	//PORT2.DDR.BIT.B3=0;			// PIN65	P23 DIG IN	X
	//PORT2.DDR.BIT.B2=0;			// PIN66	P22 DIG IN	X
	//PORT2.DDR.BIT.B1=0;			// PIN67	P21 DIG IN	MTCLKA_UP67		ENC_A1
	//PORT2.DDR.BIT.B0=0;			// PIN68	P20 DIG IN	MTCLKB_UP68		ENC_A1

	//PORT2.PORT.BYTE				// reset undefined
		// B7, .., B5
	//PORT2.PORT.BIT.B4				// PIN64	P24 DIG IN	X
	//PORT2.PORT.BIT.B3				// PIN65	P23 DIG IN	X
	//PORT2.PORT.BIT.B2				// PIN66	P22 DIG IN	X
	//PORT2.PORT.BIT.B1				// PIN67	P21 DIG IN	MTCLKA_UP67		ENC_A1
	//PORT2.PORT.BIT.B0				// PIN68	P20 DIG IN	MTCLKB_UP68		ENC_A1

	PORT2.ICR.BYTE=0x03;			// reset 0x00
		// B7, .., B5
	//PORT2.ICR.BIT.B4=0;			// PIN64	P24 DIG IN	X
	//PORT2.ICR.BIT.B3=0;			// PIN65	P23 DIG IN	X
	//PORT2.ICR.BIT.B2=0;			// PIN66	P22 DIG IN	X
	//PORT2.ICR.BIT.B1=1;			// PIN67	P21 DIG IN	MTCLKA_UP67		ENC_A1
	//PORT2.ICR.BIT.B0=1;			// PIN68	P20 DIG IN	MTCLKB_UP68		ENC_A1


	/*** Port 3 ***/

	PORT3.DR.BYTE=0x0F;				// reset 0x00
		// B7, .., B4
	//PORT3.DR.BIT.B3=1;			// PIN58	P33 DIG OUT	P33_UP58		DL4
	//PORT3.DR.BIT.B2=1;			// PIN59	P32 DIG OUT	P32_UP59		DL3
	//PORT3.DR.BIT.B1=1;			// PIN61	P31 DIG OUT	P31_UP61		DL2
	//PORT3.DR.BIT.B0=1;			// PIN63	P30 DIG OUT	P30_UP63		DL1

	PORT3.DDR.BYTE=0x0F;			// reset 0x00
		// B7, .., B4
	//PORT3.DDR.BIT.B3=1;			// PIN58	P33 DIG OUT	P33_UP58		DL4
	//PORT3.DDR.BIT.B2=1;			// PIN59	P32 DIG OUT	P32_UP59		DL3
	//PORT3.DDR.BIT.B1=1;			// PIN61	P31 DIG OUT	P31_UP61		DL2
	//PORT3.DDR.BIT.B0=1;			// PIN63	P30 DIG OUT	P30_UP63		DL1

	//PORT3.PORT.BYTE				// reset undefined
		// B7, .., B4
	//PORT3.PORT.BIT.B3				// PIN58	P33 DIG OUT	P33_UP58		DL4
	//PORT3.PORT.BIT.B2				// PIN59	P32 DIG OUT	P32_UP59		DL3
	//PORT3.PORT.BIT.B1				// PIN61	P31 DIG OUT	P31_UP61		DL2
	//PORT3.PORT.BIT.B0				// PIN63	P30 DIG OUT	P30_UP63		DL1

	//PORT3.ICR.BYTE=0x00;			// reset 0x00
		// B7, .., B4
	//PORT3.ICR.BIT.B3=0;			// PIN58	P33 DIG OUT	P33_UP58		DL4
	//PORT3.ICR.BIT.B2=0;			// PIN59	P32 DIG OUT	P32_UP59		DL3
	//PORT3.ICR.BIT.B1=0;			// PIN61	P31 DIG OUT	P31_UP61		DL2
	//PORT3.ICR.BIT.B0=0;			// PIN63	P30 DIG OUT	P30_UP63		DL1


	/*** Port 4 ***/

	//PORT4.PORT.BYTE				// reset undefined
	//PORT4.PORT.BIT.B7				// PIN84	P47 ANA IN	AN103_UP84		VB1
	//PORT4.PORT.BIT.B6				// PIN85	P46 ANA IN	AN102_UP85		IU1
	//PORT4.PORT.BIT.B5				// PIN86	P45 ANA IN	AN101_UP86		IV1
	//PORT4.PORT.BIT.B4				// PIN87	P44 ANA IN	AN100_UP87		IW1
	//PORT4.PORT.BIT.B3				// PIN88	P43 ANA IN	AN003_UP88		VB
	//PORT4.PORT.BIT.B2				// PIN89	P42 ANA IN	AN002_UP89		IU
	//PORT4.PORT.BIT.B1				// PIN90	P41 ANA IN	AN001_UP90		IV
	//PORT4.PORT.BIT.B0				// PIN91	P40 ANA IN	AN000_UP91		IW

	//PORT4.ICR.BYTE=0x00;			// reset 0x00
	//PORT4.ICR.BIT.B7=0;			// PIN84	P47 ANA IN	AN103_UP84		VB1
	//PORT4.ICR.BIT.B6=0;			// PIN85	P46 ANA IN	AN102_UP85		IU1
	//PORT4.ICR.BIT.B5=0;			// PIN86	P45 ANA IN	AN101_UP86		IV1
	//PORT4.ICR.BIT.B4=0;			// PIN87	P44 ANA IN	AN100_UP87		IW1
	//PORT4.ICR.BIT.B3=0;			// PIN88	P43 ANA IN	AN003_UP88		VB
	//PORT4.ICR.BIT.B2=0;			// PIN89	P42 ANA IN	AN002_UP89		IU
	//PORT4.ICR.BIT.B1=0;			// PIN90	P41 ANA IN	AN001_UP90		IV
	//PORT4.ICR.BIT.B0=0;			// PIN91	P40 ANA IN	AN000_UP91		IW


	/*** Port 5 ***/

	//PORT5.PORT.BYTE				// reset undefined
		// B7, B6
	//PORT5.PORT.BIT.B5				// PIN78	P55 DIG IN	P55_UP78		GND
	//PORT5.PORT.BIT.B4				// PIN79	P54 DIG IN	P54_UP79		GND
	//PORT5.PORT.BIT.B3				// PIN80	P53 DIG IN	P53_UP80		SW3
	//PORT5.PORT.BIT.B2				// PIN81	P52 DIG IN	P52_UP81		SW2
	//PORT5.PORT.BIT.B1				// PIN82	P51 DIG IN	P51_UP82		SW1
	//PORT5.PORT.BIT.B0				// PIN83	P50 DIG IN	P50_UP83		SW0

	//PORT5.ICR.BYTE=0x00;			// reset 0x00
		// B7, B6
	//PORT5.ICR.BIT.B5=0;			// PIN78	P55 DIG IN	P55_UP78		GND
	//PORT5.ICR.BIT.B4=0;			// PIN79	P54 DIG IN	P54_UP79		GND
	//PORT5.ICR.BIT.B3=0;			// PIN80	P53 DIG IN	P53_UP80		SW3
	//PORT5.ICR.BIT.B2=0;			// PIN81	P52 DIG IN	P52_UP81		SW2
	//PORT5.ICR.BIT.B1=0;			// PIN82	P51 DIG IN	P51_UP82		SW1
	//PORT5.ICR.BIT.B0=0;			// PIN83	P50 DIG IN	P50_UP83		SW0


	/*** Port 6 ***/

	//PORT6.PORT.BYTE				// reset undefined
		// B7, B6
	//PORT6.PORT.BIT.B5				// PIN69	P65 ANA IN	AN5_UP69		AN5_EXT
	//PORT6.PORT.BIT.B4				// PIN70	P64 ANA IN	AN4_UP70		AN4_EXT
	//PORT6.PORT.BIT.B3				// PIN74	P63 ANA IN	AN3_UP74		AN3_TP
	//PORT6.PORT.BIT.B2				// PIN75	P62 ANA IN	AN2_UP75		AN2_TEMP
	//PORT6.PORT.BIT.B1				// PIN76	P61 ANA IN	AN1_UP76		AN1_POT
	//PORT6.PORT.BIT.B0				// PIN77	P60 ANA IN	AN0_UP77		AN0_REF

	//PORT6.ICR.BYTE=0x00;			// reset 0x00
		// B7, B6
	//PORT6.ICR.BIT.B5=0;			// PIN69	P65 ANA IN	AN5_UP69		AN5_EXT
	//PORT6.ICR.BIT.B4=0;			// PIN70	P64 ANA IN	AN4_UP70		AN4_EXT
	//PORT6.ICR.BIT.B3=0;			// PIN74	P63 ANA IN	AN3_UP74		AN3_TP
	//PORT6.ICR.BIT.B2=0;			// PIN75	P62 ANA IN	AN2_UP75		AN2_TEMP
	//PORT6.ICR.BIT.B1=0;			// PIN76	P61 ANA IN	AN1_UP76		AN1_POT
	//PORT6.ICR.BIT.B0=0;			// PIN77	P60 ANA IN	AN0_UP77		AN0_REF


	/*** Port 7 ***/

	// WARNING: PWM ACTIVE LEVEL IS HIGH

	PORT7.DR.BYTE=0x01;				// reset 0x00
	//PORT7.DR.BYTE=0x71;			// low drives on @reset
		// B7
	//PORT7.DR.BIT.B6=0;			// PIN51	P76 DIG OUT	MTIOC4D_UP51	PWM1_WL
	//PORT7.DR.BIT.B5=0;			// PIN52	P75 DIG OUT	MTIOC4C_UP52	PWM1_VL
	//PORT7.DR.BIT.B4=0;			// PIN53	P74 DIG OUT	MTIOC3D_UP53	PWM1_UL
	//PORT7.DR.BIT.B3=0;			// PIN54	P73 DIG OUT	MTIOC4B_UP54	PWM1_WH
	//PORT7.DR.BIT.B2=0;			// PIN55	P72 DIG OUT	MTIOC4A_UP55	PWM1_VH
	//PORT7.DR.BIT.B1=0;			// PIN56	P71 DIG OUT	MTIOC3B_UP56	PWM1_UH
	//PORT7.DR.BIT.B0=1;			// PIN57	P70 DIG IN	POE0_UP57		OVCURR1

	PORT7.DDR.BYTE=0x7E;			// reset 0x00
		// B7
	//PORT7.DDR.BIT.B6=1;			// PIN51	P76 DIG OUT	MTIOC4D_UP51	PWM1_WL
	//PORT7.DDR.BIT.B5=1;			// PIN52	P75 DIG OUT	MTIOC4C_UP52	PWM1_VL
	//PORT7.DDR.BIT.B4=1;			// PIN53	P74 DIG OUT	MTIOC3D_UP53	PWM1_UL
	//PORT7.DDR.BIT.B3=1;			// PIN54	P73 DIG OUT	MTIOC4B_UP54	PWM1_WH
	//PORT7.DDR.BIT.B2=1;			// PIN55	P72 DIG OUT	MTIOC4A_UP55	PWM1_VH
	//PORT7.DDR.BIT.B1=1;			// PIN56	P71 DIG OUT	MTIOC3B_UP56	PWM1_UH
	//PORT7.DDR.BIT.B0=0;			// PIN57	P70 DIG IN	POE0_UP57		OVCURR1

	// again for safety
	PORT7.DR.BYTE=0x01;
	//PORT7.DR.BYTE=0x71;			// low drives on @reset

	//PORT7.PORT.BYTE				// reset undefined
		// B7
	//PORT7.PORT.BIT.B6				// PIN51	P76 DIG OUT	MTIOC4D_UP51	PWM1_WL
	//PORT7.PORT.BIT.B5				// PIN52	P75 DIG OUT	MTIOC4C_UP52	PWM1_VL
	//PORT7.PORT.BIT.B4				// PIN53	P74 DIG OUT	MTIOC3D_UP53	PWM1_UL
	//PORT7.PORT.BIT.B3				// PIN54	P73 DIG OUT	MTIOC4B_UP54	PWM1_WH
	//PORT7.PORT.BIT.B2				// PIN55	P72 DIG OUT	MTIOC4A_UP55	PWM1_VH
	//PORT7.PORT.BIT.B1				// PIN56	P71 DIG OUT	MTIOC3B_UP56	PWM1_UH
	//PORT7.PORT.BIT.B0				// PIN57	P70 DIG IN	POE0_UP57		OVCURR1

	PORT7.ICR.BYTE=0x01;			// reset 0x00
		// B7
	//PORT7.ICR.BIT.B6=0;			// PIN51	P76 DIG OUT	MTIOC4D_UP51	PWM1_WL
	//PORT7.ICR.BIT.B5=0;			// PIN52	P75 DIG OUT	MTIOC4C_UP52	PWM1_VL
	//PORT7.ICR.BIT.B4=0;			// PIN53	P74 DIG OUT	MTIOC3D_UP53	PWM1_UL
	//PORT7.ICR.BIT.B3=0;			// PIN54	P73 DIG OUT	MTIOC4B_UP54	PWM1_WH
	//PORT7.ICR.BIT.B2=0;			// PIN55	P72 DIG OUT	MTIOC4A_UP55	PWM1_VH
	//PORT7.ICR.BIT.B1=0;			// PIN56	P71 DIG OUT	MTIOC3B_UP56	PWM1_UH
	//PORT7.ICR.BIT.B0=1;			// PIN57	P70 DIG IN	POE0_UP57		OVCURR1


	/*** Port 8 ***/

	//PORT8.DR.BYTE=0x00;			// reset 0x00
		// B7, .., B3
	//PORT8.DR.BIT.B2=0;			// PIN96	P82 DIG IN	MTIC5U_UP96		DEAD_U1
	//PORT8.DR.BIT.B1=0;			// PIN97	P81 DIG IN	MTIC5V_UP97		DEAD_V1
	//PORT8.DR.BIT.B0=0;			// PIN98	P80 DIG IN	MTIC5W_UP98		DEAD_W1

	//PORT8.DDR.BYTE=0x00;			// reset 0x00
		// B7, .., B3
	//PORT8.DDR.BIT.B2=0;			// PIN96	P82 DIG IN	MTIC5U_UP96		DEAD_U1
	//PORT8.DDR.BIT.B1=0;			// PIN97	P81 DIG IN	MTIC5V_UP97		DEAD_V1
	//PORT8.DDR.BIT.B0=0;			// PIN98	P80 DIG IN	MTIC5W_UP98		DEAD_W1

	//PORT8.PORT.BYTE				// reset undefined
		// B7, .., B3
	//PORT8.PORT.BIT.B2				// PIN96	P82 DIG IN	MTIC5U_UP96		DEAD_U1
	//PORT8.PORT.BIT.B1				// PIN97	P81 DIG IN	MTIC5V_UP97		DEAD_V1
	//PORT8.PORT.BIT.B0				// PIN98	P80 DIG IN	MTIC5W_UP98		DEAD_W1

	PORT8.ICR.BYTE=0x07;			// reset 0x00
		// B7, .., B3
	//PORT8.ICR.BIT.B2=1;			// PIN96	P82 DIG IN	MTIC5U_UP96		DEAD_U1
	//PORT8.ICR.BIT.B1=1;			// PIN97	P81 DIG IN	MTIC5V_UP97		DEAD_V1
	//PORT8.ICR.BIT.B0=1;			// PIN98	P80 DIG IN	MTIC5W_UP98		DEAD_W1


	/*** Port 9 ***/

	// WARNING: PWM ACTIVE LEVEL IS LOW

	PORT9.DR.BYTE=0x7F;				// reset 0x00
		// B7
	//PORT9.DR.BIT.B6=1;			// PIN43	P96 DIG IN	POE4_UP43		OVCURR
	//PORT9.DR.BIT.B5=1;			// PIN45	P95 DIG OUT	MTIOC6B_UP45	PWM_UH
	//PORT9.DR.BIT.B4=1;			// PIN46	P94 DIG OUT	MTIOC7A_UP46	PWM_VH
	//PORT9.DR.BIT.B3=1;			// PIN47	P93 DIG OUT	MTIOC7B_UP47	PWM_WH
	//PORT9.DR.BIT.B2=1;			// PIN48	P92 DIG OUT	MTIOC6D_UP48	PWM_UL
	//PORT9.DR.BIT.B1=1;			// PIN49	P91 DIG OUT	MTIOC7C_UP49	PWM_VL
	//PORT9.DR.BIT.B0=1;			// PIN50	P90 DIG OUT	MTIOC7D_UP50	PWM_WL

	PORT9.DDR.BYTE=0x3F;			// reset 0x00
		// B7
	//PORT9.DDR.BIT.B6=0;			// PIN43	P96 DIG IN	POE4_UP43		OVCURR
	//PORT9.DDR.BIT.B5=1;			// PIN45	P95 DIG OUT	MTIOC6B_UP45	PWM_UH
	//PORT9.DDR.BIT.B4=1;			// PIN46	P94 DIG OUT	MTIOC7A_UP46	PWM_VH
	//PORT9.DDR.BIT.B3=1;			// PIN47	P93 DIG OUT	MTIOC7B_UP47	PWM_WH
	//PORT9.DDR.BIT.B2=1;			// PIN48	P92 DIG OUT	MTIOC6D_UP48	PWM_UL
	//PORT9.DDR.BIT.B1=1;			// PIN49	P91 DIG OUT	MTIOC7C_UP49	PWM_VL
	//PORT9.DDR.BIT.B0=1;			// PIN50	P90 DIG OUT	MTIOC7D_UP50	PWM_WL

	// again for safety
	PORT9.DR.BYTE=0x7F;

	//PORT9.PORT.BYTE				// reset undefined
		// B7
	//PORT9.PORT.BIT.B6				// PIN43	P96 DIG IN	POE4_UP43		OVCURR
	//PORT9.PORT.BIT.B5				// PIN45	P95 DIG OUT	MTIOC6B_UP45	PWM_UH
	//PORT9.PORT.BIT.B4				// PIN46	P94 DIG OUT	MTIOC7A_UP46	PWM_VH
	//PORT9.PORT.BIT.B3				// PIN47	P93 DIG OUT	MTIOC7B_UP47	PWM_WH
	//PORT9.PORT.BIT.B2				// PIN48	P92 DIG OUT	MTIOC6D_UP48	PWM_UL
	//PORT9.PORT.BIT.B1				// PIN49	P91 DIG OUT	MTIOC7C_UP49	PWM_VL
	//PORT9.PORT.BIT.B0				// PIN50	P90 DIG OUT	MTIOC7D_UP50	PWM_WL

	PORT9.ICR.BYTE=0x40;			// reset 0x00
		// B7
	//PORT9.ICR.BIT.B6=1;			// PIN43	P96 DIG IN	POE4_UP43		OVCURR
	//PORT9.ICR.BIT.B5=0;			// PIN45	P95 DIG OUT	MTIOC6B_UP45	PWM_UH
	//PORT9.ICR.BIT.B4=0;			// PIN46	P94 DIG OUT	MTIOC7A_UP46	PWM_VH
	//PORT9.ICR.BIT.B3=0;			// PIN47	P93 DIG OUT	MTIOC7B_UP47	PWM_WH
	//PORT9.ICR.BIT.B2=0;			// PIN48	P92 DIG OUT	MTIOC6D_UP48	PWM_UL
	//PORT9.ICR.BIT.B1=0;			// PIN49	P91 DIG OUT	MTIOC7C_UP49	PWM_VL
	//PORT9.ICR.BIT.B0=0;			// PIN50	P90 DIG OUT	MTIOC7D_UP50	PWM_WL


	/*** Port A ***/

	PORTA.DR.BYTE=0x00;				// reset 0x00
		// B7, B6
	//PORTA.DR.BIT.B5=0;			// PIN36	PA5 DIG OUT MTIOC1A_UP36	DEB_PWM2
	//PORTA.DR.BIT.B4=0;			// PIN37	PA4 DIG OUT MTIOC1B_UP37	DEB_PWM3
	//PORTA.DR.BIT.B3=0;			// PIN38	PA3 DIG IN	X
	//PORTA.DR.BIT.B2=0;			// PIN39	PA2 DIG IN	X
	//PORTA.DR.BIT.B1=0;			// PIN40	PA1 DIG IN	X
	//PORTA.DR.BIT.B0=0;			// PIN41	PA0 DIG IN	X

	PORTA.DDR.BYTE=0x30;			// reset 0x00
		// B7, B6
	//PORTA.DDR.BIT.B5=1;			// PIN36	PA5 DIG OUT MTIOC1A_UP36	DEB_PWM2
	//PORTA.DDR.BIT.B4=1;			// PIN37	PA4 DIG OUT MTIOC1B_UP37	DEB_PWM3
	//PORTA.DDR.BIT.B3=0;			// PIN38	PA3 DIG IN	X
	//PORTA.DDR.BIT.B2=0;			// PIN39	PA2 DIG IN	X
	//PORTA.DDR.BIT.B1=0;			// PIN40	PA1 DIG IN	X
	//PORTA.DDR.BIT.B0=0;			// PIN41	PA0 DIG IN	X

	//PORTA.PORT.BYTE;				// reset undefined
		// B7, B6
	//PORTA.PORT.BIT.B5				// PIN36	PA5 DIG OUT MTIOC1A_UP36	DEB_PWM2
	//PORTA.PORT.BIT.B4				// PIN37	PA4 DIG OUT MTIOC1B_UP37	DEB_PWM3
	//PORTA.PORT.BIT.B3				// PIN38	PA3 DIG IN	X
	//PORTA.PORT.BIT.B2				// PIN39	PA2 DIG IN	X
	//PORTA.PORT.BIT.B1				// PIN40	PA1 DIG IN	X
	//PORTA.PORT.BIT.B0				// PIN41	PA0 DIG IN	X

	//PORTA.ICR.BYTE=0x00;			// reset 0x00
		// B7, B6
	//PORTA.ICR.BIT.B5=0;			// PIN36	PA5 DIG OUT MTIOC1A_UP36	DEB_PWM2
	//PORTA.ICR.BIT.B4=0;			// PIN37	PA4 DIG OUT MTIOC1B_UP37	DEB_PWM3
	//PORTA.ICR.BIT.B3=0;			// PIN38	PA3 DIG IN	X
	//PORTA.ICR.BIT.B2=0;			// PIN39	PA2 DIG IN	X
	//PORTA.ICR.BIT.B1=0;			// PIN40	PA1 DIG IN	X
	//PORTA.ICR.BIT.B0=0;			// PIN41	PA0 DIG IN	X


	/*** Port B ***/

	PORTB.DR.BYTE=0x60;				// reset 0x00
	//PORTB.DR.BIT.B7=0;			// PIN26	PB7 DIG IN	X
	//PORTB.DR.BIT.B6=1;			// PIN27	PB6 DIG IN	RXD2_UP27		RX
	//PORTB.DR.BIT.B5=1;			// PIN28	PB5 DIG OUT	TXD2_UP28		TX
	//PORTB.DR.BIT.B4=0;			// PIN30	PB4 DIG IN	X
	//PORTB.DR.BIT.B3=0;			// PIN32	PB3 DIG IN	MTIOC0A_UP32	HALL_A
	//PORTB.DR.BIT.B2=0;			// PIN33	PB2 DIG IN	MTIOC0B_UP33	HALL_B
	//PORTB.DR.BIT.B1=0;			// PIN34	PB1 DIG IN	MTIOC0C_UP34	HALL_C
	//PORTB.DR.BIT.B0=0;			// PIN35	PB0 DIG OUT MTIOC0D_UP35	DEB_PWM1

	PORTB.DDR.BYTE=0x21;			// reset 0x00
	//PORTB.DDR.BIT.B7=0;			// PIN26	PB7 DIG IN	X
	//PORTB.DDR.BIT.B6=0;			// PIN27	PB6 DIG IN	RXD2_UP27		RX
	//PORTB.DDR.BIT.B5=1;			// PIN28	PB5 DIG OUT	TXD2_UP28		TX
	//PORTB.DDR.BIT.B4=0;			// PIN30	PB4 DIG IN	X
	//PORTB.DDR.BIT.B3=0;			// PIN32	PB3 DIG IN	MTIOC0A_UP32	HALL_A
	//PORTB.DDR.BIT.B2=0;			// PIN33	PB2 DIG IN	MTIOC0B_UP33	HALL_B
	//PORTB.DDR.BIT.B1=0;			// PIN34	PB1 DIG IN	MTIOC0C_UP34	HALL_C
	//PORTB.DDR.BIT.B0=1;			// PIN35	PB0 DIG OUT MTIOC0D_UP35	DEB_PWM1

	//PORTB.PORT.BYTE				// reset undefined
	//PORTB.PORT.BIT.B7				// PIN26	PB7 DIG IN	X
	//PORTB.PORT.BIT.B6				// PIN27	PB6 DIG IN	RXD2_UP27		RX
	//PORTB.PORT.BIT.B5				// PIN28	PB5 DIG OUT	TXD2_UP28		TX
	//PORTB.PORT.BIT.B4				// PIN30	PB4 DIG IN	X
	//PORTB.PORT.BIT.B3				// PIN32	PB3 DIG IN	MTIOC0A_UP32	HALL_A
	//PORTB.PORT.BIT.B2				// PIN33	PB2 DIG IN	MTIOC0B_UP33	HALL_B
	//PORTB.PORT.BIT.B1				// PIN34	PB1 DIG IN	MTIOC0C_UP34	HALL_C
	//PORTB.PORT.BIT.B0				// PIN35	PB0 DIG OUT MTIOC0D_UP35	DEB_PWM1

	PORTB.ICR.BYTE=0x4E;			// reset 0x00
	//PORTB.ICR.BIT.B7=0;			// PIN26	PB7 DIG IN	X
	//PORTB.ICR.BIT.B6=1;			// PIN27	PB6 DIG IN	RXD2_UP27		RX
	//PORTB.ICR.BIT.B5=0;			// PIN28	PB5 DIG OUT	TXD2_UP28		TX
	//PORTB.ICR.BIT.B4=0;			// PIN30	PB4 DIG IN	X
	//PORTB.ICR.BIT.B3=1;			// PIN32	PB3 DIG IN	MTIOC0A_UP32	HALL_A
	//PORTB.ICR.BIT.B2=1;			// PIN33	PB2 DIG IN	MTIOC0B_UP33	HALL_B
	//PORTB.ICR.BIT.B1=1;			// PIN34	PB1 DIG IN	MTIOC0C_UP34	HALL_C
	//PORTB.ICR.BIT.B0=0;			// PIN35	PB0 DIG OUT MTIOC0D_UP35	DEB_PWM1


	/*** Port D ***/

	//PORTD.DR.BYTE=0x00;			// reset 0x00
	//PORTD.DR.BIT.B7=0;			// PIN18	PD7 E1 IN	TRST_UP18
	//PORTD.DR.BIT.B6=0;			// PIN19	PD6 E1 IN	TMS_UP19
	//PORTD.DR.BIT.B5=0;			// PIN20	PD5 E1 IN	TDI_UP20
	//PORTD.DR.BIT.B4=0;			// PIN21	PD4 E1 IN	TCK_UP21
	//PORTD.DR.BIT.B3=0;			// PIN22	PD3 E1 OUT	TDO_UP22
	//PORTD.DR.BIT.B2=0;			// PIN23	PD2 DIG IN	X
	//PORTD.DR.BIT.B1=0;			// PIN24	PD1 DIG IN	X
	//PORTD.DR.BIT.B0=0;			// PIN25	PD0 DIG IN	X

	//PORTD.DDR.BYTE=0x00;			// reset 0x00
	//PORTD.DDR.BIT.B7=0;			// PIN18	PD7 E1 IN	TRST_UP18
	//PORTD.DDR.BIT.B6=0;			// PIN19	PD6 E1 IN	TMS_UP19
	//PORTD.DDR.BIT.B5=0;			// PIN20	PD5 E1 IN	TDI_UP20
	//PORTD.DDR.BIT.B4=0;			// PIN21	PD4 E1 IN	TCK_UP21
	//PORTD.DDR.BIT.B3=0;			// PIN22	PD3 E1 OUT	TDO_UP22
	//PORTD.DDR.BIT.B2=0;			// PIN23	PD2 DIG IN	X
	//PORTD.DDR.BIT.B1=0;			// PIN24	PD1 DIG IN	X
	//PORTD.DDR.BIT.B0=0;			// PIN25	PD0 DIG IN	X

	//PORTD.PORT.BYTE				// reset undefined
	//PORTD.PORT.BIT.B7				// PIN18	PD7 E1 IN	TRST_UP18
	//PORTD.PORT.BIT.B6				// PIN19	PD6 E1 IN	TMS_UP19
	//PORTD.PORT.BIT.B5				// PIN20	PD5 E1 IN	TDI_UP20
	//PORTD.PORT.BIT.B4				// PIN21	PD4 E1 IN	TCK_UP21
	//PORTD.PORT.BIT.B3				// PIN22	PD3 E1 OUT	TDO_UP22
	//PORTD.PORT.BIT.B2				// PIN23	PD2 DIG IN	X
	//PORTD.PORT.BIT.B1				// PIN24	PD1 DIG IN	X
	//PORTD.PORT.BIT.B0				// PIN25	PD0 DIG IN	X

	//PORTD.ICR.BYTE=0x00;			// reset 0x00
	//PORTD.ICR.BIT.B7=0;			// PIN18	PD7 E1 IN	TRST_UP18
	//PORTD.ICR.BIT.B6=0;			// PIN19	PD6 E1 IN	TMS_UP19
	//PORTD.ICR.BIT.B5=0;			// PIN20	PD5 E1 IN	TDI_UP20
	//PORTD.ICR.BIT.B4=0;			// PIN21	PD4 E1 IN	TCK_UP21
	//PORTD.ICR.BIT.B3=0;			// PIN22	PD3 E1 OUT	TDO_UP22
	//PORTD.ICR.BIT.B2=0;			// PIN23	PD2 DIG IN	X
	//PORTD.ICR.BIT.B1=0;			// PIN24	PD1 DIG IN	X
	//PORTD.ICR.BIT.B0=0;			// PIN25	PD0 DIG IN	X


	/*** Port E ***/

	//PORTE.DR.BYTE=0x00;			// reset 0x00
		// B7, B6
	//PORTE.DR.BIT.B5=0;			// PIN1		PE5 DIG IN	PE5_UP1			EXT_SUP_ON
	//PORTE.DR.BIT.B4=0;			// PIN8		PE4 DIG IN	X
	//PORTE.DR.BIT.B3=0;			// PIN9		PE3 DIG IN	X
	//PORTE.DR.BIT.B2=0;			// PIN15	PE2 DIG IN	NMI_UP15
	//PORTE.DR.BIT.B1=0;			// PIN16	PE1 DIG OUT	EEPSCL_UP16
	//PORTE.DR.BIT.B0=0;			// PIN17	PE0 DIG I/O EEPSDA_UP17

	//PORTE.DDR.BYTE=0x00;			// reset 0x00
		// B7, B6
	//PORTE.DDR.BIT.B5=0;			// PIN1		PE5 DIG IN	PE5_UP1			EXT_SUP_ON
	//PORTE.DDR.BIT.B4=0;			// PIN8		PE4 DIG IN	X
	//PORTE.DDR.BIT.B3=0;			// PIN9		PE3 DIG IN	X
	//PORTE.DDR.BIT.B2=0;			// PIN15	PE2 DIG IN	NMI_UP15
	//PORTE.DDR.BIT.B1=0;			// PIN16	PE1 DIG OUT	EEPSCL_UP16
	//PORTE.DDR.BIT.B0=0;			// PIN17	PE0 DIG I/O EEPSDA_UP17

	//PORTE.PORT.BYTE				// reset 0x00
		// B7, B6
	//PORTE.PORT.BIT.B5				// PIN1		PE5 DIG IN	PE5_UP1			EXT_SUP_ON
	//PORTE.PORT.BIT.B4				// PIN8		PE4 DIG IN	X
	//PORTE.PORT.BIT.B3				// PIN9		PE3 DIG IN	X
	//PORTE.PORT.BIT.B2				// PIN15	PE2 DIG IN	NMI_UP15
	//PORTE.PORT.BIT.B1				// PIN16	PE1 DIG OUT	EEPSCL_UP16
	//PORTE.PORT.BIT.B0				// PIN17	PE0 DIG I/O EEPSDA_UP17

	//PORTE.ICR.BYTE=0x00;			// reset 0x00
		// B7, B6
	//PORTE.ICR.BIT.B5=0;			// PIN1		PE5 DIG IN	PE5_UP1			EXT_SUP_ON
	//PORTE.ICR.BIT.B4=0;			// PIN8		PE4 DIG IN	X
	//PORTE.ICR.BIT.B3=0;			// PIN9		PE3 DIG IN	X
	//PORTE.ICR.BIT.B2=0;			// PIN15	PE2 DIG IN	NMI_UP15
	//PORTE.ICR.BIT.B1=0;			// PIN16	PE1 DIG OUT	EEPSCL_UP16
	//PORTE.ICR.BIT.B0=0;			// PIN17	PE0 DIG I/O EEPSDA_UP17


	/*** 12bit A/D Converter common registers (S12AD) ***/

	//S12AD.ADCMPMD0.WORD=0x0000;	// reset 0x0000
									// B15, B14
	//S12AD.ADCMPMD0.BIT.CEN102=0;	// B13, B12
	//S12AD.ADCMPMD0.BIT.CEN101=0;	// B11, B10
	//S12AD.ADCMPMD0.BIT.CEN100=0;	// B9, B8
									// B7, B6
	//S12AD.ADCMPMD0.BIT.CEN002=0;	// B5, B4
	//S12AD.ADCMPMD0.BIT.CEN001=0;	// B3, B2
	//S12AD.ADCMPMD0.BIT.CEN000=0;	// B1, B0

	//S12AD.ADCMPMD1.WORD=0x0000;	// reset 0x0000
									// B15
	//S12AD.ADCMPMD1.BIT.VSELL1=0;	// B14
	//S12AD.ADCMPMD1.BIT.VSELH1=0;	// B13
	//S12AD.ADCMPMD1.BIT.CSEL1=0;	// B12
									// B11
	//S12AD.ADCMPMD1.BIT.VSELL0=0;	// B10
	//S12AD.ADCMPMD1.BIT.VSELH0=0;	// B9
	//S12AD.ADCMPMD1.BIT.CSEL0=0;	// B8
									// B7
	//S12AD.ADCMPMD1.BIT.REFH=0;	// B6, .., B4
									// B3
	//S12AD.ADCMPMD1.BIT.REFL=0;	// B2, .., B0

	//S12AD.ADCMPNR0.WORD=0x0000;	// reset 0x0000
									// B15, .., B12
	//S12AD.ADCMPNR0.BIT.C002NR=0;	// B11, .., B8
	//S12AD.ADCMPNR0.BIT.C001NR=0;	// B7, .., B4
	//S12AD.ADCMPNR0.BIT.C000NR=0;	// B3, .., B0

	//S12AD.ADCMPNR1.WORD=0x0000;	// reset 0x0000
									// B15, .., B12
	//S12AD.ADCMPNR1.BIT.C102NR=0;	// B11, .., B8
	//S12AD.ADCMPNR1.BIT.C101NR=0;	// B7, .., B4
	//S12AD.ADCMPNR1.BIT.C100NR=0;	// B3, .., B0

	//S12AD.ADCMPFR.BYTE			// reset 0x00
									// B7, B6
	//S12AD.ADCMPFR.BIT.C102FLAG	// B5
	//S12AD.ADCMPFR.BIT.C101FLAG	// B4
	//S12AD.ADCMPFR.BIT.C100FLAG	// B3
	//S12AD.ADCMPFR.BIT.C002FLAG	// B2
	//S12AD.ADCMPFR.BIT.C001FLAG	// B1
	//S12AD.ADCMPFR.BIT.C000FLAG	// B0

	//S12AD.ADCMPSEL.WORD=0x0000;	// reset 0x0000
									// B15, .., B10
	//S12AD.ADCMPSEL.BIT.POE=0;		// B9
	//S12AD.ADCMPSEL.BIT.IE=0;		// B8
									// B7, B6
	//S12AD.ADCMPSEL.BIT.SEL102=0;	// B5
	//S12AD.ADCMPSEL.BIT.SEL101=0;	// B4
	//S12AD.ADCMPSEL.BIT.SEL100=0;	// B3
	//S12AD.ADCMPSEL.BIT.SEL002=0;	// B2
	//S12AD.ADCMPSEL.BIT.SEL001=0;	// B1
	//S12AD.ADCMPSEL.BIT.SEL000=0;	// B0


	/*** 12bit A/D Converter unit 0 registers (S12AD0) ***/

	//S12AD0.ADCSR.BYTE=0x00;		// reset 0x00
	//S12AD0.ADCSR.BIT.ADST=0;		// B7
	//S12AD0.ADCSR.BIT.ADCS=0;		// B6, B5
	//S12AD0.ADCSR.BIT.ADIE=0;		// B4
	//S12AD0.ADCSR.BIT.CKS=0;		// B3, B2
	//S12AD0.ADCSR.BIT.TRGE=0;		// B1
	//S12AD0.ADCSR.BIT.EXTRG=0;		// B0

	//S12AD0.ADANS.WORD=0x0000;		// reset 0x0000
									// B15, B14
	//S12AD0.ADANS.BIT.CH=0;		// B13
									// B12
	//S12AD0.ADANS.BIT.PG002SEL=0;	// B11
	//S12AD0.ADANS.BIT.PG001SEL=0;	// B10
	//S12AD0.ADANS.BIT.PG000SEL=0;	// B9
									// B8, .., B3
	//S12AD0.ADANS.BIT.PG002EN=0;	// B2
	//S12AD0.ADANS.BIT.PG001EN=0;	// B1
	//S12AD0.ADANS.BIT.PG000EN=0;	// B0

	//S12AD0.ADPG.WORD=0x0000;		// reset 0x0000
									// B15, .., B12
	//S12AD0.ADPG.BIT.PG002GAIN=0;	// B11, .., B8
	//S12AD0.ADPG.BIT.PG001GAIN=0;	// B7, .., B4
	//S12AD0.ADPG.BIT.PG000GAIN=0;	// B3, .., B0

	//S12AD0.ADCER.WORD=0x0000;		// reset 0x0000
	//S12AD0.ADCER.BIT.ADRFMT=0;	// B15
									// B14
	//S12AD0.ADCER.BIT.ADIEW=0;		// B13
	//S12AD0.ADCER.BIT.ADIE2=0;		// B12
	//S12AD0.ADCER.BIT.DIAGM=0;		// B11
	//S12AD0.ADCER.BIT.DIAGLD=0;	// B10
	//S12AD0.ADCER.BIT.DIAGVAL=0;	// B9, B8
									// B7, B6
	//S12AD0.ADCER.BIT.ACE=0;		// B5
									// B4, B3
	//S12AD0.ADCER.BIT.ADPRC=0;		// B2, B1
	//S12AD0.ADCER.BIT.SHBYP=0;		// B0

	//S12AD0.ADSTRGR.WORD=0x0000;	// reset 0x0000
									// B15, .., B13
	//S12AD0.ADSTRGR.BIT.ADSTRS1=0;	// B12, .., B8
									// B7, .., B5
	//S12AD0.ADSTRGR.BIT.ADSTRS0=0;	// B4, .., B0

	//S12AD0.ADRD.WORD				// data diagnostic register
	//S12AD0.ADDR0A.WORD			// data register 0 A
	//S12AD0.ADDR0B.WORD			// data register 0 B
	//S12AD0.ADDR1.WORD				// data register 1
	//S12AD0.ADDR2.WORD				// data register 2
	//S12AD0.ADDR3.WORD				// data register 3


	/*** 12bit A/D Converter unit 1 registers (S12AD1) ***/

	//S12AD1.ADCSR.BYTE=0x00;		// reset 0x00
	//S12AD1.ADCSR.BIT.ADST=0;		// B7
	//S12AD1.ADCSR.BIT.ADCS=0;		// B6, B5
	//S12AD1.ADCSR.BIT.ADIE=0;		// B4
	//S12AD1.ADCSR.BIT.CKS=0;		// B3, B2
	//S12AD1.ADCSR.BIT.TRGE=0;		// B1
	//S12AD1.ADCSR.BIT.EXTRG=0;		// B0

	//S12AD1.ADANS.WORD=0x0000;		// reset 0x0000
									// B15, B14
	//S12AD1.ADANS.BIT.CH=0;		// B13
									// B12
	//S12AD1.ADANS.BIT.PG002SEL=0;	// B11
	//S12AD1.ADANS.BIT.PG001SEL=0;	// B10
	//S12AD1.ADANS.BIT.PG000SEL=0;	// B9
									// B8, .., B3
	//S12AD1.ADANS.BIT.PG002EN=0;	// B2
	//S12AD1.ADANS.BIT.PG001EN=0;	// B1
	//S12AD1.ADANS.BIT.PG000EN=0;	// B0

	//S12AD1.ADPG.WORD=0x0000;		// reset 0x0000
									// B15, .., B12
	//S12AD1.ADPG.BIT.PG002GAIN=0;	// B11, .., B8
	//S12AD1.ADPG.BIT.PG001GAIN=0;	// B7, .., B4
	//S12AD1.ADPG.BIT.PG000GAIN=0;	// B3, .., B0

	//S12AD1.ADCER.WORD=0x0000;		// reset 0x0000
	//S12AD1.ADCER.BIT.ADRFMT=0;	// B15
									// B14
	//S12AD1.ADCER.BIT.ADIEW=0;		// B13
	//S12AD1.ADCER.BIT.ADIE2=0;		// B12
	//S12AD1.ADCER.BIT.DIAGM=0;		// B11
	//S12AD1.ADCER.BIT.DIAGLD=0;	// B10
	//S12AD1.ADCER.BIT.DIAGVAL=0;	// B9, B8
									// B7, B6
	//S12AD1.ADCER.BIT.ACE=0;		// B5
									// B4, B3
	//S12AD1.ADCER.BIT.ADPRC=0;		// B2, B1
	//S12AD1.ADCER.BIT.SHBYP=0;		// B0

	//S12AD1.ADSTRGR.WORD=0x0000;	// reset 0x0000
									// B15, .., B13
	//S12AD1.ADSTRGR.BIT.ADSTRS1=0;	// B12, .., B8
									// B7, .., B5
	//S12AD1.ADSTRGR.BIT.ADSTRS0=0;	// B4, .., B0

	//S12AD1.ADRD.WORD				// data diagnostic register
	//S12AD1.ADDR0A.WORD			// data register 0 A
	//S12AD1.ADDR0B.WORD			// data register 0 B
	//S12AD1.ADDR1.WORD				// data register 1
	//S12AD1.ADDR2.WORD				// data register 2
	//S12AD1.ADDR3.WORD				// data register 3


	/*** 10bit A/D Converter (AD0) ***/

	//AD0.ADCSR.BYTE=0x00;			// reset 0xX0
									// B7
	//AD0.ADCSR.BIT.ADIE=0;			// B6
	//AD0.ADCSR.BIT.ADST=0;			// B5
									// B4
	//AD0.ADCSR.BIT.CH=0;			// B3, .., B0

	//AD0.ADCR.BYTE=0x00;			// reset 0x00
									// B7, .., B4
	//AD0.ADCR.BIT.CKS=0;			// B3, B2
	//AD0.ADCR.BIT.MODE=0;			// B1, B0

	//AD0.ADSSTR=0x19;				// reset 0x19

	//AD0.ADDIAGR.BYTE=0x00;		// reset 0x00
									// B7, .., B2
	//AD0.ADDIAGR.BIT.DIAG=0;		// B1, B0

	//AD0.ADSTRGR.BYTE=0x00;		// reset 0x00
									// B7, .., B5
	//AD0.ADSTRGR.BIT.DIAG=0;		// B4, B0

	//AD0.ADDPR.BYTE=0x00;			// reset 0x00
	//AD0.ADDPR.BIT.DPSEL=0;		// B7
									// B6, .., B1
	//AD0.ADDPR.BIT.DPPRC=0;		// B0

	//AD0.ADDRA						// data register A
	//AD0.ADDRB						// data register B
	//AD0.ADDRC						// data register C
	//AD0.ADDRD						// data register D
	//AD0.ADDRE						// data register E
	//AD0.ADDRF						// data register F
	//AD0.ADDRG						// data register G
	//AD0.ADDRH						// data register H
	//AD0.ADDRI						// data register I
	//AD0.ADDRJ						// data register J
	//AD0.ADDRK						// data register K
	//AD0.ADDRL						// data register L


	/*** Interrupt Controller ***/

	//ICU.IR[X].BYTE				// X= 0, .., 254	Interrupt source registers
									// B7, .., B1
	//ICU.IR[X].BIT.IR				// B0

	//ICU.DTCER[X].BYTE				// X= 0, .., 254	DTC activation registers
									// B7, .., B1
	//ICU.DTCER[X].BIT.DTCE			// B0

	//ICU.IER[X].BYTE				// X= 0, .., 31		Interrupt request enable registers
	//ICU.IER[X].BIT.IEN7			// B7
	//ICU.IER[X].BIT.IEN6			// B6
	//ICU.IER[X].BIT.IEN5			// B5
	//ICU.IER[X].BIT.IEN4			// B4
	//ICU.IER[X].BIT.IEN3			// B3
	//ICU.IER[X].BIT.IEN2			// B2
	//ICU.IER[X].BIT.IEN1			// B1
	//ICU.IER[X].BIT.IEN0			// B0

	//ICU.SWINTR.BYTE=0x00;			// Software Interrupt Activation Register (reset 0x00)
									// B7, .., B1
	//ICU.SWINTR.BIT.SWINT=0;		// B0

	//ICU.FIR.WORD=0x0000;			// Fast Interrupt Set Register (reset 0x0000)
	//ICU.FIR.BIT.FIEN=0;			// B15
									// B14, .., B8
	//ICU.FIR.BIT.FVCT=0;			// B7, .., B0

	//ICU.IPR[X].BYTE				// X= 0, .., 144	Interrupt source priority registers
									// B7, .., B4
	//ICU.IPR[X].BIT.IPR			// B3, .., B0

	//ICU.IRQCR[X].BYTE				// X= 0, .., 7		IRQ control registers
									// B7, .., B4
	//ICU.IRQCR[X].BIT.IRQMD		// B3, B2
									// B1, B0

	//ICU.NMISR.BYTE=0x00;			// reset 0x00
									// B7, .., B3
	//ICU.NMISR.BIT.OSTST=0;		// B2
	//ICU.NMISR.BIT.LVDST=0;		// B1
	//ICU.NMISR.BIT.NMIST=0;		// B0

	//ICU.NMIER.BYTE=0x00;			// reset 0x00
									// B7, .., B3
	//ICU.NMIER.BIT.OSTEN=0;		// B2
	//ICU.NMIER.BIT.LVDEN=0;		// B1
	//ICU.NMIER.BIT.NMIEN=0;		// B0

	//ICU.NMICLR.BYTE=0x00;			// reset 0x00
									// B7, .., B3
	//ICU.NMICLR.BIT.OSTCLR=0;		// B2
									// B1
	//ICU.NMICLR.BIT.NMICLR=0;		// B0

	//ICU.NMICR.BYTE=0x00;			// reset 0x00
									// B7, .., B4
	//ICU.NMICR.BIT.NMIMD=0;		// B3
									// B0, .., B2


	/*** Multi-function Timer Unit (general) ***/

	//MTU.TGCRA.BYTE=0x80;			// Timer Gate Control Register (Reset val 0x80)
	//MTU.TGCRA.BIT.BDC=0;			// B6
	//MTU.TGCRA.BIT.N=0;			// B5
	//MTU.TGCRA.BIT.P=0;			// B4
	//MTU.TGCRA.BIT.FB=0;			// B3
	//MTU.TGCRA.BIT.WF=0;			// B2
	//MTU.TGCRA.BIT.VF=0;			// B1
	//MTU.TGCRA.BIT.UF=0;			// B0

	//MTU.TOERA.BYTE=0xC0;			// Timer Output Master Enable Register A (Reset val 0xC0)
	//MTU.TOERA.BIT.OE4D=0;			// B5
	//MTU.TOERA.BIT.OE4C=0;			// B4
	//MTU.TOERA.BIT.OE3D=0;			// B3
	//MTU.TOERA.BIT.OE4B=0;			// B2
	//MTU.TOERA.BIT.OE4A=0;			// B1
	//MTU.TOERA.BIT.OE3B=0;			// B0

	//MTU.TOERB.BYTE=0xC0;			// Timer Output Master Enable Register B (Reset val 0xC0)
	//MTU.TOERB.BIT.OE7D=0;			// B5
	//MTU.TOERB.BIT.OE7C=0;			// B4
	//MTU.TOERB.BIT.OE6D=0;			// B3
	//MTU.TOERB.BIT.OE7B=0;			// B2
	//MTU.TOERB.BIT.OE7A=0;			// B1
	//MTU.TOERB.BIT.OE6B=0;			// B0

	//MTU.TOCR1A.BYTE=0x00;			// Timer Output Control Register 1A (Reset val 0x00)
	//MTU.TOCR1A.BIT.PSYE=0;		// B6
	//MTU.TOCR1A.BIT.TOCL=0;		// B3
	//MTU.TOCR1A.BIT.TOCS=0;		// B2
	//MTU.TOCR1A.BIT.OLSN=0;		// B1
	//MTU.TOCR1A.BIT.OLSP=0;		// B0

	//MTU.TOCR1B.BYTE=0x00;			// Timer Output Control Register 1B (Reset val 0x00)
	//MTU.TOCR1B.BIT.PSYE=0;		// B6
	//MTU.TOCR1B.BIT.TOCL=0;		// B3
	//MTU.TOCR1B.BIT.TOCS=0;		// B2
	//MTU.TOCR1B.BIT.OLSN=0;		// B1
	//MTU.TOCR1B.BIT.OLSP=0;		// B0

	//MTU.TOCR2A.BYTE=0x00;			// Timer Output Control Register 2A (Reset val 0x00)
	//MTU.TOCR2A.BIT.BF=0;			// B7, B6
	//MTU.TOCR2A.BIT.OLS3N=0;		// B5
	//MTU.TOCR2A.BIT.OLS3P=0;		// B4
	//MTU.TOCR2A.BIT.OLS2N=0;		// B3
	//MTU.TOCR2A.BIT.OLS2P=0;		// B2
	//MTU.TOCR2A.BIT.OLS1N=0;		// B1
	//MTU.TOCR2A.BIT.OLS1P=0;		// B0

	//MTU.TOCR2B.BYTE=0x00;			// Timer Output Control Register 2B (Reset val 0x00)
	//MTU.TOCR2B.BIT.BF=0;			// B7, B6
	//MTU.TOCR2B.BIT.OLS3N=0;		// B5
	//MTU.TOCR2B.BIT.OLS3P=0;		// B4
	//MTU.TOCR2B.BIT.OLS2N=0;		// B3
	//MTU.TOCR2B.BIT.OLS2P=0;		// B2
	//MTU.TOCR2B.BIT.OLS1N=0;		// B1
	//MTU.TOCR2B.BIT.OLS1P=0;		// B0

	//MTU.TCDRA=0xFFFF;				// Timer Cycle Data Register A (Reset val 0xFFFF)

	//MTU.TCDRB=0xFFFF;				// Timer Cycle Data Register B (Reset val 0xFFFF)

	//MTU.TDDRA=0xFFFF;				// Timer Dead Time Data Register A (Reset val 0xFFFF)

	//MTU.TDDRB=0xFFFF;				// Timer Dead Time Data Register B (Reset val 0xFFFF)

	//MTU.TCNTSA=0x0000;			// Timer Subcounter A (Reset val 0x0000)

	//MTU.TCNTSB=0x0000;			// Timer Subcounter B (Reset val 0x0000)

	//MTU.TCBRA=0xFFFF;				// Timer Cycle Buffer Register A (Reset val 0xFFFF)

	//MTU.TCBRB=0xFFFF;				// Timer Cycle Buffer Register B (Reset val 0xFFFF)

	//MTU.TITCR1A.BYTE=0x00;		// Timer Interrupt Skipping Set Register 1A (Reset val 0x00)
	//MTU.TITCR1A.BIT.T3AEN=0;		// B7
	//MTU.TITCR1A.BIT.T3ACOR=0;		// B6, B5, B4
	//MTU.TITCR1A.BIT.T4VEN=0;		// B3
	//MTU.TITCR1A.BIT.T4VCOR=0;		// B2,B1, B0

	//MTU.TITCR1B.BYTE=0x00;		// Timer Interrupt Skipping Set Register 1B (Reset val 0x00)
	//MTU.TITCR1B.BIT.T6AEN=0;		// B7
	//MTU.TITCR1B.BIT.T6ACOR=0;		// B6, B5, B4
	//MTU.TITCR1B.BIT.T7VEN=0;		// B3
	//MTU.TITCR1B.BIT.T7VCOR=0;		// B2,B1, B0

	//MTU.TITCNT1A.BYTE=0x00;		// Timer Interrupt Skipping Counter 1A (Reset val 0x00)
	//MTU.TITCNT1A.BIT.T3ACNT=0;	// B6, B5, B4
	//MTU.TITCNT1A.BIT.T4VCNT=0;	// B2, B1, B0

	//MTU.TITCNT1B.BYTE=0x00;		// Timer Interrupt Skipping Counter 1B (Reset val 0x00)
	//MTU.TITCNT1B.BIT.T6ACNT=0;	// B6, B5, B4
	//MTU.TITCNT1B.BIT.T7VCNT=0;	// B2, B1, B0

	//MTU.TBTERA.BYTE=0x00;			// Timer Buffer Transfer Set Register A (Reset val 0x00)
	//MTU.TBTERA.BIT.BTE=0;			// B1, B0

	//MTU.TBTERB.BYTE=0x00;			// Timer Buffer Transfer Set Register B (Reset val 0x00)
	//MTU.TBTERB.BIT.BTE=0;			// B1, B0

	//MTU.TDERA.BYTE=0x01;			// Timer Dead Time Enable Register A (Reset val 0x01)
	//MTU.TDERA.BIT.TDER=1;			// B0

	//MTU.TDERB.BYTE=0x01;			// Timer Dead Time Enable Register B (Reset val 0x01)
	//MTU.TDERB.BIT.TDER=1;			// B0

	//MTU.TOLBRA.BYTE=0x00;			// Timer Output Level Buffer Register A (Reset val 0x00)
	//MTU.TOLBRA.BIT.OLS3N=0;		// B5
	//MTU.TOLBRA.BIT.OLS3P=0;		// B4
	//MTU.TOLBRA.BIT.OLS2N=0;		// B3
	//MTU.TOLBRA.BIT.OLS2P=0;		// B2
	//MTU.TOLBRA.BIT.OLS1N=0;		// B1
	//MTU.TOLBRA.BIT.OLS1P=0;		// B0

	//MTU.TOLBRB.BYTE=0x00;			// Timer Output Level Buffer Register B (Reset val 0x00)
	//MTU.TOLBRB.BIT.OLS3N=0;		// B5
	//MTU.TOLBRB.BIT.OLS3P=0;		// B4
	//MTU.TOLBRB.BIT.OLS2N=0;		// B3
	//MTU.TOLBRB.BIT.OLS2P=0;		// B2
	//MTU.TOLBRB.BIT.OLS1N=0;		// B1
	//MTU.TOLBRB.BIT.OLS1P=0;		// B0

	//MTU.TITMRA.BYTE=0x00;			// Timer interrupt skipping mode register A (Reset val 0x00)
	//MTU.TITMRA.BIT.TITM=0;		// B0

	//MTU.TITMRB.BYTE=0x00;			// Timer interrupt skipping mode register B (Reset val 0x00)
	//MTU.TITMRB.BIT.TITM=0;		// B0

	//MTU.TITCR2A.BYTE=0x00;		// Timer Interrupt Skipping Set Register 2A (Reset val 0x00)
	//MTU.TITCR2A.BIT.TRG4COR=0;	// B2, .., B0

	//MTU.TITCR2B.BYTE=0x00;		// Timer Interrupt Skipping Set Register 2B (Reset val 0x00)
	//MTU.TITCR2B.BIT.TRG7COR=0;	// B2, .., B0

	//MTU.TITCNT2A.BYTE=0x00;		// Timer Interrupt Skipping Counter 2A (Reset val 0x00)
	//MTU.TITCNT2A.BIT.TRG4CNT=0;	// B2, .., B0

	//MTU.TITCNT2B.BYTE=0x00;		// Timer Interrupt Skipping Counter 2B (Reset val 0x00)
	//MTU.TITCNT2B.BIT.TRG7CNT=0;	// B2, .., B0

	//MTU.TWCRA.BYTE=0x00;			// Timer Waveform Control Register A (Reset val 0x00)
	//MTU.TWCRA.BIT.CCE=0;			// B7
	//MTU.TWCRA.BIT.SCC=0;			// B1
	//MTU.TWCRA.BIT.WRE=0;			// B0

	//MTU.TWCRB.BYTE=0x00;			// Timer Waveform Control Register B (Reset val 0x00)
	//MTU.TWCRB.BIT.CCE=0;			// B7
	//MTU.TWCRB.BIT.SCC=0;			// B1
	//MTU.TWCRB.BIT.WRE=0;			// B0

	//MTU.TMDR2A.BYTE=0x00;			// Timer mode register 2A (Reset val 0x00)
	//MTU.TMDR2A.BIT.DRS=0;			// B0

	//MTU.TMDR2B.BYTE=0x00;			// Timer mode register 2B (Reset val 0x00)
	//MTU.TMDR2B.BIT.DRS=0;			// B0

	//MTU.TSTRA.BYTE=0x00;			// Timer Start Register A (Reset val 0x00)
	//MTU.TSTRA.BIT.CST4=0;			// B7
	//MTU.TSTRA.BIT.CST3=0;			// B6
	//MTU.TSTRA.BIT.CST2=0;			// B2
	//MTU.TSTRA.BIT.CST1=0;			// B1
	//MTU.TSTRA.BIT.CST0=0;			// B0

	//MTU.TSTRB.BYTE=0x00;			// Timer Start Register B (Reset val 0x00)
	//MTU.TSTRB.BIT.CST7=0;			// B7
	//MTU.TSTRB.BIT.CST6=0;			// B6

	//MTU.TSYRA.BYTE=0x00;			// Timer Synchronous Register A (Reset val 0x00)
	//MTU.TSYRA.BIT.SYNC4=0;		// B7
	//MTU.TSYRA.BIT.SYNC3=0;		// B6
	//MTU.TSYRA.BIT.SYNC2=0;		// B2
	//MTU.TSYRA.BIT.SYNC1=0;		// B1
	//MTU.TSYRA.BIT.SYNC0=0;		// B0

	//MTU.TSYRB.BYTE=0x00;			// Timer Synchronous Register B (Reset val 0x00)
	//MTU.TSYRB.BIT.SYNC7=0;		// B7
	//MTU.TSYRB.BIT.SYNC6=0;		// B6

	//MTU.TRWERA.BYTE=0x00;			// Timer read/write Enable register A (Reset val 0x00)
	//MTU.TRWERA.BIT.RWE=0;			// B0

	//MTU.TRWERB.BYTE=0x01;			// Timer Read/Write Enable Register B (Reset val 0x01)
	//MTU.TRWERB.BIT.RWE=1;			// B0

	//MTU.TCSYSTR.BYTE=0x00;		// Timer Counter Synchronous Start Register (Reset val 0x00)
	//MTU.TCSYSTR.BIT.SCH0=0;		// B7
	//MTU.TCSYSTR.BIT.SCH1=0;		// B6
	//MTU.TCSYSTR.BIT.SCH2=0;		// B5
	//MTU.TCSYSTR.BIT.SCH3=0;		// B4
	//MTU.TCSYSTR.BIT.SCH4=0;		// B3
	//MTU.TCSYSTR.BIT.SCH6=0;		// B1
	//MTU.TCSYSTR.BIT.SCH7=0;		// B0


	/*** Multi-function Timer Unit (timer 0) ***/

	//MTU0.TCR.BYTE=0x00;			// Timer Control Register (Reset val 0x00)
	//MTU0.TCR.BIT.CCLR=0;			// B7, B6, B5
	//MTU0.TCR.BIT.CKEG=0;			// B4, B3
	//MTU0.TCR.BIT.TPSC=0;			// B2, B1, B0

	//MTU0.TMDR1.BYTE=0x00;			// Timer Mode Register 1 (Reset val 0x00)
	//MTU0.TMDR1.BIT.BFE=0;			// B6
	//MTU0.TMDR1.BIT.BFB=0;			// B5
	//MTU0.TMDR1.BIT.BFA=0;			// B4
	//MTU0.TMDR1.BIT.MD=0;			// B3, B2, B1, B0

	//MTU0.TIORH.BYTE=0x00;			// Timer I/O Control Register H (Reset val 0x00)
	//MTU0.TIORH.BIT.IOB=0;			// B7, B6, B5, B4
	//MTU0.TIORH.BIT.IOA=0;			// B3, B2, B1, B0

	//MTU0.TIORL.BYTE=0x00;			// Timer I/O Control Register L (Reset val 0x00)
	//MTU0.TIORL.BIT.IOD=0;			// B7, B6, B5, B4
	//MTU0.TIORL.BIT.IOC=0;			// B3, B2, B1, B0

	//MTU0.TIER.BYTE=0x00;			// Timer Interrupt Enable Register (Reset val 0x00)
	//MTU0.TIER.BIT.TTGE=0;			// B7
	//MTU0.TIER.BIT.TCIEV=0;		// B4
	//MTU0.TIER.BIT.TGIED=0;		// B3
	//MTU0.TIER.BIT.TGIEC=0;		// B2
	//MTU0.TIER.BIT.TGIEB=0;		// B1
	//MTU0.TIER.BIT.TGIEA=0;		// B0

	//MTU0.TSR.BYTE=0xC0;			// Timer Status Register (Reset val 0xC0)
	//MTU0.TSR.BIT.TCFV=0;			// B4
	//MTU0.TSR.BIT.TGFD=0;			// B3
	//MTU0.TSR.BIT.TGFC=0;			// B2
	//MTU0.TSR.BIT.TGFB=0;			// B1
	//MTU0.TSR.BIT.TGFA=0;			// B0

	//MTU0.TCNT=0x0000;				// Timer Counter (Reset val 0x0000)

	//MTU0.TGRA=0xFFFF;				// Timer General Register (Reset val 0xFFFF)

	//MTU0.TGRB=0xFFFF;				// Timer General Register (Reset val 0xFFFF)

	//MTU0.TGRC=0xFFFF;				// Timer General Register (Reset val 0xFFFF)

	//MTU0.TGRD=0xFFFF;				// Timer General Register (Reset val 0xFFFF)

	//MTU0.TGRE=0xFFFF;				// Timer General Register (Reset val 0xFFFF)

	//MTU0.TGRF=0xFFFF;				// Timer General Register (Reset val 0xFFFF)

	//MTU0.TIER2.BYTE=0x00;			// Timer Interrupt Enable Register (Reset val 0x00)
	//MTU0.TIER2.BIT.TTGE2=0;		// B7
	//MTU0.TIER2.BIT.TGIEF=0;		// B1
	//MTU0.TIER2.BIT.TGIEE=0;		// B0

	//MTU0.TSR2.BYTE0xC0;			// Timer Status Register (Reset val 0xC0)
	//MTU0.TSR2.BIT.TGFF=0;			// B1
	//MTU0.TSR2.BIT.TGFE=0;			// B0

	//MTU0.TBTM.BYTE=0x00;			// Timer Buffer Operation Transfer Mode Register (Reset val 0x00)
	//MTU0.TBTM.BIT.TTSE=0;			// B2
	//MTU0.TBTM.BIT.TTSB=0;			// B1
	//MTU0.TBTM.BIT.TTSA=0;			// B0


	/*** Multi-function Timer Unit (timer 1) ***/

	//MTU1.TCR.BYTE=0x00;			// Timer Control Register (Reset val 0x00)
	//MTU1.TCR.BIT.CCLR=0;			// B6, B5
	//MTU1.TCR.BIT.CKEG=0;			// B4, B3
	//MTU1.TCR.BIT.TPSC=0;			// B2, B1, B0

	//MTU1.TMDR1.BYTE=0x00;			// Timer Mode Register 1 (Reset val 0x00)
	//MTU1.TMDR1.BIT.MD=0;			// B3, B2, B1, B0

	//MTU1.TIOR.BYTE=0x00;			// Timer I/O Control Register (Reset val 0x00)
	//MTU1.TIOR.BIT.IOB=0;			// B7, B6, B5, B4
	//MTU1.TIOR.BIT.IOA=0;			// B3, B2, B1, B0

	//MTU1.TIER.BYTE=0x00;			// Timer Interrupt Enable Register (Reset val 0x00)
	//MTU1.TIER.BIT.TTGE=0;			// B7
	//MTU1.TIER.BIT.TCIEU=0;		// B5
	//MTU1.TIER.BIT.TCIEV=0;		// B4
	//MTU1.TIER.BIT.TGIEB=0;		// B1
	//MTU1.TIER.BIT.TGIEA=0;		// B0

	//MTU1.TSR.BYTE=0xC0;			// Timer Status Register (Reset val 0xC0)
	//MTU1.TSR.BIT.TCFD=0;			// B7
	//MTU1.TSR.BIT.TCFU=0;			// B5
	//MTU1.TSR.BIT.TCFV=0;			// B4
	//MTU1.TSR.BIT.TGFB=0;			// B1
	//MTU1.TSR.BIT.TGFA=0;			// B0

	//MTU1.TCNT=0x0000;				// Timer Counter (Reset val 0x0000)

	//MTU1.TGRA=0xFFFF;				// Timer General Register (Reset val 0xFFFF)

	//MTU1.TGRB=0xFFFF;				// Timer General Register (Reset val 0xFFFF)

	//MTU1.TICCR.BYTE=0x00;			// Timer Input Capture Control Register (Reset val 0x00)
	//MTU1.TICCR.BIT.I2BE=0;		// B3
	//MTU1.TICCR.BIT.I2AE=0;		// B2
	//MTU1.TICCR.BIT.I1BE=0;		// B1
	//MTU1.TICCR.BIT.I1AE=0;		// B0


	/*** Multi-function Timer Unit (timer 2) ***/

	//MTU2.TCR.BYTE=0x00;			// Timer Control Register (Reset val 0x00)
	//MTU2.TCR.BIT.CCLR=0;			// B6, B5
	//MTU2.TCR.BIT.CKEG=0;			// B4, B3
	//MTU2.TCR.BIT.TPSC=0;			// B2, B1, B0

	//MTU2.TMDR1.BYTE=0x00;			// Timer Mode Register 1 (Reset val 0x00)
	//MTU2.TMDR1.BIT.MD=0;			// B3, B2, B1, B0

	//MTU2.TIOR.BYTE=0x00;			// Timer I/O Control Register (Reset val 0x00)
	//MTU2.TIOR.BIT.IOB=0;			// B7, B6, B5, B4
	//MTU2.TIOR.BIT.IOA=0;			// B3, B2, B1, B0

	//MTU2.TIER.BYTE=0x00;			// Timer Interrupt Enable Register (Reset val 0x00)
	//MTU2.TIER.BIT.TTGE=0;			// B7
	//MTU2.TIER.BIT.TCIEU=0;		// B5
	//MTU2.TIER.BIT.TCIEV=0;		// B4
	//MTU2.TIER.BIT.TGIEB=0;		// B1
	//MTU2.TIER.BIT.TGIEA=0;		// B0

	//MTU2.TSR.BYTE=0xC0;			// Timer Status Register (Reset val 0xC0)
	//MTU2.TSR.BIT.TCFD=0;			// B7
	//MTU2.TSR.BIT.TCFU=0;			// B5
	//MTU2.TSR.BIT.TCFV=0;			// B4
	//MTU2.TSR.BIT.TGFB=0;			// B1
	//MTU2.TSR.BIT.TGFA=0;			// B0

	//MTU2.TCNT=0x0000;				// Timer Counter (Reset val 0x0000)

	//MTU2.TGRA=0xFFFF;				// Timer General Register (Reset val 0xFFFF)

	//MTU2.TGRB=0xFFFF;				// Timer General Register (Reset val 0xFFFF)


	/*** Multi-function Timer Unit (timer 3) ***/

	//MTU3.TCR.BYTE=0x00;			// Timer Control Register (Reset val 0x00)
	//MTU3.TCR.BIT.CCLR=0;			// B7, B6, B5
	//MTU3.TCR.BIT.CKEG=0;			// B4, B3
	//MTU3.TCR.BIT.TPSC=0;			// B2, B1, B0

	//MTU3.TMDR1.BYTE=0x00;			// Timer Mode Register 1 (Reset val 0x00)
	//MTU3.TMDR1.BIT.BFB=0;			// B5
	//MTU3.TMDR1.BIT.BFA=0;			// B4
	//MTU3.TMDR1.BIT.MD=0;			// B3, B2, B1, B0

	//MTU3.TIORH.BYTE=0x00;			// Timer I/O Control Register H (Reset val 0x00)
	//MTU3.TIORH.BIT.IOB=0;			// B7, B6, B5, B4
	//MTU3.TIORH.BIT.IOA=0;			// B3, B2, B1, B0

	//MTU3.TIORL.BYTE=0x00;			// Timer I/O Control Register L (Reset val 0x00)
	//MTU3.TIORL.BIT.IOD=0;			// B7, B6, B5, B4
	//MTU3.TIORL.BIT.IOC=0;			// B3, B2, B1, B0

	//MTU3.TIER.BYTE=0x00;			// Timer Interrupt Enable Register (Reset val 0x00)
	//MTU3.TIER.BIT.TTGE=0;			// B7
	//MTU3.TIER.BIT.TCIEV=0;		// B4
	//MTU3.TIER.BIT.TGIED=0;		// B3
	//MTU3.TIER.BIT.TGIEC=0;		// B2
	//MTU3.TIER.BIT.TGIEB=0;		// B1
	//MTU3.TIER.BIT.TGIEA=0;		// B0

	//MTU3.TCNT=0x0000;				// Timer Counter (Reset val 0x0000)

	//MTU3.TGRA=0xFFFF;				// Timer General Register (Reset val 0xFFFF)

	//MTU3.TGRB=0xFFFF;				// Timer General Register (Reset val 0xFFFF)

	//MTU3.TGRC=0xFFFF;				// Timer General Register (Reset val 0xFFFF)

	//MTU3.TGRD=0xFFFF;				// Timer General Register (Reset val 0xFFFF)

	//MTU3.TGRE=0xFFFF;				// Timer General Register (Reset val 0xFFFF)

	//MTU3.TSR.BYTE=0xC0;			// Timer Status Register (Reset val 0xC0)
	//MTU3.TSR.BIT.TCFD=0;			// B7
	//MTU3.TSR.BIT.TCFV=0;			// B4
	//MTU3.TSR.BIT.TGFD=0;			// B3
	//MTU3.TSR.BIT.TGFC=0;			// B2
	//MTU3.TSR.BIT.TGFB=0;			// B1
	//MTU3.TSR.BIT.TGFA=0;			// B0

	//MTU3.TBTM.BYTE=0x00;			// Timer Buffer Operation Transfer Mode Register (Reset val 0x00)
	//MTU3.TBTM.BIT.TTSB=0;			// B1
	//MTU3.TBTM.BIT.TTSA=0;			// B0


	/*** Multi-function Timer Unit (timer 4) ***/

	//MTU4.TCR.BYTE=0x00;			// Timer Control Register (Reset val 0x00)
	//MTU4.TCR.BIT.CCLR=0;			// B7, B6, B5
	//MTU4.TCR.BIT.CKEG=0;			// B4, B3
	//MTU4.TCR.BIT.TPSC=0;			// B2, B1, B0

	//MTU4.TMDR1.BYTE=0x00;			// Timer Mode Register 1 (Reset val 0x00)
	//MTU4.TMDR1.BIT.BFB=0;			// B5
	//MTU4.TMDR1.BIT.BFA=0;			// B4
	//MTU4.TMDR1.BIT.MD=0;			// B3, B2, B1, B0

	//MTU4.TIORH.BYTE=0x00;			// Timer I/O Control Register H (Reset val 0x00)
	//MTU4.TIORH.BIT.IOB=0;			// B7, B6, B5, B4
	//MTU4.TIORH.BIT.IOA=0;			// B3, B2, B1, B0

	//MTU4.TIORL.BYTE=0x00;			// Timer I/O Control Register L (Reset val 0x00)
	//MTU4.TIORL.BIT.IOD=0;			// B7, B6, B5, B4
	//MTU4.TIORL.BIT.IOC=0;			// B3, B2, B1, B0

	//MTU4.TIER.BYTE=0x00;			// Timer Interrupt Enable Register (Reset val 0x00)
	//MTU4.TIER.BIT.TTGE=0;			// B7
	//MTU4.TIER.BIT.TTGE2=0;		// B6
	//MTU4.TIER.BIT.TCIEV=0;		// B4
	//MTU4.TIER.BIT.TGIED=0;		// B3
	//MTU4.TIER.BIT.TGIEC=0;		// B2
	//MTU4.TIER.BIT.TGIEB=0;		// B1
	//MTU4.TIER.BIT.TGIEA=0;		// B0

	//MTU4.TCNT=0x0000;				// Timer Counter (Reset val 0x0000)

	//MTU4.TGRA=0xFFFF;				// Timer General Register (Reset val 0xFFFF)

	//MTU4.TGRB=0xFFFF;				// Timer General Register (Reset val 0xFFFF)

	//MTU4.TGRC=0xFFFF;				// Timer General Register (Reset val 0xFFFF)

	//MTU4.TGRD=0xFFFF;				// Timer General Register (Reset val 0xFFFF)

	//MTU4.TGRE=0xFFFF;				// Timer General Register (Reset val 0xFFFF)

	//MTU4.TGRF=0xFFFF;				// Timer General Register (Reset val 0xFFFF)

	//MTU4.TSR.BYTE=0xC0;			// Timer Status Register (Reset val 0xC0)
	//MTU4.TSR.BIT.TCFD=0;			// B7
	//MTU4.TSR.BIT.TCFV=0;			// B4
	//MTU4.TSR.BIT.TGFD=0;			// B3
	//MTU4.TSR.BIT.TGFC=0;			// B2
	//MTU4.TSR.BIT.TGFB=0;			// B1
	//MTU4.TSR.BIT.TGFA=0;			// B0

	//MTU4.TBTM.BYTE=0x00;			// Timer Buffer Operation Transfer Mode Register (Reset val 0x00)
	//MTU4.TBTM.BIT.TTSB=0;			// B1
	//MTU4.TBTM.BIT.TTSA=0;			// B0

	//MTU4.TADCR.WORD=0x0000;		// Timer A/D Converter Start Request Control Register (Reset val 0x0000)
	//MTU4.TADCR.BIT.BF=0;			// B15, B14
	//MTU4.TADCR.BIT.UT4AE=0;		// B7
	//MTU4.TADCR.BIT.DT4AE=0;		// B6
	//MTU4.TADCR.BIT.UT4BE=0;		// B5
	//MTU4.TADCR.BIT.DT4BE=0;		// B4
	//MTU4.TADCR.BIT.ITA3AE=0;		// B3
	//MTU4.TADCR.BIT.ITA4VE=0;		// B2
	//MTU4.TADCR.BIT.ITB3AE=0;		// B1
	//MTU4.TADCR.BIT.ITB4VE=0;		// B0

	//MTU4.TADCORA=0xFFFF;			// Timer A/D Converter Start Request Cycle Set Register (Reset val 0xFFFF)

	//MTU4.TADCORB=0xFFFF;			// Timer A/D Converter Start Request Cycle Set Register (Reset val 0xFFFF)

	//MTU4.TADCOBRA=0xFFFF;			// Timer A/D Converter Start Request Cycle Set Buffer Register (Reset val 0xFFFF)

	//MTU4.TADCOBRB=0xFFFF;			// Timer A/D Converter Start Request Cycle Set Buffer Register (Reset val 0xFFFF)


	/*** Multi-function Timer Unit (timer 5) ***/

	//MTU5.TCNTU=0x0000;			// Timer Counter (Reset val 0x0000)

	//MTU5.TGRU=0xFFFF;				// Timer General Register (Reset val 0xFFFF)

	//MTU5.TCRU.BYTE=0x00;			// Timer Control Register (Reset val 0x00)
	//MTU5.TCRU.BIT.TPSC=0;			// B1, B0

	//MTU5.TIORU.BYTE=0x00;			// Timer I/O Control Register (Reset val 0x00)
	//MTU5.TIORU.BIT.IOC=0;			// B5, B3, B2, B1, B0

	//MTU5.TCNTV=0x0000;			// Timer Counter (Reset val 0x0000)

	//MTU5.TGRV=0xFFFF;				// Timer General Register (Reset val 0xFFFF)

	//MTU5.TCRV.BYTE=0x00;			// Timer Control Register (Reset val 0x00)
	//MTU5.TCRV.BIT.TPSC=0;			// B1, B0

	//MTU5.TIORV.BYTE=0x00;			// Timer I/O Control Register (Reset val 0x00)
	//MTU5.TIORV.BIT.IOC=0;			// B5, B3, B2, B1, B0

	//MTU5.TCNTW=0x0000;			// Timer Counter (Reset val 0x0000)

	//MTU5.TGRW=0xFFFF;				// Timer General Register (Reset val 0xFFFF)

	//MTU5.TCRW.BYTE=0x00;			// Timer Control Register (Reset val 0x00)
	//MTU5.TCRW.BIT.TPSC=0;			// B1, B0

	//MTU5.TIORW.BYTE=0x00;			// Timer I/O Control Register (Reset val 0x00)
	//MTU5.TIORW.BIT.IOC=0;			// B5, B3, B2, B1, B0

	//MTU5.TSR.BYTE=0xC0;			// Timer Status Register (Reset val 0xC0)
	//MTU5.TSR.BIT.CMFU5=0;			// B2
	//MTU5.TSR.BIT.CMFV5=0;			// B1
	//MTU5.TSR.BIT.CMFW5=0;			// B0

	//MTU5.TIER.BYTE=0x00;			// Timer Interrupt Enable Register (Reset val 0x00)
	//MTU5.TIER.BIT.TGIE5U=0;		// B2
	//MTU5.TIER.BIT.TGIE5V=0;		// B1
	//MTU5.TIER.BIT.TGIE5W=0;		// B0

	//MTU5.TSTR.BYTE=0x00;			// Timer Start Register (Reset val 0x00)
	//MTU5.TSTR.BIT.CSTU5=0;		// B2
	//MTU5.TSTR.BIT.CSTV5=0;		// B1
	//MTU5.TSTR.BIT.CSTW5=0;		// B0

	//MTU5.TCCR.BYTE=0x00;			// Timer Compare Match Clear Register (Reset val 0x00)
	//MTU5.TCCR.BIT.CMPCLR5U=0;		// B2
	//MTU5.TCCR.BIT.CMPCLR5V=0;		// B1
	//MTU5.TCCR.BIT.CMPCLR5W=0;		// B0


	/*** Multi-function Timer Unit (timer 6) ***/

	//MTU6.TCR.BYTE=0x00;			// Timer Control Register (Reset val 0x00)
	//MTU6.TCR.BIT.CCLR=0;			// B7, B6, B5
	//MTU6.TCR.BIT.CKEG=0;			// B4, B3
	//MTU6.TCR.BIT.TPSC=0;			// B2, B1, B0

	//MTU6.TMDR1.BYTE=0x00;			// Timer Mode Register 1 (Reset val 0x00)
	//MTU6.TMDR1.BIT.BFB=0;			// B5
	//MTU6.TMDR1.BIT.BFA=0;			// B4
	//MTU6.TMDR1.BIT.MD=0;			// B3, B2, B1, B0

	//MTU6.TIORH.BYTE=0x00;			// Timer I/O Control Register H (Reset val 0x00)
	//MTU6.TIORH.BIT.IOB=0;			// B7, B6, B5, B4
	//MTU6.TIORH.BIT.IOA=0;			// B3, B2, B1, B0

	//MTU6.TIORL.BYTE=0x00;			// Timer I/O Control Register L (Reset val 0x00)
	//MTU6.TIORL.BIT.IOD=0;			// B7, B6, B5, B4
	//MTU6.TIORL.BIT.IOC=0;			// B3, B2, B1, B0

	//MTU6.TIER.BYTE=0x00;			// Timer Interrupt Enable Register (Reset val 0x00)
	//MTU6.TIER.BIT.TTGE=0;			// B7
	//MTU6.TIER.BIT.TCIEV=0;		// B4
	//MTU6.TIER.BIT.TGIED=0;		// B3
	//MTU6.TIER.BIT.TGIEC=0;		// B2
	//MTU6.TIER.BIT.TGIEB=0;		// B1
	//MTU6.TIER.BIT.TGIEA=0;		// B0

	//MTU6.TCNT=0x0000;				// Timer Counter (Reset val 0x0000)

	//MTU6.TGRA=0xFFFF;				// Timer General Register (Reset val 0xFFFF)

	//MTU6.TGRB=0xFFFF;				// Timer General Register (Reset val 0xFFFF)

	//MTU6.TGRC=0xFFFF;				// Timer General Register (Reset val 0xFFFF)

	//MTU6.TGRD=0xFFFF;				// Timer General Register (Reset val 0xFFFF)

	//MTU6.TGRE=0xFFFF;				// Timer General Register (Reset val 0xFFFF)

	//MTU6.TSR.BYTE=0xC0;			// Timer Status Register (Reset val 0xC0)
	//MTU6.TSR.BIT.TCFD=0;			// B7
	//MTU6.TSR.BIT.TCFV=0;			// B4
	//MTU6.TSR.BIT.TGFD=0;			// B3
	//MTU6.TSR.BIT.TGFC=0;			// B2
	//MTU6.TSR.BIT.TGFB=0;			// B1
	//MTU6.TSR.BIT.TGFA=0;			// B0

	//MTU6.TBTM.BYTE=0x00;			// Timer Buffer Operation Transfer Mode Register (Reset val 0x00)
	//MTU6.TBTM.BIT.TTSB=0;			// B1
	//MTU6.TBTM.BIT.TTSA=0;			// B0

	//MTU6.TSYCR.BYTE=0x00;			// Timer synchronous clear register (Reset val 0x00)
	//MTU6.TSYCR.BIT.CE0A=0;		// B7
	//MTU6.TSYCR.BIT.CE0B=0;		// B6
	//MTU6.TSYCR.BIT.CE0C=0;		// B5
	//MTU6.TSYCR.BIT.CE0D=0;		// B4
	//MTU6.TSYCR.BIT.CE1A=0;		// B3
	//MTU6.TSYCR.BIT.CE1B=0;		// B2
	//MTU6.TSYCR.BIT.CE2A=0;		// B1
	//MTU6.TSYCR.BIT.CE2B=0;		// B0


	/*** Multi-function Timer Unit (timer 7) ***/

	//MTU7.TCR.BYTE=0x00;			// Timer Control Register (Reset val 0x00)
	//MTU7.TCR.BIT.CCLR=0;			// B7, B6, B5
	//MTU7.TCR.BIT.CKEG=0;			// B4, B3
	//MTU7.TCR.BIT.TPSC=0;			// B2, B1, B0

	//MTU7.TMDR1.BYTE=0x00;			// Timer Mode Register 1 (Reset val 0x00)
	//MTU7.TMDR1.BIT.BFB=0;			// B5
	//MTU7.TMDR1.BIT.BFA=0;			// B4
	//MTU7.TMDR1.BIT.MD=0;			// B3, B2, B1, B0

	//MTU7.TIORH.BYTE=0x00;			// Timer I/O Control Register H (Reset val 0x00)
	//MTU7.TIORH.BIT.IOB=0;			// B7, B6, B5, B4
	//MTU7.TIORH.BIT.IOA=0;			// B3, B2, B1, B0

	//MTU7.TIORL.BYTE=0x00;			// Timer I/O Control Register L (Reset val 0x00)
	//MTU7.TIORL.BIT.IOD=0;			// B7, B6, B5, B4
	//MTU7.TIORL.BIT.IOC=0;			// B3, B2, B1, B0

	//MTU7.TIER.BYTE=0x00;			// Timer Interrupt Enable Register (Reset val 0x00)
	//MTU7.TIER.BIT.TTGE=0;			// B7
	//MTU7.TIER.BIT.TTGE2=0;		// B6
	//MTU7.TIER.BIT.TCIEV=0;		// B4
	//MTU7.TIER.BIT.TGIED=0;		// B3
	//MTU7.TIER.BIT.TGIEC=0;		// B2
	//MTU7.TIER.BIT.TGIEB=0;		// B1
	//MTU7.TIER.BIT.TGIEA=0;		// B0

	//MTU7.TCNT=0x0000;				// Timer Counter (Reset val 0x0000)

	//MTU7.TGRA=0xFFFF;				// Timer General Register (Reset val 0xFFFF)

	//MTU7.TGRB=0xFFFF;				// Timer General Register (Reset val 0xFFFF)

	//MTU7.TGRC=0xFFFF;				// Timer General Register (Reset val 0xFFFF)

	//MTU7.TGRD=0xFFFF;				// Timer General Register (Reset val 0xFFFF)

	//MTU7.TGRE=0xFFFF;				// Timer General Register (Reset val 0xFFFF)

	//MTU7.TGRF=0xFFFF;				// Timer General Register (Reset val 0xFFFF)

	//MTU7.TSR.BYTE=0xC0;			// Timer Status Register (Reset val 0xC0)
	//MTU7.TSR.BIT.TCFD=0;			// B7
	//MTU7.TSR.BIT.TCFV=0;			// B4
	//MTU7.TSR.BIT.TGFD=0;			// B3
	//MTU7.TSR.BIT.TGFC=0;			// B2
	//MTU7.TSR.BIT.TGFB=0;			// B1
	//MTU7.TSR.BIT.TGFA=0;			// B0

	//MTU7.TBTM.BYTE=0x00;			// Timer Buffer Operation Transfer Mode Register (Reset val 0x00)
	//MTU7.TBTM.BIT.TTSB=0;			// B1
	//MTU7.TBTM.BIT.TTSA=0;			// B0

	//MTU7.TADCR.WORD=0x0000;		// Timer A/D Converter Start Request Control Register (Reset val 0x0000)
	//MTU7.TADCR.BIT.BF=0;			// B15, B14
	//MTU7.TADCR.BIT.UT7AE=0;		// B7
	//MTU7.TADCR.BIT.DT7AE=0;		// B6
	//MTU7.TADCR.BIT.UT7BE=0;		// B5
	//MTU7.TADCR.BIT.DT7BE=0;		// B4
	//MTU7.TADCR.BIT.ITA6AE=0;		// B3
	//MTU7.TADCR.BIT.ITA7VE=0;		// B2
	//MTU7.TADCR.BIT.ITB6AE=0;		// B1
	//MTU7.TADCR.BIT.ITB7VE=0;		// B0

	//MTU7.TADCORA=0xFFFF;			// Timer A/D Converter Start Request Cycle Set Register (Reset val 0xFFFF)

	//MTU7.TADCORB=0xFFFF;			// Timer A/D Converter Start Request Cycle Set Register (Reset val 0xFFFF)

	//MTU7.TADCOBRA=0xFFFF;			// Timer A/D Converter Start Request Cycle Set Buffer Register (Reset val 0xFFFF)

	//MTU7.TADCOBRB=0xFFFF;			// Timer A/D Converter Start Request Cycle Set Buffer Register (Reset val 0xFFFF)


	/*** Port Output Enable ***/

	//POE.ICSR1.WORD=0x0000;		// Input level control/status register 1 (reset 0x0000)
	//POE.ICSR1.BYTE.H=0x00;
	//POE.ICSR1.BYTE.L=0x00;
	//POE.ICSR1.BIT.POE0F=0;		// B12
	//POE.ICSR1.BIT.PIE1=0;			// B8
	//POE.ICSR1.BIT.POE0M=0;		// B1, B0

	//POE.OCSR1.WORD=0x0000;		// Output level control/status register 1 (reset 0x0000)
	//POE.OCSR1.BYTE.H=0x00;
	//POE.OCSR1.BYTE.L=0x00;
	//POE.OCSR1.BIT.OSF1=0;			// B15
	//POE.OCSR1.BIT.OCE1=0;			// B9
	//POE.OCSR1.BIT.OIE1=0;			// B8

	//POE.ICSR2.WORD=0x0000;		// Input level control/status register 2 (reset 0x0000)
	//POE.ICSR2.BYTE.H=0x00;
	//POE.ICSR2.BYTE.L=0x00;
	//POE.ICSR2.BIT.POE4F=0;		// B12
	//POE.ICSR2.BIT.PIE2=0;			// B8
	//POE.ICSR2.BIT.POE4M=0;		// B1, B0

	//POE.OCSR2.WORD=0x0000;		// Output level control/status register 2 (reset 0x0000)
	//POE.OCSR2.BYTE.H=0x00;
	//POE.OCSR2.BYTE.L=0x00;
	//POE.OCSR2.BIT.OSF2=0;			// B15
	//POE.OCSR2.BIT.OCE2=0;			// B9
	//POE.OCSR2.BIT.OIE2=0;			// B8

	//POE.ICSR3.WORD=0x0000;		// Input level control/status register 3 (reset 0x0000)
	//POE.ICSR3.BYTE.H=0x00;
	//POE.ICSR3.BYTE.L=0x00;
	//POE.ICSR3.BIT.POE8F=0;		// B12
	//POE.ICSR3.BIT.POE8E=0;		// B9
	//POE.ICSR3.BIT.PIE3=0;			// B8
	//POE.ICSR3.BIT.POE8M=0;		// B1, B0

	//POE.SPOER.BYTE=0x00;			// Software port output enable register (reset 0x00)
	//POE.SPOER.BIT.GPT23HIZ=0;		// B4
	//POE.SPOER.BIT.GPT01HIZ=0;		// B3
	//POE.SPOER.BIT.MTUCH0HIZ=0;	// B2
	//POE.SPOER.BIT.MTUCH67HIZ=0;	// B1
	//POE.SPOER.BIT.MTUCH34HIZ=0;	// B0

	//POE.POECR1.BYTE=0x00;			// Port output enable control register 1 (reset 0x00)
	//POE.POECR1.BIT.MTU0DZE=0;		// B3
	//POE.POECR1.BIT.MTU0CZE=0;		// B2
	//POE.POECR1.BIT.MTU0BZE=0;		// B1
	//POE.POECR1.BIT.MTU0AZE=0;		// B0

	//POE.POECR2.WORD=0x00;			// Port output enable control register 2 (reset 0x00)
	//POE.POECR2.BIT.MTU3BDZE=0;	// B10
	//POE.POECR2.BIT.MTU4ACZE=0;	// B9
	//POE.POECR2.BIT.MTU4BDZE=0;	// B8
	//POE.POECR2.BIT.MTU6BDZE=0;	// B2
	//POE.POECR2.BIT.MTU7ACZE=0;	// B1
	//POE.POECR2.BIT.MTU7BDZE=0;	// B0

	//POE.POECR3.WORD=0x00;			// Port output enable control register 3 (reset 0x00)
	//POE.POECR3.BIT.GPT3ABZE=0;	// B9
	//POE.POECR3.BIT.GPT2ABZE=0;	// B8
	//POE.POECR3.BIT.GPT1ABZE=0;	// B1
	//POE.POECR3.BIT.GPT0ABZE=0;	// B0

	//POE.POECR4.WORD=0x00;			// Port output enable control register 4 (reset 0x00)
	//POE.POECR4.BIT.IC5ADDMT67ZE=0;	// B13
	//POE.POECR4.BIT.IC4ADDMT67ZE=0;	// B12
	//POE.POECR4.BIT.IC3ADDMT67ZE=0;	// B11
	//POE.POECR4.BIT.IC1ADDMT67ZE=0;	// B9
	//POE.POECR4.BIT.CMADDMT67ZE=0;		// B8
	//POE.POECR4.BIT.IC5ADDMT34ZE=0;	// B5
	//POE.POECR4.BIT.IC4ADDMT34ZE=0;	// B4
	//POE.POECR4.BIT.IC3ADDMT34ZE=0;	// B3
	//POE.POECR4.BIT.IC2ADDMT34ZE=0;	// B2
	//POE.POECR4.BIT.CMADDMT34ZE=0;		// B0

	//POE.POECR5.WORD=0x00;			// Port output enable control register 5 (reset 0x00)
	//POE.POECR5.BIT.IC5ADDMT0ZE=0;	// B5
	//POE.POECR5.BIT.IC4ADDMT0ZE=0;	// B4
	//POE.POECR5.BIT.IC2ADDMT0ZE=0;	// B2
	//POE.POECR5.BIT.IC1ADDMT0ZE=0;	// B1
	//POE.POECR5.BIT.CMADDMT0ZE=0;	// B0

	//POE.POECR6.WORD=0x00;			// Port output enable control register 6 (reset 0x00)
	//POE.POECR6.BIT.IC4ADDGPT23ZE=0;	// B12
	//POE.POECR6.BIT.IC3ADDGPT23ZE=0;	// B11
	//POE.POECR6.BIT.IC2ADDGPT23ZE=0;	// B10
	//POE.POECR6.BIT.IC1ADDGPT23ZE=0;	// B9
	//POE.POECR6.BIT.CMADDGPT23ZE=0;	// B8
	//POE.POECR6.BIT.IC5ADDGPT01ZE=0;	// B6
	//POE.POECR6.BIT.IC3ADDGPT01ZE=0;	// B4
	//POE.POECR6.BIT.IC2ADDGPT01ZE=0;	// B3
	//POE.POECR6.BIT.IC1ADDGPT01ZE=0;	// B2
	//POE.POECR6.BIT.CMADDGPT01ZE=0;	// B1, B0

	//POE.ICSR4.WORD=0x0000;		// Input level control/status register 4 (reset 0x0000)
	//POE.ICSR4.BYTE.H=0x00;
	//POE.ICSR4.BYTE.L=0x00;
	//POE.ICSR4.BIT.POE10F=0;		// B12
	//POE.ICSR4.BIT.POE10E=0;		// B9
	//POE.ICSR4.BIT.PIE4=0;			// B8
	//POE.ICSR4.BIT.POE10M=0;		// B1, B0

	//POE.ICSR5.WORD=0x0000;		// Input level control/status register 5 (reset 0x0000)
	//POE.ICSR5.BYTE.H=0x00;
	//POE.ICSR5.BYTE.L=0x00;
	//POE.ICSR5.BIT.POE11F=0;		// B12
	//POE.ICSR5.BIT.POE11E=0;		// B9
	//POE.ICSR5.BIT.PIE5=0;			// B8
	//POE.ICSR5.BIT.POE11M=0;		// B1, B0

	//POE.ALR1.WORD=0x0000;			// Input level control/status register 5 (reset 0x0000)
	//POE.ALR1.BYTE.H=0x00;
	//POE.ALR1.BYTE.L=0x00;
	//POE.ALR1.BIT.OLSEN=0;			// B7
	//POE.ALR1.BIT.OLSG2B=0;		// B5
	//POE.ALR1.BIT.OLSG2A=0;		// B4
	//POE.ALR1.BIT.OLSG1B=0;		// B3
	//POE.ALR1.BIT.OLSG1A=0;		// B2
	//POE.ALR1.BIT.OLSG0B=0;		// B1
	//POE.ALR1.BIT.OLSG0A=0;		// B0


	/*** Serial Communication Interface 2 ***/

	//SCI2.SMR.BYTE=0x00;			// Serial Mode Register (Reset val 0x00)
	//SCI2.SMR.BIT.CM=0;			// B7
	//SCI2.SMR.BIT.CHR=0;			// B6
	//SCI2.SMR.BIT.PE=0;			// B5
	//SCI2.SMR.BIT.PM=0;			// B4
	//SCI2.SMR.BIT.STOP=0;			// B3
	//SCI2.SMR.BIT.MP=0;			// B2
	//SCI2.SMR.BIT.CKS=0;			// B1, B0
	//SCI2.SMR.BIT2.GM=0;			// B7
	//SCI2.SMR.BIT2.BLK=0;			// B6
	//SCI2.SMR.BIT2.PE=0;			// B5
	//SCI2.SMR.BIT2.PM=0;			// B4
	//SCI2.SMR.BIT2.BCP=0;			// B3, B2
	//SCI2.SMR.BIT2.CKS=0;			// B1, B0

	//SCI2.BRR=0xFF;				// Bit Rate Register (Reset val 0xFF)

	//SCI2.SCR.BYTE=0x00;			// Serial Control Register (Reset val 0x00)
	//SCI2.SCR.BIT.TIE=0;			// B7
	//SCI2.SCR.BIT.RIE=0;			// B6
	//SCI2.SCR.BIT.TE=0;			// B5
	//SCI2.SCR.BIT.RE=0;			// B4
	//SCI2.SCR.BIT.MPIE=0;			// B3
	//SCI2.SCR.BIT.TEIE=0;			// B2
	//SCI2.SCR.BIT.CKE=0;			// B1, B0

	//SCI2.TDR=0;					// Transmit data register

	//SCI2.SSR.BYTE=0x84;			// Serial Status Register (Reset val 0xX4)
	//SCI2.SSR.BIT.ORER=0;			// B5
	//SCI2.SSR.BIT.FER=0;			// B4
	//SCI2.SSR.BIT.PER=0;			// B3
	//SCI2.SSR.BIT.TEND=1;			// B2
	//SCI2.SSR.BIT.MPB=0;			// B1
	//SCI2.SSR.BIT.MPBT=0;			// B0
	//SCI2.SSR.BIT2.ERS=0;			// B4

	//SCI2.RDR						// Receive Data Register

	//SCI2.SCMR.BYTE=0xF2;			// Smart card mode register (Reset val 0xF2)
	//SCI2.SCMR.BIT.BCP2=0;			// B7
	//SCI2.SCMR.BIT.SDIR=0;			// B3
	//SCI2.SCMR.BIT.SINV=0;			// B2
	//SCI2.SCMR.BIT.SMIF=0;			// B0

	//SCI2.SEMR.BYTE=0x00;			// Serial extended mode register (Reset val 0x00)
	//SCI2.SEMR.BIT.NFEN=0;			// B5
	//SCI2.SEMR.BIT.ABCS=0;			// B4


}


