
/*******************************************************************************
*	DISCLAIMER
*
*	THIS SOFTWARE IS PROVIDED "AS IS" AND BFG ENGINEERING MAKES NO WARRANTIES
*	REGARDING THIS SOFTWARE, WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING
*	BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
*	PURPOSE AND NON-INFRINGEMENT. ALL SUCH WARRANTIES ARE EXPRESSLY DISCLAIMED.
*
*	WE (BFG ENGINEERING) DO NOT WARRANT THAT THIS SOFTWARE IS FREE FROM CLAIMS
*	BY A THIRD PARTY OF COPYRIGHT, PATENT, TRADEMARK, TRADE SECRET OR ANY OTHER
*	INTELLECTUAL PROPERTY INFRINGIMENT.
*
*	TO THE MAXIMUM EXTENT PERMITTED NOT PROHIBITED BY LAW, BFG ENGINEERING
*	SHALL NOT BE LIABLE FOR ANY DIRECT, INDIRECT, SPECIAL, INCIDENTAL OR
*	CONSEQUENTIAL DAMAGES FOR ANY REASON RELATED TO THIS SOFTWARE, EVEN IF BFG
*	ENGINEERING HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
*	PARTICULARLY, UNDER NO CIRCUMSTANCES ARE WE LIABLE FOR ANY OF THE FOLLOWING:
*	- THIRD PARTY CLAIMS AGAINST YOU FOR LOSSES OR DAMAGES;
*	- LOSS OF, OR DAMAGE TO YOUR RECORDS OR DATA; OR
*	- ECONOMIC CONSEQUENTIAL DAMAGES (INCLUDING LOST PROFITS OR SAVINGS) OR
*	  INCIDENTAL DAMAGES, EVEN IF WE ARE INFORMED OF THEIR POSSIBILITY.
*
*	BFG ENGINEERING DOES NOT WARRANT UNINTERRUPTED OR ERROR_FREE OPERATION OF
*	THIS SOFTWARE.
*	BFG ENGINEERING HAS NO OBLIGATION TO PROVIDE SERVICE, DEFECT CORRECTION OR
*	ANY MANTEINANCE OF THIS SOFTWARE; OR TO SUPPLY ANY UPDATES OR ENHANCEMENTS
*	EVEN IF SUCH ARE, OR LATER BECOME, AVAILABLE.
*
*	IF YOU DOWNLOAD OR USE THIS SOFTWARE YOU AGREE TO THESE TERMS, AND DO IT AT
*	YOUR OWN RISK.
*******************************************************************************/

/*******************************************************************************
*	File:		main.c
*	Project:	MCRP07 RX62T
*	Revision:	7.0
*	Date:		25-10-2013 (DD-MM-YYYY)
*	Author:		Andrea Ghirardello
*	Contents:	Main program
*******************************************************************************/

#define _MAIN_C				// to be inserted BEFORE including any ".h"

#include "globdef.h"
#include "ges_eqp.h"
#include "motorcontrol.h"
#include "userif.h"

void main(void)
{
	// delay for bus voltage stabilization
	MC_Delay(1000);		// 10ms

	// flags
	UIF_R.var.flg=0;
	//RES_ALRM_ON
	//RES_COM_ON
	//RES_STA_BSY
	//RES_END_NOK

	// parameters upload
	ini_eqp();
	def_to_ram();
//	ram_to_eqp();
	if(eqp_to_ram()!=0) {
		UIF_R.var.all=EQP_ALL;
		SET_ALRM_ON
	}

	/* delay tuning
	while(1) {
		SET_DL1
		MC_Delay(100);		// 1ms
		CLR_DL1
		MC_Delay(100);		// 1ms
	} */

	// current offsets reading
	MC_SetOff();

	// program init
	MC_IniPar();
	ini_232_pc();
	MC_IniPWM();
	MC_StartDBPWM();

	// start of pwm, interrupt enable
	MC_StartPWM();
	CLR_DL1
	CLR_DL2
	CLR_DL3
	CLR_DL4

	// main loop
	while(1) {

		// time synchronization
		while(MC_WaitSync()) {
			// this time can be used for asynchronous functions
		}

		//SET_DL4				// timing debug

		// working mode management function (speed ramp etc.)
		MC_WorkMan();

		// interface management
		MC_ConFil();
		ges_232_pc();

		// general management functions
		if(ges_eqp()!=0) {
			if(UIF_R.var.all!=0) {
				UIF_R.var.all=EQP_ALL;
				SET_ALRM_ON
			}
		}
		ges_led();

		// parameters update
		MC_UpdPar();

		//CLR_DL4				// timing debug

	}

}

