
/*******************************************************************************
*	DISCLAIMER
*
*	THIS SOFTWARE IS PROVIDED "AS IS" AND BFG ENGINEERING MAKES NO WARRANTIES
*	REGARDING THIS SOFTWARE, WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING
*	BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
*	PURPOSE AND NON-INFRINGEMENT. ALL SUCH WARRANTIES ARE EXPRESSLY DISCLAIMED.
*
*	WE (BFG ENGINEERING) DO NOT WARRANT THAT THIS SOFTWARE IS FREE FROM CLAIMS
*	BY A THIRD PARTY OF COPYRIGHT, PATENT, TRADEMARK, TRADE SECRET OR ANY OTHER
*	INTELLECTUAL PROPERTY INFRINGIMENT.
*
*	TO THE MAXIMUM EXTENT PERMITTED NOT PROHIBITED BY LAW, BFG ENGINEERING
*	SHALL NOT BE LIABLE FOR ANY DIRECT, INDIRECT, SPECIAL, INCIDENTAL OR
*	CONSEQUENTIAL DAMAGES FOR ANY REASON RELATED TO THIS SOFTWARE, EVEN IF BFG
*	ENGINEERING HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
*	PARTICULARLY, UNDER NO CIRCUMSTANCES ARE WE LIABLE FOR ANY OF THE FOLLOWING:
*	- THIRD PARTY CLAIMS AGAINST YOU FOR LOSSES OR DAMAGES;
*	- LOSS OF, OR DAMAGE TO YOUR RECORDS OR DATA; OR
*	- ECONOMIC CONSEQUENTIAL DAMAGES (INCLUDING LOST PROFITS OR SAVINGS) OR
*	  INCIDENTAL DAMAGES, EVEN IF WE ARE INFORMED OF THEIR POSSIBILITY.
*
*	BFG ENGINEERING DOES NOT WARRANT UNINTERRUPTED OR ERROR_FREE OPERATION OF
*	THIS SOFTWARE.
*	BFG ENGINEERING HAS NO OBLIGATION TO PROVIDE SERVICE, DEFECT CORRECTION OR
*	ANY MANTEINANCE OF THIS SOFTWARE; OR TO SUPPLY ANY UPDATES OR ENHANCEMENTS
*	EVEN IF SUCH ARE, OR LATER BECOME, AVAILABLE.
*
*	IF YOU DOWNLOAD OR USE THIS SOFTWARE YOU AGREE TO THESE TERMS, AND DO IT AT
*	YOUR OWN RISK.
*******************************************************************************/

/*******************************************************************************
*	File:		pws_E6108A.h
*	Project:	MCRP07 RX62T
*	Revision:	7.0
*	Date:		25-11-2013 (DD-MM-YYYY)
*	Author:		Andrea Ghirardello
*	Contents:	External power stage (E6108A) related definitions
*******************************************************************************/

#ifndef	_PWS_E6108A_H
#define _PWS_E6108A_H

// current conversion
#define RSHUNT_OHM			0.05		// shunt value [Ohm]
#define RSGAIN				4.7			// circuit gain

// DC bus voltage conversion
#define RVBUSH_OHM			400000.0	// high side split resistor [Ohm]
#define RVBUSL_OHM			4700.0		// low side split resistor [Ohm]

// deadtimes to be inserted by MTU
#define DEADTIM_NS			1000		// deatimes [ns]

// minimum on time of low arms, to guarantee bootstrap operations
// this time should guarantee that the lower switch commutates effectively for enough time to
// charge the bootstrap capacitor
#define MIN_TON_LOW_NS		1500		// [ns] larger than deadtimes

// voltages
#define VB_NOM_VOL			311			// nominal bus voltage [V]

// inverter non linearities compensation
// non-linearities table definitions for MCRP EXTERNAL POWER STAGE E6108A
// voltage error is INL_O+INL_xx[I]*pwm_freq_Hz*BusVoltage/1000000
#define T_INL_INMAX			3.1f
#define T_INL_INDMAX		31
#define INL_O	1.169
#define INL_01	0.075		// 0.1A
#define INL_02	0.4625		// 0.2A
#define INL_03	0.7125		// 0.3A
#define INL_04	0.8375		// 0.4A
#define INL_05	0.91875		// 0.5A
#define INL_06	0.98125		// 0.6A
#define INL_07	1.0125		// 0.7A
#define INL_08	1.04375		// 0.8A
#define INL_09	1.0625		// 0.9A
#define INL_10	1.075		// 1.0A
#define INL_11	1.090625	// 1.1A
#define INL_12	1.0975		// 1.2A
#define INL_13	1.1			// 1.3A
#define INL_14	1.113125	// 1.4A
#define INL_15	1.11875		// 1.5A
#define INL_16	1.12125		// 1.6A
#define INL_17	1.12375		// 1.7A
#define INL_18	1.125		// 1.8A
#define INL_19	1.126875	// 1.9A
#define INL_20	1.12875		// 2.0A
#define INL_21	1.130625	// 2.1A
#define INL_22	1.1325		// 2.2A
#define INL_23	1.134375	// 2.3A
#define INL_24	1.13625		// 2.4A
#define INL_25	1.138125	// 2.5A
#define INL_26	1.14		// 2.6A
#define INL_27	1.14125		// 2.7A
#define INL_28	1.1425		// 2.8A
#define INL_29	1.14375		// 2.9A
#define INL_30	1.144375	// 3.0A
#define INL_31	1.144375	// 3.1A

#endif	// _PWS_E6108A_H

