
/*******************************************************************************
*	DISCLAIMER
*
*	THIS SOFTWARE IS PROVIDED "AS IS" AND BFG ENGINEERING MAKES NO WARRANTIES
*	REGARDING THIS SOFTWARE, WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING
*	BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
*	PURPOSE AND NON-INFRINGEMENT. ALL SUCH WARRANTIES ARE EXPRESSLY DISCLAIMED.
*
*	WE (BFG ENGINEERING) DO NOT WARRANT THAT THIS SOFTWARE IS FREE FROM CLAIMS
*	BY A THIRD PARTY OF COPYRIGHT, PATENT, TRADEMARK, TRADE SECRET OR ANY OTHER
*	INTELLECTUAL PROPERTY INFRINGIMENT.
*
*	TO THE MAXIMUM EXTENT PERMITTED NOT PROHIBITED BY LAW, BFG ENGINEERING
*	SHALL NOT BE LIABLE FOR ANY DIRECT, INDIRECT, SPECIAL, INCIDENTAL OR
*	CONSEQUENTIAL DAMAGES FOR ANY REASON RELATED TO THIS SOFTWARE, EVEN IF BFG
*	ENGINEERING HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
*	PARTICULARLY, UNDER NO CIRCUMSTANCES ARE WE LIABLE FOR ANY OF THE FOLLOWING:
*	- THIRD PARTY CLAIMS AGAINST YOU FOR LOSSES OR DAMAGES;
*	- LOSS OF, OR DAMAGE TO YOUR RECORDS OR DATA; OR
*	- ECONOMIC CONSEQUENTIAL DAMAGES (INCLUDING LOST PROFITS OR SAVINGS) OR
*	  INCIDENTAL DAMAGES, EVEN IF WE ARE INFORMED OF THEIR POSSIBILITY.
*
*	BFG ENGINEERING DOES NOT WARRANT UNINTERRUPTED OR ERROR_FREE OPERATION OF
*	THIS SOFTWARE.
*	BFG ENGINEERING HAS NO OBLIGATION TO PROVIDE SERVICE, DEFECT CORRECTION OR
*	ANY MANTEINANCE OF THIS SOFTWARE; OR TO SUPPLY ANY UPDATES OR ENHANCEMENTS
*	EVEN IF SUCH ARE, OR LATER BECOME, AVAILABLE.
*
*	IF YOU DOWNLOAD OR USE THIS SOFTWARE YOU AGREE TO THESE TERMS, AND DO IT AT
*	YOUR OWN RISK.
*******************************************************************************/

/*******************************************************************************
*	File:		userif.c
*	Project:	MCRP07 RX62T
*	Revision:	7.0
*	Date:		25-10-2013 (DD-MM-YYYY)
*	Author:		Andrea Ghirardello
*	Contents:	User interface
*******************************************************************************/

#define	_USERIF_C		// insert define BEFORE including header files

#include "globdef.h"
#include "userif.h"
#include "ges_eqp.h"

/* timing defines */
#define	LED_TIME_FUN	20	// 200ms led blinking time
#define	LED_TIME_ALL	3	// 30ms led blinking time

/* hardware related defines */
#define ERI2_NUM		222
#define ERI2_FLG		ICU.IR[ERI2_NUM].BIT.IR
#define	RX2_ERR			(ERI2_FLG!=0)
#define	RES_RX2_ERR		//ERI2_FLG=0;
#define RXI2_NUM		223
#define RXI2_FLG		ICU.IR[RXI2_NUM].BIT.IR
#define	RX2_FULL		(RXI2_FLG!=0)
#define	RES_RX2_FULL	RXI2_FLG=0;
#define TXI2_NUM		224
#define TXI2_FLG		ICU.IR[TXI2_NUM].BIT.IR
#define	TX2_EMPTY		(TXI2_FLG!=0)
#define	RES_TX2_EMPTY	TXI2_FLG=0;
#define	RX2_OVR_ERR		(SCI2.SSR.BIT.ORER!=0)
#define	RES_RX2_OVR_ERR	{ if(RX2_OVR_ERR) SCI2.SSR.BIT.ORER=0; }
#define	RX2_FRA_ERR		(SCI2.SSR.BIT.FER!=0)
#define	RES_RX2_FRA_ERR	{ if(RX2_FRA_ERR) SCI2.SSR.BIT.FER=0; }
#define	RX2_PAR_ERR		(SCI2.SSR.BIT.PER!=0)
#define	RES_RX2_PAR_ERR	{ if(RX2_PAR_ERR) SCI2.SSR.BIT.PER=0; }
#define ERR_FLG_MSK		0x38	// B5, B4, B3
#define RX2_HW_ERR		((SCI2.SSR.BYTE & ERR_FLG_MSK)!=0)
#define	RES_RX2_HW_ERR	SCI2.SSR.BYTE&=~ERR_FLG_MSK;	// { RES_RX2_OVR_ERR RES_RX2_FRA_ERR RES_RX2_PAR_ERR }
#define TX2_END			(SCI2.SSR.BIT.TEND!=0)
#define	SET_TX2			SCI2.SCR.BYTE|=0xA0;	// { SCI2.SCR.BIT.TE=1; SCI2.SCR.BIT.TIE=1;}
#define	RES_TX2			SCI2.SCR.BYTE&=0x5F;	// { SCI2.SCR.BIT.TE=0; SCI2.SCR.BIT.TIE=0;}
#define	SET_RX2			SCI2.SCR.BYTE|=0x50;	// { SCI2.SCR.BIT.RE=1; SCI2.SCR.BIT.RIE=1; }
#define	RES_RX2			SCI2.SCR.BYTE&=0xAF;	// { SCI2.SCR.BIT.RE=0; SCI2.SCR.BIT.RIE=0; }
#define	RX2_REG			SCI2.RDR
#define	TX2_REG			SCI2.TDR

/* serial communication protocol */
#define	N_CENT			0	/* slave identification number */
#define SEL_MAS			'?'	/* master frame identification character (question) */
#define SEL_SLA			'!'	/* slave frame identification character (answer OK) */
#define SEL_NOK			'#'	/* slave frame identification character (answer NOK) */
#define CCO				'c'	/* Check Com operation code */
#define NCO				'C'	/* Check Com operation code (answer) */
#define XCO				'd'	/* Check Com operation code (answer, programs with auto-tuning) */
#define RBO				'b'	/* Read Byte operation code */
#define RWO				'w'	/* Read Word operation code */
#define WWO				'W'	/* Write Word operation code */
#define RW3				'y'	/* Read Word 3 operation code (parameter minimum values) */
#define RW4				'z'	/* Read Word 4 operation code (parameter maximum values) */
#define RW5				'k'	/* Read Word 5 operation code (measurement samples vector) */
#define	LEN_MIN			5	/* shortest frame length, crc included */
#define	LEN_DEL			2	/* additional characters, data excluded, crc included */
#define	IND_LEN			0	/* string length index */
#define	IND_SEL			1	/* master/slave identificator index */
#define	IND_ADS			2	/* station address index */
#define	IND_COD			3	/* operation code index */
#define IND_ADD			4	/* data address index */
#define	IND_ND			5	/* data number index */
#define	IND_ID			6	/* data start index */

/* software related flags */
#define	RX2_ON			(fser2.bit.b0!=0)
#define	RX2_OFF			(fser2.bit.b0==0)
#define	RX2_INI			(fser2.bit.b1!=0)
#define	TX2_ON			(fser2.bit.b2!=0)
#define	TX2_OFF			(fser2.bit.b2==0)
#define	RTX2_ON			(fser2.bit.b3!=0)
#define	RTX2_OFF		(fser2.bit.b3==0)
#define GO_TX2			(fser2.bit.b4!=0)
#define	SET_RX2_ON		fser2.bit.b0=1;
#define	SET_RX2_INI		fser2.bit.b1=1;
#define	SET_TX2_ON		fser2.bit.b2=1;
#define	SET_RTX2_ON		fser2.bit.b3=1;
#define SET_GO_TX2		fser2.bit.b4=1;
#define	RES_RX2_ON		fser2.bit.b0=0;
#define	RES_RX2_INI		fser2.bit.b1=0;
#define	RES_TX2_ON		fser2.bit.b2=0;
#define	RES_RTX2_ON		fser2.bit.b3=0;
#define RES_GO_TX2		fser2.bit.b4=0;

#define	START_TX2		{	SET_TX2					/* enable TX */				\
							rtx2_cnt = 0;			/* counter init */			\
							SET_TX2_ON				/* TX flag setting */		}
/*							TX2_REG = rtx2_buf[1];	 shift reg. loading */
#define	START_RX2		{	RES_RX2												\
							rtx2_cnt = 0;			/* counter init */			\
							RES_RX2_FULL										\
							RES_RX2_ERR											\
							RES_RX2_HW_ERR										\
							RES_RX2_INI				/* reset RX started flag */	\
							SET_RX2					/* enable RX */				\
							SET_RX2_ON				/* RX flag setting */		}

#define	RTX2_LEN		300	/* rx/tx buffer dim. */
#define	RX2_TIM			20	/* end of receive delay (1=0.1ms) */

const unsigned char
	crc_tab[256] = {		// DOW CRC table
		  0,  94, 188, 226,  97,  63, 221, 131, 194, 156, 126,  32, 163, 253,  31,  65,
		157, 195,  33, 127, 252, 162,  64,  30,  95,   1, 227, 189,  62,  96, 130, 220,
		 35, 125, 159, 193,  66,  28, 254, 160, 225, 191,  93,   3, 128, 222,  60,  98,
		190, 224,   2,  92, 223, 129,  99,  61, 124,  34, 192, 158,  29,  67, 161, 255,
		 70,  24, 250, 164,  39, 121, 155, 197, 132, 218,  56, 102, 229, 187,  89,   7,
		219, 133, 103,  57, 186, 228,   6,  88,  25,  71, 165, 251, 120,  38, 196, 154,
		101,  59, 217, 135,   4,  90, 184, 230, 167, 249,  27,  69, 198, 152, 122,  36,
		248, 166,  68,  26, 153, 199,  37, 123,  58, 100, 134, 216,  91,   5, 231, 185,
		140, 210,  48, 110, 237, 179,  81,  15,  78,  16, 242, 172,  47, 113, 147, 205,
		 17,  79, 173, 243, 112,  46, 204, 146, 211, 141, 111,  49, 178, 236,  14,  80,
		175, 241,  19,  77, 206, 144, 114,  44, 109,  51, 209, 143,  12,  82, 176, 238,
		 50, 108, 142, 208,  83,  13, 239, 177, 240, 174,  76,  18, 145, 207,  45, 115,
		202, 148, 118,  40, 171, 245,  23,  73,   8,  86, 180, 234, 105,  55, 213, 139,
		 87,   9, 235, 181,  54, 104, 138, 212, 149, 203,  41, 119, 244, 170,  72,  22,
		233, 183,  85,  11, 136, 214,  52, 106,  43, 117, 151, 201,  74,  20, 246, 168,
		116,  42, 200, 150,  21,  75, 169, 247, 182, 232,  10,  84, 215, 137, 107,  53};

byte_t
	fser2;

unsigned short
	rtx2_tim=0,
	rtx2_cnt=0,
	rtx2_num=0;
unsigned char
	rtx2_buf[RTX2_LEN];				// rx/tx buffer (half duplex)
unsigned short
	add_par,
	dta_par;

// timing macro
#define	US10		167U	// constant corresponding to 0.01 ms @100MHz

void uif_delay(u32 time)
/*******************************************************************************
*	Description:	delay
*******************************************************************************/
{
	u32	i;

	for(; time>0; --time)
		for(i=US10; i>0; --i)
			nop();
}

unsigned short b2w(unsigned char *v)
/******************************************************************************
* Function Name: b2w
* Description  : 2 bytes vector conversion in a word
* Arguments    : two bytes vector *v
* Return Value : the short obtained by the union of the two bytes
******************************************************************************/
{
	word_t	w;

	w.byte.h=v[0];
	w.byte.l=v[1];
	return(w.word);
}

unsigned char *w2b(unsigned short w, unsigned char *v)
/******************************************************************************
* Function Name: w2b
* Description  : 1 word conversion in a 2 bytes vector
* Arguments    : the word to convert and the address of the result vector
* Return Value : the address of the result vector
* Note         : it modifies the vector content
******************************************************************************/
{
	word_t	x;

	x.word=w;
	v[0]=x.byte.h;
	v[1]=x.byte.l;
	return(v);
}

unsigned char cal_crc(unsigned char n, unsigned char *v)
/******************************************************************************
* Function Name: cal_crc
* Description  : DOW CRC calculation
* Arguments    : the number of bytes to be taken into account and the vector
*                containing these bytes
* Return Value : CRC
* Note         : it uses the DOW CRC calculation table defined before
******************************************************************************/
{
	unsigned char	cks=0, i;

	for(i=0; i<n; i++)
		cks=crc_tab[cks^v[i]];
	return(cks);
}

void ini_232_pc(void)
/******************************************************************************
* Function Name: ini_232_pc
* Description  : serial communication init
* Arguments    : none
* Return Value : none
******************************************************************************/
{

	WAKEUP_SCI2

	for(rtx2_cnt=0; rtx2_cnt<RTX2_LEN; rtx2_cnt++)
		rtx2_buf[rtx2_cnt]=0;
	rtx2_cnt=0;
	rtx2_tim=0,
	rtx2_num=0;

	SCI2.SCR.BYTE=0x00;			// disable any tx/rx, set internal clock
	SCI2.SMR.BYTE=0x01;			// Asynchronous, N81, clock/4
	SCI2.SEMR.BYTE=0x00;		// base clock=16, no noise canc
	SCI2.BRR=40;				// 9600baud @12.5MHz (=(50/4)MHz)

	uif_delay(20);				// wait at least 1 bit time

	// ports setup already done in hwsetup.c
	//PORTB.DR.BIT.B6=1;		// PIN27	PB6 DIG IN	RXD2_UP27		RX
	//PORTB.DDR.BIT.B6=0;		// PIN27	PB6 DIG IN	RXD2_UP27		RX
	//PORTB.ICR.BIT.B6=1;		// PIN27	PB6 DIG IN	RXD2_UP27		RX
	//PORTB.DR.BIT.B5=1;		// PIN28	PB5 DIG OUT	TXD2_UP28		TX
	//PORTB.DDR.BIT.B5=1;		// PIN28	PB5 DIG OUT	TXD2_UP28		TX
	//PORTB.ICR.BIT.B5=0;		// PIN28	PB5 DIG OUT	TXD2_UP28		TX

//	ICU.IPR[0x82].BIT.IPR=1;		// interrupt priority
//	ICU.IER[0x1B].BIT.IEN7=1;		// interrupt enable
//	SCI2.SCR.BIT.RIE=1;				// B6

	RES_GO_TX2
	START_RX2					// start rx

}

void poll_232_pc(void)
/******************************************************************************
* Function Name: poll_232_pc
* Description  : serial communication polling
* Arguments    : none
* Return Value : none
* Note         : to be called in the control interrupt
******************************************************************************/
{
	if(TX2_ON) {
		if(TX2_EMPTY) {							//	if buffer empty ...
			RES_TX2_EMPTY						//	... reset empty buffer flag ...
			if(rtx2_cnt < rtx2_num)				//	... if data not finished ...
				TX2_REG = rtx2_buf[rtx2_cnt++];	//	... loading buffer
		}
		if(TX2_END) {							//	if tx end ...
			RES_TX2								//	... tx disable ...
			RES_TX2_ON							//	... end tx ...
			START_RX2							//	... rx enable
		}
	}
	else if(RX2_ON) {
		if(RX2_ERR)								//	if errors ...
			START_RX2							//	... re-start
		else if(RX2_FULL) {						//	if data received ...
			RES_RX2_FULL						//	... reset flag ...
			SET_RX2_INI							//	... rx begun flag setting ...
			rtx2_tim = RX2_TIM;					//	... delay timer reset ...
			if(rtx2_cnt < RTX2_LEN)				//	... if enough space ...
				rtx2_buf[rtx2_cnt++] = RX2_REG;	//		... received data saving ...
			else {								//	... if no space ...
				RES_RX2							//		... rx disable ...
				RES_RX2_ON						//		... rx end
			}
		}
		else if(RX2_INI) {						//	if rx begun ...
			if(rtx2_tim > 0)					//	... if still time ...
				--rtx2_tim;						//		... wait
			else {								//	... if delay elapsed ...
				RES_RX2							//		... rx disable ...
				RES_RX2_ON						//		... end rx
			}
		}
	}
}

void ges_232_pc(void)
/******************************************************************************
* Function Name: ges_232_pc
* Description  : serial communication management
* Arguments    : none
* Return Value : none
* Note         : to be called in the main loop;
*                the slave is always waiting for commands (reception)
*                when a commend is received, it is decoded and, if it make sense,
*                executed; if the command is correctly received or if the errors
*                are in the data or in the addresses, the slave send an answer.
******************************************************************************/
{
	static unsigned short	add, nda, i, tot;

//	if(GO_TX2) {
//		RES_GO_TX2
//		START_TX2
//	}
//	else
	if(RX2_INI && RX2_OFF) {	// end RX: decoding and start TX
		RES_RX2_INI					// reset flag

		// no answer cases
		rtx2_num=rtx2_buf[IND_LEN];
		if(	(rtx2_num<LEN_MIN) 				||
			(rtx2_num>rtx2_cnt) 			||
			(rtx2_buf[IND_SEL]!=SEL_MAS) 	||
			(rtx2_buf[IND_ADS]!=N_CENT)		) {
			START_RX2
			return;
		}
		if(rtx2_buf[rtx2_num-1]!=cal_crc((rtx2_num-1), rtx2_buf)) {
			START_RX2
			return;
		}

		// operation codes select and answer coding
		SET_RTX2_ON							// flag communication on
		rtx2_buf[IND_SEL]=SEL_SLA;
	    rtx2_num = LEN_MIN;					// frame lenght
		switch(rtx2_buf[IND_COD]) {
			case CCO:	// check
			case NCO:	// check
			case XCO:	// check
				rtx2_buf[IND_COD] = XCO;		// answer of programs with auto tuning
				break;
			case RWO:	// answer coding
				add=rtx2_buf[IND_ADD];
				nda=rtx2_buf[IND_ND];
				if(add<NUM_PAR) {		// reading from parameters table
					if((nda>NUM_PAR) || (add>(NUM_PAR-nda))) {
						rtx2_buf[IND_SEL]=SEL_NOK;
						break;
					}
					for(i=0; i<nda; i++)
						w2b(par_vec[add+i], &(rtx2_buf[IND_ID+(i<<1)]));
				    rtx2_num += LEN_DEL + (nda << 1);// frame lenght
				}
				else {						// reading from ram table
					add-=NUM_PAR;
					if((nda>N_RAM_READ) || (add>(N_RAM_READ-nda))) {
						rtx2_buf[IND_SEL]=SEL_NOK;
						break;
					}
					for(i=0; i<nda; i++)
						w2b(UIF_R.ram_tab[add+i], &(rtx2_buf[IND_ID+(i<<1)]));
				    rtx2_num += LEN_DEL + (nda << 1);// frame lenght
				}
				break;
			case WWO:	// answer coding
				add=rtx2_buf[IND_ADD];
				nda=rtx2_buf[IND_ND];
				if(add<NUM_PAR) {		// writing in parameters table
					if((nda>NUM_PAR) || (add>(NUM_PAR-nda))) {
						rtx2_buf[IND_SEL]=SEL_NOK;
						break;
					}
					for(i=0; i<nda; i++) {
						dta_par=b2w(&(rtx2_buf[IND_ID+(i<<1)]));
						add_par=add+i;
						if(par_vec[add_par]!=dta_par)
							eqp_set_par(dta_par, add_par);
					}
					dta_par=0;
					add_par=0;
				}
				else {						// writing in ram table
					add-=NUM_PAR;
					if((nda>N_RAM_WRITE) || (add>(N_RAM_WRITE-nda))) {
						rtx2_buf[IND_SEL]=SEL_NOK;
						break;
					}
					for(i=0; i<nda; i++)
						UIF_W.ram_tab[add+i]=b2w(&(rtx2_buf[IND_ID+(i<<1)]));
				}
				break;
			case RW3:	// reading parameters minimum values
				add=rtx2_buf[IND_ADD];
				nda=rtx2_buf[IND_ND];
				if((add>=NUM_PAR) || (nda>(NUM_PAR-add))) {
					rtx2_buf[IND_SEL]=SEL_NOK;
					break;
				}
				for(i=0; i<nda; i++)
					w2b(par_min[add+i], &(rtx2_buf[IND_ID+(i<<1)]));
			    rtx2_num+=LEN_DEL;
			    rtx2_num+=nda<<1;
				break;
			case RW4:	// reading parameters maximum values
				add=rtx2_buf[IND_ADD];
				nda=rtx2_buf[IND_ND];
				if((add>=NUM_PAR) || (nda>(NUM_PAR-add))) {
					rtx2_buf[IND_SEL]=SEL_NOK;
					break;
				}
				for(i=0; i<nda; i++)
					w2b(par_max[add+i], &(rtx2_buf[IND_ID+(i<<1)]));
			    rtx2_num+=LEN_DEL;
			    rtx2_num+=nda<<1;
				break;
			case RW5:	// reading measurement samples
				add=rtx2_buf[IND_ADD];
				nda=rtx2_buf[IND_ND];
				if((add>=OUTBUF_SDIM) || (nda>(OUTBUF_SDIM-add))) {
					rtx2_buf[IND_SEL]=SEL_NOK;
					break;
				}
				if(add==0) {
					SET_RBUSY
					tot=0;
				}
				for(i=0; i<nda; i++)
					w2b(rbuf[add+i], &(rtx2_buf[IND_ID+(i<<1)]));
				tot+=nda;
				if(tot>=125)
					RES_RBUSY
			    rtx2_num+=LEN_DEL;
			    rtx2_num+=nda<<1;
				break;
			default:
				rtx2_buf[IND_SEL]=SEL_NOK;
				break;
		}

		// crc calc. and answer transmission
		rtx2_buf[IND_LEN]=rtx2_num;
		rtx2_buf[rtx2_num-1]=cal_crc(rtx2_num-1, rtx2_buf);
		rtx2_buf[rtx2_num] = 0;			// ("C" string)
//		SET_GO_TX2
		START_TX2
		return;
    }

}

void ges_led(void)
/******************************************************************************
* Function Name: ges_led
* Description  : led blinking management
* Arguments    : none
* Return Value : none
* Note         : to be called in the main loop
******************************************************************************/
{
	static unsigned short led_cnt;

	switch(UIF_R.var.all) {
		case 0:
			CLR_DL2
			if(led_cnt<LED_TIME_FUN)
				++led_cnt;
			else {
				led_cnt=0;
				if(DL1_OFF) {
					SET_DL1
				}
				else {
					CLR_DL1
				}
			}
			break;
		default:
			CLR_DL1
			if(led_cnt<LED_TIME_ALL)
				++led_cnt;
			else {
				led_cnt=0;
				if(DL2_OFF) {
					SET_DL2
				}
				else {
					CLR_DL2
				}
			}
			break;
	}
}

