
/*******************************************************************************
*	DISCLAIMER
*
*	THIS SOFTWARE IS PROVIDED "AS IS" AND BFG ENGINEERING MAKES NO WARRANTIES
*	REGARDING THIS SOFTWARE, WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING
*	BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
*	PURPOSE AND NON-INFRINGEMENT. ALL SUCH WARRANTIES ARE EXPRESSLY DISCLAIMED.
*
*	WE (BFG ENGINEERING) DO NOT WARRANT THAT THIS SOFTWARE IS FREE FROM CLAIMS
*	BY A THIRD PARTY OF COPYRIGHT, PATENT, TRADEMARK, TRADE SECRET OR ANY OTHER
*	INTELLECTUAL PROPERTY INFRINGIMENT.
*
*	TO THE MAXIMUM EXTENT PERMITTED NOT PROHIBITED BY LAW, BFG ENGINEERING
*	SHALL NOT BE LIABLE FOR ANY DIRECT, INDIRECT, SPECIAL, INCIDENTAL OR
*	CONSEQUENTIAL DAMAGES FOR ANY REASON RELATED TO THIS SOFTWARE, EVEN IF BFG
*	ENGINEERING HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
*	PARTICULARLY, UNDER NO CIRCUMSTANCES ARE WE LIABLE FOR ANY OF THE FOLLOWING:
*	- THIRD PARTY CLAIMS AGAINST YOU FOR LOSSES OR DAMAGES;
*	- LOSS OF, OR DAMAGE TO YOUR RECORDS OR DATA; OR
*	- ECONOMIC CONSEQUENTIAL DAMAGES (INCLUDING LOST PROFITS OR SAVINGS) OR
*	  INCIDENTAL DAMAGES, EVEN IF WE ARE INFORMED OF THEIR POSSIBILITY.
*
*	BFG ENGINEERING DOES NOT WARRANT UNINTERRUPTED OR ERROR_FREE OPERATION OF
*	THIS SOFTWARE.
*	BFG ENGINEERING HAS NO OBLIGATION TO PROVIDE SERVICE, DEFECT CORRECTION OR
*	ANY MANTEINANCE OF THIS SOFTWARE; OR TO SUPPLY ANY UPDATES OR ENHANCEMENTS
*	EVEN IF SUCH ARE, OR LATER BECOME, AVAILABLE.
*
*	IF YOU DOWNLOAD OR USE THIS SOFTWARE YOU AGREE TO THESE TERMS, AND DO IT AT
*	YOUR OWN RISK.
*******************************************************************************/

/*******************************************************************************
*	File:		PI_tun.h
*	Project:	MCRP07 RX62T
*	Revision:	7
*	Date:		25-10-2013 (DD-MM-YYYY)
*	Author:		Andrea Ghirardello
*	Contents:	Header for PI_tun.c
*******************************************************************************/

#ifndef _PI_TUN_H
#define _PI_TUN_H

/*******************************************************************************
Function:		PIT_IniVar
Description:	internal variables init
Input:			is current step amplitude [A]
				vn nominal bus voltage [V]
				sp sampling period [sec]
Output:			nothing
Revision:		1.0
*******************************************************************************/
void PIT_IniVar(float is, float vn, float sp);

/*******************************************************************************
Function:		PIT_SetCur
Description:	measurement setting routine; it is needed to pass to the
				tuning algorithm the currents measurements
Input:			id d current measurement [A]
				iq q current measurement [A]
Output:			nothing
Revision:		1.0
*******************************************************************************/
void PIT_SetCur(float id, float iq);

/*******************************************************************************
Function:		PIT_RampUp
Description:	voltage ramp up
Input:			*v voltage reference address
Output:			1 if final level is reached, 0 otherwise
Modifies:		v voltage reference [V]
Revision:		1.0
*******************************************************************************/
unsigned short PIT_RampUp(float *v);

/*******************************************************************************
Function:		PIT_Measure
Description:	waiting routine, when delay elapsed takes the measurements
				samples
Input:			*v voltage reference address
Output:			1 if delay elapsed, 0 otherwise
Modifies:		v voltage reference [V]
Revision:		1.0
*******************************************************************************/
unsigned short PIT_Measure(float *v);

/*******************************************************************************
Function:		PIT_RampDown
Description:	voltage ramp down
Input:			*v voltage reference address
Output:			1 if final level is reached, 0 otherwise
Modifies:		v voltage reference [V]
Revision:		1.0
*******************************************************************************/
unsigned short PIT_RampDown(float *v);

/*******************************************************************************
Function:		PIT_VoltStep
Description:	voltage step
Input:			*v voltage reference address
Output:			1 if measurements finished, 0 otherwise
Modifies:		v voltage reference [V]
Revision:		1.0
*******************************************************************************/
unsigned short PIT_VoltStep(float *v);

/*******************************************************************************
Function:		PIT_ReadKP
Description:	output routine (it returns the calculated kp value)
Input:			nothing
Output:			proportional gain
Revision:		1.0
*******************************************************************************/
float PIT_ReadKP(void);

/*******************************************************************************
Function:		PIT_ReadKI
Description:	output routine (it returns the calculated ki value)
Input:			nothing
Output:			integral gain
Revision:		1.0
*******************************************************************************/
float PIT_ReadKI(void);

#endif	// _PI_TUN_H
