
/*******************************************************************************
*	DISCLAIMER
*
*	THIS SOFTWARE IS PROVIDED "AS IS" AND BFG ENGINEERING MAKES NO WARRANTIES
*	REGARDING THIS SOFTWARE, WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING
*	BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
*	PURPOSE AND NON-INFRINGEMENT. ALL SUCH WARRANTIES ARE EXPRESSLY DISCLAIMED.
*
*	WE (BFG ENGINEERING) DO NOT WARRANT THAT THIS SOFTWARE IS FREE FROM CLAIMS
*	BY A THIRD PARTY OF COPYRIGHT, PATENT, TRADEMARK, TRADE SECRET OR ANY OTHER
*	INTELLECTUAL PROPERTY INFRINGIMENT.
*
*	TO THE MAXIMUM EXTENT PERMITTED NOT PROHIBITED BY LAW, BFG ENGINEERING
*	SHALL NOT BE LIABLE FOR ANY DIRECT, INDIRECT, SPECIAL, INCIDENTAL OR
*	CONSEQUENTIAL DAMAGES FOR ANY REASON RELATED TO THIS SOFTWARE, EVEN IF BFG
*	ENGINEERING HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
*	PARTICULARLY, UNDER NO CIRCUMSTANCES ARE WE LIABLE FOR ANY OF THE FOLLOWING:
*	- THIRD PARTY CLAIMS AGAINST YOU FOR LOSSES OR DAMAGES;
*	- LOSS OF, OR DAMAGE TO YOUR RECORDS OR DATA; OR
*	- ECONOMIC CONSEQUENTIAL DAMAGES (INCLUDING LOST PROFITS OR SAVINGS) OR
*	  INCIDENTAL DAMAGES, EVEN IF WE ARE INFORMED OF THEIR POSSIBILITY.
*
*	BFG ENGINEERING DOES NOT WARRANT UNINTERRUPTED OR ERROR_FREE OPERATION OF
*	THIS SOFTWARE.
*	BFG ENGINEERING HAS NO OBLIGATION TO PROVIDE SERVICE, DEFECT CORRECTION OR
*	ANY MANTEINANCE OF THIS SOFTWARE; OR TO SUPPLY ANY UPDATES OR ENHANCEMENTS
*	EVEN IF SUCH ARE, OR LATER BECOME, AVAILABLE.
*
*	IF YOU DOWNLOAD OR USE THIS SOFTWARE YOU AGREE TO THESE TERMS, AND DO IT AT
*	YOUR OWN RISK.
*******************************************************************************/

/*******************************************************************************
*	File:		customize.h
*	Project:	MCRP07 RX62T
*	Revision:	7.0
*	Date:		25-10-2013 (DD-MM-YYYY)
*	Author:		Andrea Ghirardello
*	Contents:	Custom values definition
*******************************************************************************/

#ifndef	_CUSTOMIZE_H
#define _CUSTOMIZE_H

// eeprom (comment if not used)
#define EEPROM_USED

// debug (comment after first control)
//#define MACRO_DEBUG

// open loop debug (comment in final release)
#define DEBUG_OPENLOOP

// DC current vector setting debug mode (comment in final release)
//#define DCCUR_SETTING

// ADDITIONAL FEATURE: current PI manual tuning (comment if not used)
#define CPI_TUN

// ADDITIONAL FEATURE: current PI automatic tuning (comment if not used)
#define CPI_AUT

// ADDITIONAL FEATURE: motor parameters auto-identification (comment if not used)
#define MOT_IDENT

// ADDITIONAL FEATURE: oscilloscope window in GUI management (comment if not used)
#define OSC_WIN

// sampling period and modulation setting
// NOTE: This relation MUST be satisfied: PWM_FREQ_CUSTOM=N*SAM_FREQ_CUSTOM where 1<=N<=8
#define	PWM_FREQ_CUSTOM		16000	// PWM Frequency [Hz], 2000<=PWM_FREQ_CUSTOM<=20000
#define	SAM_FREQ_CUSTOM		16000	// Sampling Frequency [Hz], 2000<=SAM_FREQ_CUSTOM<=20000

// lower arms ON when not rotating
//#define DEF_LOW_ON

// PI gains amplification
#define AMP_KPCUR			4.0f
#define UAMP_KICUR			128.0f
#define AMP_KICUR			((float)(1.0/UAMP_KICUR))	// 0.0078125f
#define AMP_KPVEL			16384.0f
#define AMP_KIVEL			2048.0f

// parameters measurement units resolution
#define	AMP_RES				1000.0f	// current parameters expressed in ampere/AMP_RES
#define	VOL_RES				10.0f	// voltage parameters expressed in volt/VOL_RES
#define	OHM_RES				100.0f	// resistance parameters expressed in ohm/OHM_RES
#define	HEN_RES				10000.0f// inductance parameters expressed in henry/HEN_RES
#define	WEB_RES				10000.0f// flux parameters expressed in weber/WEB_RES

// FL28BL38-HS motor default parameters
#define	RPM_MIN_DEF			3000	//  200 < X <  5000	// min speed in rpm
#define	RPM_MAX_DEF			13000	// 1000 < X < 20000	// max speed in rpm
#define	R_ACC_DEF			2000	//    1 < X < 10000	// accel. ramp in rpm/sec
#define	R_DEC_DEF			2000	//    1 < X < 10000	// accel. ramp in rpm/sec
#define	C_POLI_DEF			2		//    1 < X <    24	// polar couples number
#define	I_START_DEF			200		//    0 < X < 15000	// startup current in A(pk)/AMP_DIV
#define	I_MAX_DEF			400		//    0 < X < 15000	// max current in A(pk)/AMP_DIV
#define	R_STA_DEF			220		//    0 < X < 30000	// stator phase resistance in Ohm/OHM_DIV
#define	L_SYN_DEF			25		//    0 < X < 30000	// synchronous inductance in Henry/HEN_DIV
#define PM_FLX_DEF			30		//	  0 < X < 30000 // permanent magnet flux in Weber/WEB_DIV
#define	KP_CUR_DEF			20		//    0 < X < 30000	// K prop. current control
#define	KI_CUR_DEF			120		//    0 < X < 30000	// K integ. current control
#define	KP_VEL_DEF			50		//    0 < X < 30000	// K prop. speed control
#define	KI_VEL_DEF			100		//    0 < X < 30000	// K integ. speed control
#define	FB_GAIN_DEF			500		//    0 < X < 30000	// flux amplitude feedback gain
#define PHA_OFF_DEF			0		//	  0 < X < 360	// offset angle

/*
// MB057GA240 motor default parameters
#define	RPM_MIN_DEF			400		//  200 < X <  5000	// min speed in rpm
#define	RPM_MAX_DEF			3000	// 1000 < X < 20000	// max speed in rpm
#define	R_ACC_DEF			1000	//    1 < X < 10000	// accel. ramp in rpm/sec
#define	R_DEC_DEF			1000	//    1 < X < 10000	// accel. ramp in rpm/sec
#define	C_POLI_DEF			2		//    1 < X <    24	// polar couples number
#define	I_START_DEF			1000	//    0 < X < 15000	// startup current in A(pk)/AMP_RES
#define	I_MAX_DEF			3000	//    0 < X < 15000	// max current in A(pk)/AMP_RES
#define	R_STA_DEF			70		//    0 < X < 30000	// stator phase resistance in Ohm/OHM_RES
#define	L_SYN_DEF			20		//    0 < X < 30000	// synchronous inductance in Henry/HEN_RES
#define PM_FLX_DEF			260		//	  0 < X < 30000 // permanent magnet flux in Weber/WEB_DIV
#define	KP_CUR_DEF			50		//    0 < X < 30000	// K prop. current control
#define	KI_CUR_DEF			100		//    0 < X < 30000	// K integ. current control
#define	KP_VEL_DEF			30		//    0 < X < 30000	// K prop. speed control
#define	KI_VEL_DEF			400		//    0 < X < 30000	// K integ. speed control
#define	FB_GAIN_DEF			100		//    0 < X < 30000	// flux amplitude feedback gain
#define PHA_OFF_DEF			0		//	  0 < X < 360	// offset angle
*/

// startup timing definitions
#define STUP_CUR_RT_MS		1000	// current rising time during startup alignment [ms]
#define STUP_SPE_RT_MS		1000	// speed rising time (from 0 to min speed) during startup [ms]
#define STUP_CUR_FT_MS		1000	// d current falling time after startup [ms] (assuming id=i_start)

// rotation direction
//#define ROT_REV

// modulation
#define DTC_REF						// uses current references in calculations (else uses measurements)
//#define ICOMP						// uses the currents to compensate modulation
#define CENTERED					// centered modulation
//#define OVERMOD					// overmodulation

// inverter non-linearities compensation
#define INLCOMP						// inverter non linearities compensation
//#define INL_DET					// non-linearity table determination (comment in final release)

// other control parameters
#define MAXERR_RPM			300.0f	// maximum error for ramp limitation and PI clamping
#define K_MARGV0			0.90f	// max_d_volt/max_volt ratio

// speed PI error clamping
#define SPEEDPI_ERRCLAMP			// input to speed PI is clamped to MAXERR_RPM

// DC bus voltage limit for ramp limitation
//#define VB_RAMP					// comment this to avoid ramp limitation due to vbus
#define VBUS_LIM			36.0f	// dc bus voltage limit [V]
#define VBUS_LIMH			38.0f	// dc bus voltage limit [V]
#define VBUS_LIML			36.0f	// dc bus voltage limit [V]
#define K_RAMPLIM			0.9f	// ramp limitation gain

// ramp clamp (comment if you don't want it)
#define RAMP_CL0					// clamp if heavy speed error

// flux weakening
#define FLUXWEAK					// comment to avoid flux weakening
#define K_MARGV1			0.95f	// percent of available voltage at which FW begins
#define K_MARGI0			0.80f	// max_d_cur/max_cur ratio
#define DCUR_DT				1.50f	// d current variation rate [A/s] during FW

// speed lowpass filter cut-off frequency f0 (time constant will be tau=(1/w0)=(1/(2PIf0)
#define	SPEED_LP_CUTOFF_HZ	100.0f	// cut-off frequency [Hz]

// flux estimation method selection
//#define APP_INT					// uncomment this if you prefer approximated integration

#endif		// _CUSTOMIZE_H

