
/*******************************************************************************
*	DISCLAIMER
*
*	THIS SOFTWARE IS PROVIDED "AS IS" AND BFG ENGINEERING MAKES NO WARRANTIES
*	REGARDING THIS SOFTWARE, WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING
*	BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
*	PURPOSE AND NON-INFRINGEMENT. ALL SUCH WARRANTIES ARE EXPRESSLY DISCLAIMED.
*
*	WE (BFG ENGINEERING) DO NOT WARRANT THAT THIS SOFTWARE IS FREE FROM CLAIMS
*	BY A THIRD PARTY OF COPYRIGHT, PATENT, TRADEMARK, TRADE SECRET OR ANY OTHER
*	INTELLECTUAL PROPERTY INFRINGIMENT.
*
*	TO THE MAXIMUM EXTENT PERMITTED NOT PROHIBITED BY LAW, BFG ENGINEERING
*	SHALL NOT BE LIABLE FOR ANY DIRECT, INDIRECT, SPECIAL, INCIDENTAL OR
*	CONSEQUENTIAL DAMAGES FOR ANY REASON RELATED TO THIS SOFTWARE, EVEN IF BFG
*	ENGINEERING HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
*	PARTICULARLY, UNDER NO CIRCUMSTANCES ARE WE LIABLE FOR ANY OF THE FOLLOWING:
*	- THIRD PARTY CLAIMS AGAINST YOU FOR LOSSES OR DAMAGES;
*	- LOSS OF, OR DAMAGE TO YOUR RECORDS OR DATA; OR
*	- ECONOMIC CONSEQUENTIAL DAMAGES (INCLUDING LOST PROFITS OR SAVINGS) OR
*	  INCIDENTAL DAMAGES, EVEN IF WE ARE INFORMED OF THEIR POSSIBILITY.
*
*	BFG ENGINEERING DOES NOT WARRANT UNINTERRUPTED OR ERROR_FREE OPERATION OF
*	THIS SOFTWARE.
*	BFG ENGINEERING HAS NO OBLIGATION TO PROVIDE SERVICE, DEFECT CORRECTION OR
*	ANY MANTEINANCE OF THIS SOFTWARE; OR TO SUPPLY ANY UPDATES OR ENHANCEMENTS
*	EVEN IF SUCH ARE, OR LATER BECOME, AVAILABLE.
*
*	IF YOU DOWNLOAD OR USE THIS SOFTWARE YOU AGREE TO THESE TERMS, AND DO IT AT
*	YOUR OWN RISK.
*******************************************************************************/

/*******************************************************************************
*	File:		ges_eqp.c
*	Project:	MCRP07 RX62T
*	Revision:	7.0
*	Date:		25-10-2013 (DD-MM-YYYY)
*	Author:		Andrea Ghirardello
*	Contents:	Eeprom management functions
*******************************************************************************/

#include "globdef.h"		// include globdef.h BEFORE including ges_eqp.h
#include "ges_eqp.h"

#ifdef EEPROM_USED

#define MAX_WAIT	50		// 50 ms
#define	NL_W_EQP	 5		// 5*10ms=50ms max
#define	MS00005		9U		// constant corresponding to 0.00054 ms @100MHz

void eqp_hw_ini();
unsigned short eqp_busy(void);
unsigned short eqp_read_word(unsigned short, unsigned short *);
unsigned short eqp_write_word(unsigned short, unsigned short);

#define	NUM_FIFO_EQP		NUM_PAR+10		// eqp fifo dimension
unsigned short
	eqp_fifo[NUM_FIFO_EQP],	// fifo valori eqp da aggiornare tramite seriale
	eqp_add[NUM_FIFO_EQP];	// fifo indirizzi eqp da aggiornare tramite seriale
unsigned short
	eqp_all=0,
	mas_ind=0,				// indice master su fifo
	sla_ind=0;				// indice slave su fifo
signed short
	modif=-1;
unsigned short
	eqp_wrt=0,
	eqp_bsy=0,
	eqp_aus=0;

void eqp_del(unsigned long time)
/*******************************************************************************
*	Description:	delay
*******************************************************************************/
{
	unsigned long	i;

	for(; time>0; --time)
		for(i=MS00005; i>0; --i)
			nop();
}

void ini_eqp(void)
/*******************************************************************************
*	Description:	hardware init if needed
*******************************************************************************/
{
	eqp_hw_ini();
}

unsigned short def_to_ram(void)
/*******************************************************************************
*	Description:	copies default parameters into ram
*	Returns:		=0->ok, !=0->nok
*******************************************************************************/
{
	unsigned short i;

	for(i=0; i<NUM_PAR; i++) {
/*	EQP_DEBUG
		if(par_min[i]>par_max[i]) {
			par_vec[i]=par_def[i];
			eqp_all=1;
		}
		else if(par_def[i]<par_min[i]) {
			par_vec[i]=par_min[i];
			eqp_all=1;
		}
		else if(par_vec[i]>par_max[i]){
			par_vec[i]=par_max[i];
			eqp_all=1;
		}
EQP_DEBUG */
		par_vec[i]=par_def[i];
	}
	return(eqp_all=0);
}

unsigned short wait_busy(unsigned short max_time)
/*******************************************************************************
*	Description:	wait if eeprom is busy, for a max of max_time delays
*	Note:			to be used out of main loop, due to the high delay
*	Returns:		=0->ok, !=0->nok
*******************************************************************************/
{
	if(eqp_all)
		return(eqp_all);
	while(eqp_busy()) {
		if(max_time!=0) {
			eqp_del(2000);
			--max_time;
		}
		else
			return(eqp_all=1);
	}
	return(0);
}

unsigned short ram_to_eqp(void)
/*******************************************************************************
*	Description:	copies all the parameters from ram to eeprom
*	Note:			to be used out of main loop, due to the high delay
*	Returns:		=0->ok, !=0->nok
*******************************************************************************/
{
	static unsigned short i;

	// wait if busy
	if(wait_busy(MAX_WAIT))
		return(eqp_all);

	// read/write cycle
	for(i=0; i<NUM_PAR; i++) {
		if(eqp_read_word(PAR_ADD(i), &eqp_aus))
			return(eqp_all=1);
		if(par_vec[i]!=eqp_aus) {
			if(eqp_write_word(PAR_ADD(i), par_vec[i]))
				return(eqp_all=1);
			if(wait_busy(MAX_WAIT))
				return(eqp_all);
			if(eqp_read_word(PAR_ADD(i), &eqp_aus))
				return(eqp_all=1);
			if(par_vec[i]!=eqp_aus)
				return(eqp_all=1);
		}
	}
	return(eqp_all=0);
}

unsigned short eqp_to_ram(void)
/*******************************************************************************
*	Description:	if par0!=RIP_DEF copies all parameters from eeprom to
*					ram, else copies all default values in ram parameter
*					table, then copies all the parameters from ram to eeprom
*	Note:			to be used out of main loop, due to the high delay
*	Returns:		=0->ok, !=0->nok
*******************************************************************************/
{
	unsigned short	i;

	// wait if busy
	if(wait_busy(MAX_WAIT))
		return(eqp_all);

	// par 0 reading
	if(eqp_read_word(PAR_ADD(0), &eqp_aus))
		return(eqp_all=1);

	// default values restoration if requested, or special modes reset
	if((eqp_aus==RIP_DEF) || (eqp_aus==65535)) {
		for(i=0; i<NUM_PAR; i++)
			par_vec[i]=par_def[i];
		if(ram_to_eqp())
			return(eqp_all=1);
	}
	else if(eqp_aus!=0) {
		eqp_aus=0;
		if(eqp_write_word(PAR_ADD(0), eqp_aus))
			return(eqp_all=1);
		if(wait_busy(MAX_WAIT))
			return(eqp_all);
		if(eqp_read_word(PAR_ADD(0), &eqp_aus))
			return(eqp_all=1);
		if(eqp_aus!=0)
			return(eqp_all=1);
	}
	par_vec[0]=eqp_aus;

	// parameters reading
	for(i=1; i<NUM_PAR; i++) {
		if(eqp_read_word(PAR_ADD(i), &eqp_aus))
			return(eqp_all=1);
		if(eqp_aus<par_min[i])
			return(eqp_all=1);
		if(eqp_aus>par_max[i])
			return(eqp_all=1);
		par_vec[i]=eqp_aus;
	}
	return(eqp_all);
}

unsigned short agg_eqp(void)
/*******************************************************************************
*	Description:	copies a modified parameter from ram to eeprom
*	Note:			to be called in main loop
*	Returns:		=0->ok, !=0->nok
*******************************************************************************/
{
	if(modif<0)
		return(eqp_all);
	if(eqp_bsy) {
		if(eqp_busy()) {
			if((--eqp_bsy)==0)
				goto agg_eqp_err;
			return(eqp_all);
		}
		eqp_bsy=0;
		if(eqp_read_word(PAR_ADD(modif), &eqp_aus))
			goto agg_eqp_err;
		if(par_vec[modif]!=eqp_aus)
			goto agg_eqp_err;
	}
	else if( (modif==0) || ( (modif<NUM_PAR) && (eqp_all==0) ) ) {
		if(eqp_read_word(PAR_ADD(modif), &eqp_aus))
			goto agg_eqp_err;
		else if(par_vec[modif]!=eqp_aus) {
			if(eqp_write_word(PAR_ADD(modif), par_vec[modif]))
				goto agg_eqp_err;
			eqp_bsy=NL_W_EQP;
			return(eqp_all);
		}
	}
	modif=-1;
	return(eqp_all);
agg_eqp_err:
	modif=-1;
	return(eqp_all=1);
}

void eqp_set_par(unsigned short val, unsigned short add)
/***************************************************************************
*	Description: insertion of a parameter in eqp fifo, to be updated
***************************************************************************/
{
	eqp_fifo[mas_ind]=val;
	eqp_add[mas_ind++]=add;
	if(mas_ind>=NUM_FIFO_EQP)
		mas_ind=0;
	return;
}

unsigned short ges_eqp()
/***************************************************************************
*	Description: eeprom parameters modification management
*	Note:			to be called in main loop
*	Returns:		=0->ok, !=0->nok
***************************************************************************/
{
	static unsigned short	stato, eqpbusy1;
	unsigned short			pnum, indice;

#define	NOR_0	10
#define	MOD_0	20

	switch(stato) {
		case	NOR_0:
			if((sla_ind!=mas_ind) && ((eqp_all==0) || (eqp_add[sla_ind]==0))) {
				pnum=eqp_fifo[sla_ind];
				indice=eqp_add[sla_ind];
				eqp_fifo[sla_ind]=0;
				eqp_add[sla_ind]=0;
				if(sla_ind<(NUM_FIFO_EQP-1))
					++sla_ind;
				else
					sla_ind=0;
				if((indice==IND_EQP_SEL_OP) && (pnum!=0) && (pnum!=RIP_DEF)) {
					par_vec[indice]=pnum;	// modif not touched, no eeprom operations
				}
				else if((pnum>=par_min[indice]) && (pnum<=par_max[indice])) {
					par_vec[indice]=pnum;
					modif=indice;
					eqpbusy1=4;
					stato=MOD_0;
				}
			}
			break;
		case	MOD_0:
			if(modif>=0) {
				if(eqpbusy1>0) {
					--eqpbusy1;
					break;
				}
				else
					return(eqp_all=1);
			}
			// no break;
		default:
			stato=NOR_0;
			break;
	}

	// eeprom management
	return(agg_eqp());

}

/* management functions for iic eeprom ****************************************/

/* Hardware notes **************************************************************
	Since used micro's ports are input or push_pull outputs, to interface an
	IIC eeprom the following strategy is used:
	_	a port of the micro (EEPSCL) is used as clock output and is directly
		connected with the SCL input of the eeprom;
	_	the SDA I/O of the eeprom is connected to a pull-up resistor and to a
		port (EEPSDA) of the micro;
	_	to read a data bit or to write a HIGH data bit the EEPSDA port is
		configured as input.
	_	to write a LOW data bit the EEPSDA port is configured as output and
		it is forced to zero.
*******************************************************************************/

	// I/O settings
	//PORTE.DR.BIT.B1=1;		// PIN16 PE1 DIG OUT EEPSCL_UP16
	//PORTE.DR.BIT.B0=1;		// PIN17 PE0 DIG I/O EEPSDA_UP17
	//PORTE.DDR.BIT.B1=0;		// PIN16 PE1 DIG OUT EEPSCL_UP16
	//PORTE.DDR.BIT.B0=0;		// PIN17 PE0 DIG I/O EEPSDA_UP17
	//PORTE.ICR.BIT.B1=0;		// PIN16 PE1 DIG OUT EEPSCL_UP16
	//PORTE.ICR.BIT.B0=0;		// PIN17 PE0 DIG I/O EEPSDA_UP17
	//PORTE.PORT.BIT.B1			// PIN16 PE1 DIG OUT EEPSCL_UP16
	//PORTE.PORT.BIT.B0			// PIN17 PE0 DIG I/O EEPSDA_UP17

#define	EEPSCL			PORTE.DR.BIT.B1
#define	EEPSDA			PORTE.DR.BIT.B0
#define	EEPSDAIN		PORTE.PORT.BIT.B0
#define	SCLIOC			PORTE.DDR.BIT.B1
#define	SDAIOC			PORTE.DDR.BIT.B0

#define PUT_SCL_OUT		SCLIOC=1;
#define PUT_SCL_IN		SCLIOC=0;
#define PUT_SDA_OUT		SDAIOC=1;
#define PUT_SDA_IN		SDAIOC=0;
#define	SET_SCL			EEPSCL=1;
#define	CLR_SCL			EEPSCL=0;
#define SET_SDA			PUT_SDA_IN
#define CLR_SDA			{PUT_SDA_OUT EEPSDA=0;}
#define	SDA_IN_H		(EEPSDAIN!=0)
#define	SDA_IN_L		(EEPSDAIN==0)

#define	WAIT_SCL		eqp_del(2);			// clock half period: minimum 1.25 microsec

#define	CODE_ADD_W		0xA0U				// 1010=CODE 000=ADD 0=WRITE
#define	CODE_ADD_R		0xA1U				// 1010=CODE 000=ADD 1=READ

// If the eeprom has a 2 bytes addressing please remove the comment in the following
// define, else if the eeprom has a 1 byte addressing please comment it
//#define	ADD2BYTES

// Routines are called with SCL=0 and SDA=1; they leave the same situation on exit

void eqp_hw_ini(void)
/*******************************************************************************
*	Description:	hardware initialization
*******************************************************************************/
{
	// I/O settings
	PUT_SCL_OUT
	CLR_SCL
	SET_SDA
}

void send_start(void)
/*******************************************************************************
*	Description:	sends start sequence
*******************************************************************************/
{
	CLR_SCL				// for safety
	SET_SDA				// for safety
	WAIT_SCL
	SET_SCL
	WAIT_SCL
	CLR_SDA
	WAIT_SCL
	CLR_SCL
	SET_SDA
}

void send_stop(void)
/*******************************************************************************
*	Description:	sends stop sequence
*******************************************************************************/
{
	CLR_SCL				// for safety
	CLR_SDA
	WAIT_SCL
	SET_SCL
	WAIT_SCL
	SET_SDA
	WAIT_SCL
	CLR_SCL
}

unsigned short send_byte(unsigned char byt)
/*******************************************************************************
*	Description:	sends a byte
*	Returns:		=0->ok, !=0->nok
*******************************************************************************/
{
	unsigned char i;

	CLR_SCL				// for safety
	for(i=0; i<8; i++, byt<<=1) {
		if(byt & 0x80)
			SET_SDA
		else
			CLR_SDA
		WAIT_SCL
		SET_SCL
		WAIT_SCL
		CLR_SCL
	}
	SET_SDA
	WAIT_SCL
	SET_SCL
	WAIT_SCL
	if(SDA_IN_L) {
		CLR_SCL
		return(0);
	}
	else {
		CLR_SCL
		send_stop();
		return(1);
	}
}

unsigned char read_byte(unsigned char ack)
/*******************************************************************************
*	Description:	receive a byte
*	Returns:		read value
*******************************************************************************/
{
	unsigned char i, msk, val=0;

	CLR_SCL				// for safety
	SET_SDA				// for safety
	for(i=0, msk=0x80; i<8; i++, msk>>=1) {
		WAIT_SCL
		SET_SCL
		WAIT_SCL
		if(SDA_IN_H)
			val|=msk;
		CLR_SCL
	}
	if(ack)
		CLR_SDA
	else
		SET_SDA
	WAIT_SCL
	SET_SCL
	WAIT_SCL
	CLR_SCL
	SET_SDA
	return(val);
}

unsigned short eqp_write_word(unsigned short add, unsigned short val)
/*******************************************************************************
*	Description:	write a word data in eeprom
*	Returns:		=0->ok, !=0->nok
*******************************************************************************/
{
	unsigned char msb, lsb;

	if(add>(NUM_PAR-1))
		return(1);
	add<<=1;					// word access
	send_start();
	if(0!=send_byte(CODE_ADD_W))
		return(1);
	msb=add>>8;					// MSB of address
	lsb=add&0x00FF;				// LSB of address
#ifdef	ADD2BYTES
	if(0!=send_byte(msb))
		return(1);
#endif
	if(0!=send_byte(lsb))
		return(1);
	msb=val>>8;					// MSB of value
	lsb=val&0x00FF;				// LSB of value
	if(0!=send_byte(msb))
		return(1);
	if(0!=send_byte(lsb))
		return(1);
	send_stop();
	return(0);
}

unsigned short eqp_read_word(unsigned short add, unsigned short *val)
/*******************************************************************************
*	Description:	reads a word from eeprom
*	Returns:		=0->ok, !=0->nok
*******************************************************************************/
{
	unsigned char msb, lsb;
	unsigned short result;

	if(add>(NUM_PAR-1))
		return(1);
	add<<=1;					// word access
	send_start();
	if(0!=send_byte(CODE_ADD_W))
		return(1);
	msb=add>>8;					// MSB of address
	lsb=add&0x00FF;				// LSB of address
#ifdef	ADD2BYTES
	if(0!=send_byte(msb))
		return(1);
#endif
	if(0!=send_byte(lsb))
		return(1);
	send_start();
	if(0!=send_byte(CODE_ADD_R))
		return(1);
	msb=read_byte(1);			// MSB of value
	lsb=read_byte(0);			// LSB of value
	send_stop();
	result=msb;
	result<<=8;
	result|=lsb;
	*val=result;
	return(0);
}

unsigned short eqp_busy(void)
/*******************************************************************************
*	Description:	test busy
*	Returns:		=0->ok, !=0->busy or nok
*******************************************************************************/
{
	send_start();
	if(0!=send_byte(CODE_ADD_W))
		return(1);
	send_stop();
	return(0);
}

/* end of management functions for iic_eeprom *********************************/

#else	// EEPROM_USED
void ini_eqp(void)
{	return;	}
unsigned short ram_to_eqp(void)
{	return(0);	}
unsigned short eqp_to_ram(void)
{	return(0);	}
unsigned short ges_eqp(void)
{	return(0);	}
unsigned short def_to_ram(void)
{
	unsigned short i;

	for(i = 0; i < NUM_PAR; i++)
	{
		par_vec[i] = par_def[i];
	}
	return(eqp_all = 0);
}
void eqp_set_par(unsigned short dta, unsigned short add)
{
	if((dta < par_min[add]) || (dta > par_max[add]))
	{
		return;
	}
	par_vec[add] = dta;
}
#endif 	// EEPROM_USED


