
/*******************************************************************************
*	DISCLAIMER
*
*	THIS SOFTWARE IS PROVIDED "AS IS" AND BFG ENGINEERING MAKES NO WARRANTIES
*	REGARDING THIS SOFTWARE, WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING
*	BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
*	PURPOSE AND NON-INFRINGEMENT. ALL SUCH WARRANTIES ARE EXPRESSLY DISCLAIMED.
*
*	WE (BFG ENGINEERING) DO NOT WARRANT THAT THIS SOFTWARE IS FREE FROM CLAIMS
*	BY A THIRD PARTY OF COPYRIGHT, PATENT, TRADEMARK, TRADE SECRET OR ANY OTHER
*	INTELLECTUAL PROPERTY INFRINGIMENT.
*
*	TO THE MAXIMUM EXTENT PERMITTED NOT PROHIBITED BY LAW, BFG ENGINEERING
*	SHALL NOT BE LIABLE FOR ANY DIRECT, INDIRECT, SPECIAL, INCIDENTAL OR
*	CONSEQUENTIAL DAMAGES FOR ANY REASON RELATED TO THIS SOFTWARE, EVEN IF BFG
*	ENGINEERING HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
*	PARTICULARLY, UNDER NO CIRCUMSTANCES ARE WE LIABLE FOR ANY OF THE FOLLOWING:
*	- THIRD PARTY CLAIMS AGAINST YOU FOR LOSSES OR DAMAGES;
*	- LOSS OF, OR DAMAGE TO YOUR RECORDS OR DATA; OR
*	- ECONOMIC CONSEQUENTIAL DAMAGES (INCLUDING LOST PROFITS OR SAVINGS) OR
*	  INCIDENTAL DAMAGES, EVEN IF WE ARE INFORMED OF THEIR POSSIBILITY.
*
*	BFG ENGINEERING DOES NOT WARRANT UNINTERRUPTED OR ERROR_FREE OPERATION OF
*	THIS SOFTWARE.
*	BFG ENGINEERING HAS NO OBLIGATION TO PROVIDE SERVICE, DEFECT CORRECTION OR
*	ANY MANTEINANCE OF THIS SOFTWARE; OR TO SUPPLY ANY UPDATES OR ENHANCEMENTS
*	EVEN IF SUCH ARE, OR LATER BECOME, AVAILABLE.
*
*	IF YOU DOWNLOAD OR USE THIS SOFTWARE YOU AGREE TO THESE TERMS, AND DO IT AT
*	YOUR OWN RISK.
*******************************************************************************/

/*******************************************************************************
*	File:		motorcontrol.h
*	Project:	MCRP07 RX62T
*	Revision:	7.0
*	Date:		25-10-2013 (DD-MM-YYYY)
*	Author:		Andrea Ghirardello
*	Contents:	Header for motorcontrol.c
*******************************************************************************/

#ifndef _MOTORCONTROL_H
#define _MOTORCONTROL_H

void MC_Delay(unsigned long time);
/*******************************************************************************
*	Description:	delay
*******************************************************************************/

unsigned char MC_WaitSync(void);
/***************************************************************************
*	Description:	time synchronization control function
***************************************************************************/

void MC_StartDBPWM(void);
/***************************************************************************
*	Description:	set and start debug pwm outputs
*	Note:			DB-PWM-3 (TIOC2A) cannot be used if timer 2 is used for
*					encoder; DB-PWM-1 and DB_PWM-2 (TIOC1A and TIOC1B)
*					cannot be used if timer 1 is used for encoder
***************************************************************************/

void MC_SetDBPWM1_TP7(unsigned short val);
/***************************************************************************
*	Description:	set debug pwm output duty (no buffered operation!)
*					TP7 is the filtered output of MTIOC0D (DEB_PWM1)
***************************************************************************/

void MC_SetDBPWM2_TP5(unsigned short val);
/***************************************************************************
*	Description:	set debug pwm output duty (no buffered operation!)
*					TP5 is the filtered output of MTIOC1A (DEB_PWM2)
***************************************************************************/

void MC_SetDBPWM3_TP6(unsigned short val);
/***************************************************************************
*	Description:	set debug pwm output duty (no buffered operation!)
*					TP6 is the filtered output of MTIOC1B (DEB_PWM3)
***************************************************************************/

void MC_SetOff(void);
/***************************************************************************
*	Description:	current offsets measurement
***************************************************************************/

void MC_IniPWM(void);
/***************************************************************************
*	Description:	pwm initialization
***************************************************************************/

void MC_StartPWM(void);
/***************************************************************************
*	Description:	start pwm and main interrupt (but not the outputs)
***************************************************************************/

void MC_IniPar(void);
/***************************************************************************
*	Description:	parameters initialization
***************************************************************************/

void MC_UpdPar(void);
/***************************************************************************
*	Description:	parameters update
***************************************************************************/

void MC_ConFil(void);
/***************************************************************************
*	Description:	filtering of measured values
***************************************************************************/

void MC_WorkMan(void);
/***************************************************************************
*	Description:	working mode management routine
***************************************************************************/

void MC_ConInt(void);
/***************************************************************************
*	Description:	control interrupt
***************************************************************************/

void MC_FaultInt(void);
/***************************************************************************
*	Description:	interrupt routine for overcurrent fault
***************************************************************************/

#endif	// _MOTORCONTROL_H


