
/*******************************************************************************
*	DISCLAIMER
*
*	THIS SOFTWARE IS PROVIDED "AS IS" AND BFG ENGINEERING MAKES NO WARRANTIES
*	REGARDING THIS SOFTWARE, WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING
*	BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
*	PURPOSE AND NON-INFRINGEMENT. ALL SUCH WARRANTIES ARE EXPRESSLY DISCLAIMED.
*
*	WE (BFG ENGINEERING) DO NOT WARRANT THAT THIS SOFTWARE IS FREE FROM CLAIMS
*	BY A THIRD PARTY OF COPYRIGHT, PATENT, TRADEMARK, TRADE SECRET OR ANY OTHER
*	INTELLECTUAL PROPERTY INFRINGIMENT.
*
*	TO THE MAXIMUM EXTENT PERMITTED NOT PROHIBITED BY LAW, BFG ENGINEERING
*	SHALL NOT BE LIABLE FOR ANY DIRECT, INDIRECT, SPECIAL, INCIDENTAL OR
*	CONSEQUENTIAL DAMAGES FOR ANY REASON RELATED TO THIS SOFTWARE, EVEN IF BFG
*	ENGINEERING HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
*	PARTICULARLY, UNDER NO CIRCUMSTANCES ARE WE LIABLE FOR ANY OF THE FOLLOWING:
*	- THIRD PARTY CLAIMS AGAINST YOU FOR LOSSES OR DAMAGES;
*	- LOSS OF, OR DAMAGE TO YOUR RECORDS OR DATA; OR
*	- ECONOMIC CONSEQUENTIAL DAMAGES (INCLUDING LOST PROFITS OR SAVINGS) OR
*	  INCIDENTAL DAMAGES, EVEN IF WE ARE INFORMED OF THEIR POSSIBILITY.
*
*	BFG ENGINEERING DOES NOT WARRANT UNINTERRUPTED OR ERROR_FREE OPERATION OF
*	THIS SOFTWARE.
*	BFG ENGINEERING HAS NO OBLIGATION TO PROVIDE SERVICE, DEFECT CORRECTION OR
*	ANY MANTEINANCE OF THIS SOFTWARE; OR TO SUPPLY ANY UPDATES OR ENHANCEMENTS
*	EVEN IF SUCH ARE, OR LATER BECOME, AVAILABLE.
*
*	IF YOU DOWNLOAD OR USE THIS SOFTWARE YOU AGREE TO THESE TERMS, AND DO IT AT
*	YOUR OWN RISK.
*******************************************************************************/

/*******************************************************************************
*	File:		pws_CST000041.h
*	Project:	MCRP07 RX62T
*	Revision:	7.0
*	Date:		25-11-2013 (DD-MM-YYYY)
*	Author:		Andrea Ghirardello
*	Contents:	Internal power stage (CST000041) related definitions
*******************************************************************************/

#ifndef	_PWS_CST000041_H
#define _PWS_CST000041_H

// current conversion
#define RSHUNT_OHM			0.1			// shunt value [Ohm]
#define RSGAIN				5.0			// circuit gain

// DC bus voltage conversion
#define RVBUSH_OHM			47000.0		// high side split resistor [Ohm]
#define RVBUSL_OHM			10000.0		// low side split resistor [Ohm]

// deadtimes to be inserted by MTU
//#define DEADTIM_NS			1000		// deatimes [ns]
#define DEADTIM_NS			0			// due to driving transistors delay, no further deadtimes are needed

// minimum on time of low arms, to guarantee bootstrap operations
// this time should guarantee that the lower switch commutates effectively for enough time to
// charge the bootstrap capacitor
#define MIN_TON_LOW_NS		1500		// [ns] larger than deadtimes

// voltages
#define VB_NOM_VOL			24			// nominal bus voltage [V]

// inverter non linearities compensation
// non-linearities table definitions for MCRP INTERNAL POWER STAGE CST000041
// voltage error is INL_O+INL_xx[I]*pwm_freq_Hz*BusVoltage/1000000
#define T_INL_INMAX			3.1f
#define T_INL_INDMAX		31
#define INL_O	0.0f
#define INL_01	3.8		// 0.1A
#define INL_02	3.9		// 0.2A
#define INL_03	3.93125	// 0.3A
#define INL_04	3.95	// 0.4A
#define INL_05	3.9625	// 0.5A
#define INL_06	3.96875	// 0.6A
#define INL_07	3.975	// 0.7A
#define INL_08	3.975	// 0.8A
#define INL_09	3.98125	// 0.9A
#define INL_10	3.9875	// 1.0A
#define INL_11	3.9875	// 1.1A
#define INL_12	3.99375	// 1.2A
#define INL_13	3.99375	// 1.3A
#define INL_14	4.0		// 1.4A
#define INL_15	4.0		// 1.5A
#define INL_16	4.00625	// 1.6A
#define INL_17	4.00625	// 1.7A
#define INL_18	4.0125	// 1.8A
#define INL_19	4.0125	// 1.9A
#define INL_20	4.0125	// 2.0A
#define INL_21	4.0125	// 2.1A
#define INL_22	4.0125	// 2.2A
#define INL_23	4.0125	// 2.3A
#define INL_24	4.0125	// 2.4A
#define INL_25	4.0125	// 2.5A
#define INL_26	4.0125	// 2.6A
#define INL_27	4.0125	// 2.7A
#define INL_28	4.0125	// 2.8A
#define INL_29	4.0125	// 2.9A
#define INL_30	4.00625	// 3.0A
#define INL_31	4.00625	// 3.1A

#endif	// _PWS_CST000041_H

