
/*******************************************************************************
*	DISCLAIMER
*
*	THIS SOFTWARE IS PROVIDED "AS IS" AND BFG ENGINEERING MAKES NO WARRANTIES
*	REGARDING THIS SOFTWARE, WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING
*	BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
*	PURPOSE AND NON-INFRINGEMENT. ALL SUCH WARRANTIES ARE EXPRESSLY DISCLAIMED.
*
*	WE (BFG ENGINEERING) DO NOT WARRANT THAT THIS SOFTWARE IS FREE FROM CLAIMS
*	BY A THIRD PARTY OF COPYRIGHT, PATENT, TRADEMARK, TRADE SECRET OR ANY OTHER
*	INTELLECTUAL PROPERTY INFRINGIMENT.
*
*	TO THE MAXIMUM EXTENT PERMITTED NOT PROHIBITED BY LAW, BFG ENGINEERING
*	SHALL NOT BE LIABLE FOR ANY DIRECT, INDIRECT, SPECIAL, INCIDENTAL OR
*	CONSEQUENTIAL DAMAGES FOR ANY REASON RELATED TO THIS SOFTWARE, EVEN IF BFG
*	ENGINEERING HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
*	PARTICULARLY, UNDER NO CIRCUMSTANCES ARE WE LIABLE FOR ANY OF THE FOLLOWING:
*	- THIRD PARTY CLAIMS AGAINST YOU FOR LOSSES OR DAMAGES;
*	- LOSS OF, OR DAMAGE TO YOUR RECORDS OR DATA; OR
*	- ECONOMIC CONSEQUENTIAL DAMAGES (INCLUDING LOST PROFITS OR SAVINGS) OR
*	  INCIDENTAL DAMAGES, EVEN IF WE ARE INFORMED OF THEIR POSSIBILITY.
*
*	BFG ENGINEERING DOES NOT WARRANT UNINTERRUPTED OR ERROR_FREE OPERATION OF
*	THIS SOFTWARE.
*	BFG ENGINEERING HAS NO OBLIGATION TO PROVIDE SERVICE, DEFECT CORRECTION OR
*	ANY MANTEINANCE OF THIS SOFTWARE; OR TO SUPPLY ANY UPDATES OR ENHANCEMENTS
*	EVEN IF SUCH ARE, OR LATER BECOME, AVAILABLE.
*
*	IF YOU DOWNLOAD OR USE THIS SOFTWARE YOU AGREE TO THESE TERMS, AND DO IT AT
*	YOUR OWN RISK.
*******************************************************************************/

/*******************************************************************************
*	File:		userif.h
*	Project:	MCRP07 RX62T
*	Revision:	7.0
*	Date:		25-10-2013 (DD-MM-YYYY)
*	Author:		Andrea Ghirardello
*	Contents:	Header for user interface
*******************************************************************************/

#ifndef	_USERIF_H
#define	_USERIF_H

#define N_RAM_READ		32
typedef union {
	unsigned short		ram_tab[N_RAM_READ];
	struct {
		signed short	rif;		//  0	internal speed reference
		signed short	rpm;		//  1	measured speed
		signed short	fre;		//  2	imposed frequency
		signed short	id;			//  3	direct current
		signed short	iq;			//  4	quadrature current
		signed short 	vd;			//  5	direct voltage
		signed short 	vq;			//  6	quadrature voltage
		signed short	vb;			//  7	bus voltage
		signed short	all;		//  8	alarm
		signed short	flg;		//  9	flags
		signed short	toti;		// 10	current vector amplitude
		signed short	totv;		// 11	voltage vector amplitude
		signed short	du0;		// 12
		signed short	du1;		// 13
		signed short	du2;		// 14
		signed short	du3;		// 15
		signed short	mod;		// 16	mode
		signed short	rs;			// 17	stator resistance
		signed short	ls;			// 18	synchronous inductance	
		signed short	fl;			// 19	permanent magnet flux
		signed short	kpi;		// 20	current loop kp
		signed short	kii;		// 21	current loop ki
		signed short	pwmf;		// 22	pwm frequency [Hz]
		signed short	sf;			// 23	sampling frequency [Hz]
		signed short	ena;		// 24	extra features enable flags
		signed short	du4;		// 25
		signed short	du5;		// 26
		signed short	du6;		// 27
		signed short	du7;		// 28
		signed short	du8;		// 29
		signed short	du9;		// 30
		signed short	du10;		// 31
	}					var;
}	UIF_R_type;
#define N_RAM_WRITE		8
typedef union {
	unsigned short		ram_tab[N_RAM_WRITE];
	struct {
		signed short	trg;		//  0	trigger
		signed short	mod;		//  1	mode
		signed short	rif;		//  2	speed reference
		signed short	cra;		//  3	current ratio
		signed short	sel;		//  4	variable and time scale selection
		signed short	du0;		//  5
		signed short	du1;		//  6
		signed short	du2;		//  7
	}					var;
}	UIF_W_type;

#define MAX_SAM_CNT		125
#define OUTBUF_XDIM		128
#define OUTBUF_SDIM		OUTBUF_XDIM
#define OUTBUF_CDIM		(OUTBUF_XDIM*2)
typedef union {
	signed short		ss[OUTBUF_SDIM];
	unsigned char		uc[OUTBUF_CDIM];
} OUTB_type;

#ifdef _USERIF_C
UIF_R_type				UIF_R;
UIF_W_type				UIF_W;
OUTB_type				outbuf, outbuf1;
unsigned short			*wbuf=((unsigned short *)(outbuf1.ss));
unsigned short			*rbuf=((unsigned short *)(outbuf.ss));
unsigned short			*pbuf=((unsigned short *)(outbuf.ss));
#else	// _USERIF_C
extern UIF_R_type		UIF_R;
extern UIF_W_type		UIF_W;
extern OUTB_type		outbuf, outbuf1;
extern unsigned short	*wbuf;
extern unsigned short	*rbuf;
extern unsigned short	*pbuf;
#endif	// _USERIF_C

void uif_delay(u32 time);
void ini_232_pc(void);
void poll_232_pc(void);
void ges_232_pc(void);
void ges_led(void);

#endif	// _USERIF_H


/*	--- Special Working Modes ---

	Special working modes are controlled trough UIF_W.var.mod:
	if it is 0 then normal mode is used, other values stay for
	special modes. A feedback of the working mode is given in UIF_R.var.mod,
	which is equal to the working mode.
	If the working mode requires a trigger from the GUI to execute some
	operations, UIF_W.var.trg bit0 is used (it is automatically cleared after
	being detected); the feedback regarding the requested operation status
	is given by some bits in UIF_R.var.flg: bit9=1 means BUSY, while if it is 0 means
	READY, bitA=1 means last operation was ENDED_NOK, while if it is 0 means ENDED_OK.
	Trigger requests are not accepted if UIF_R.var.sta is not ready. It means that the
	GUI has to stay in polling for this flag after a trigger.
	Other important flags are bit7 (alarm), and bit8 which indicates that the motor
	is driven.
	Working status can be changed only when the motor in not driven (UIF_R.var.flg
	has bit8 equal to 0).
*/

#define ENA_CURPI_TUN	UIF_R.var.ena |= WSET0;
#define ENA_CURPI_AUT	UIF_R.var.ena |= WSET1;
#define ENA_AUTO_IDEN	UIF_R.var.ena |= WSET2;
#define ENA_OSCI_WIND	UIF_R.var.ena |= WSET3;

#define NORM_MODE_CODE	( 0 )	// normal inverter behaviour
#define CURPI_TUN_CODE	( 1 )	// current PI gains manual tuning mode
#define CURPI_AUT_CODE	( 2 )	// current PI gains automatic detection mode
#define AUTO_IDEN_CODE	( 3 )	// motor parameters auto-identification mode

#define NORM_MODE_REQ	( UIF_W.var.mod == NORM_MODE_CODE )
#define CURPI_TUN_REQ	( UIF_W.var.mod == CURPI_TUN_CODE )
#define CURPI_AUT_REQ	( UIF_W.var.mod == CURPI_AUT_CODE )
#define AUTO_IDEN_REQ	( UIF_W.var.mod == AUTO_IDEN_CODE )

#define NORM_MODE		( UIF_R.var.mod == NORM_MODE_CODE )
#define CURPI_TUN		( UIF_R.var.mod == CURPI_TUN_CODE )
#define CURPI_AUT		( UIF_R.var.mod == CURPI_AUT_CODE )
#define AUTO_IDEN		( UIF_R.var.mod == AUTO_IDEN_CODE )

#define SET_NORM_MODE	UIF_R.var.mod = NORM_MODE_CODE;
#define SET_CURPI_TUN	UIF_R.var.mod = CURPI_TUN_CODE;
#define SET_CURPI_AUT	UIF_R.var.mod = CURPI_AUT_CODE;
#define SET_AUTO_IDEN	UIF_R.var.mod = AUTO_IDEN_CODE;

#define ALRM_ON			(UIF_R.var.flg & WSET7)
#define ALRM_OFF		(! ALRM_ON)
#define COM_ON			(UIF_R.var.flg & WSET8)
#define COM_OFF			(! COM_ON)
#define STA_BSY			(UIF_R.var.flg & WSET9)
#define STA_RDY			(! STA_BSY)
#define END_NOK			(UIF_R.var.flg & WSETA)
#define END_OK			(! END_NOK)
#define ICOM_ON			(UIF_R.var.flg & WSETB)
#define ICOM_OFF		(! ICOM_ON)
#define SET_ALRM_ON		UIF_R.var.flg |= WSET7;
#define RES_ALRM_ON		UIF_R.var.flg &= WCLR7;
#define SET_COM_ON		UIF_R.var.flg |= WSET8;
#define RES_COM_ON		UIF_R.var.flg &= WCLR8;
#define SET_STA_BSY		UIF_R.var.flg |= WSET9;
#define RES_STA_BSY		UIF_R.var.flg &= WCLR9;
#define SET_END_NOK		UIF_R.var.flg |= WSETA;
#define RES_END_NOK		UIF_R.var.flg &= WCLRA;
#define SET_ICOM_ON		UIF_R.var.flg |= WSETB;
#define RES_ICOM_ON		UIF_R.var.flg &= WCLRB;

#define GUI_TRI			(UIF_W.var.trg & WSET0)
#define RES_GUI_TRI		UIF_W.var.trg &= WCLR0;
#define GUI_STP			(UIF_W.var.trg & WSET1)
#define RES_GUI_STP		UIF_W.var.trg &= WCLR1;



